// u-blox 9 positioning receivers configuration library
//
// Copyright (c) 2020-2021 Philippe Kehl (flipflip at oinkzwurgl dot org),
// https://oinkzwurgl.org/hacking/ubloxcfg
//
//    This program is free software: you can redistribute it and/or modify it under the terms of the
//    GNU Lesser General Public License as published by the Free Software Foundation, either version 3
//    of the License, or (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
//    without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//    See the GNU Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public License along with this
//    program. If not, see <https://www.gnu.org/licenses/>.
//
// This file is automatically generated. Do not edit.

// Sources:
// - u-blox ZED-F9P Interface Description (HPG 1.13) (https://www.u-blox.com/en/docs/UBX-18010854), copyright (c) 2020 u-blox AG
// - u-blox NEO-M9N Interface description (SPG 4.04) (https://www.u-blox.com/en/docs/UBX-19035940), copyright (c) 2020 u-blox AG
// - u-blox ZED-F9R Interface description (HPS 1.20) (https://www.u-blox.com/en/docs/UBX-19056845), copyright (c) 2020 u-blox AG
// - u-center 20.01, copyright (c) 2020 u-blox AG

#include <stddef.h>
#include "ubloxcfg.h"
#include "ubloxcfg_gen.h"


static const UBLOXCFG_ITEM_t ubloxcfg_cfgBdsUsePrn1To5 =
{
    .id = 0x10340014, .name = "CFG-BDS-USE_PRN_1_TO_5",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =    1, .title ="Use BeiDou geostationary satellites (PRN 1-5)"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgGeofenceConflvl_consts[6] =
{
    {
        .name = "L000",              .value = "0",                 .val = { .E = 0 },
        .title = "No confidence"
    },
    {
        .name = "L680",              .value = "1",                 .val = { .E = 1 },
        .title = "68%"
    },
    {
        .name = "L950",              .value = "2",                 .val = { .E = 2 },
        .title = "95%"
    },
    {
        .name = "L997",              .value = "3",                 .val = { .E = 3 },
        .title = "99.7%"
    },
    {
        .name = "L9999",             .value = "4",                 .val = { .E = 4 },
        .title = "99.99%"
    },
    {
        .name = "L999999",           .value = "5",                 .val = { .E = 5 },
        .title = "99.9999%"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceConflvl =
{
    .id = 0x20240011, .name = "CFG-GEOFENCE-CONFLVL",                            .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =    2, .title ="Required confidence level for state evaluation",
    .nConsts =   6, .consts = ubloxcfg_cfgGeofenceConflvl_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceUsePio =
{
    .id = 0x10240012, .name = "CFG-GEOFENCE-USE_PIO",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =    3, .title ="Use PIO combined fence state output"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgGeofencePinpol_consts[2] =
{
    {
        .name = "LOW_IN",            .value = "0",                 .val = { .E = 0 },
        .title = "PIO low means inside geofence"
    },
    {
        .name = "LOW_OUT",           .value = "1",                 .val = { .E = 1 },
        .title = "PIO low means outside geofence"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofencePinpol =
{
    .id = 0x20240013, .name = "CFG-GEOFENCE-PINPOL",                             .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =    4, .title ="PIO pin polarity",
    .nConsts =   2, .consts = ubloxcfg_cfgGeofencePinpol_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofencePin =
{
    .id = 0x20240014, .name = "CFG-GEOFENCE-PIN",                                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =    5, .title ="PIO pin number"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceUseFence1 =
{
    .id = 0x10240020, .name = "CFG-GEOFENCE-USE_FENCE1",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =    6, .title ="Use first geofence"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence1Lat =
{
    .id = 0x40240021, .name = "CFG-GEOFENCE-FENCE1_LAT",                         .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =    7, .title ="Latitude of the first geofence circle center",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence1Lon =
{
    .id = 0x40240022, .name = "CFG-GEOFENCE-FENCE1_LON",                         .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =    8, .title ="Longitude of the first geofence circle center",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence1Rad =
{
    .id = 0x40240023, .name = "CFG-GEOFENCE-FENCE1_RAD",                         .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =    9, .title ="Radius of the first geofence circle",
    .unit = "m",        .scale = "0.01",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceUseFence2 =
{
    .id = 0x10240030, .name = "CFG-GEOFENCE-USE_FENCE2",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   10, .title ="Use second geofence"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence2Lat =
{
    .id = 0x40240031, .name = "CFG-GEOFENCE-FENCE2_LAT",                         .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   11, .title ="Latitude of the second geofence circle center",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence2Lon =
{
    .id = 0x40240032, .name = "CFG-GEOFENCE-FENCE2_LON",                         .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   12, .title ="Longitude of the second geofence circle center",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence2Rad =
{
    .id = 0x40240033, .name = "CFG-GEOFENCE-FENCE2_RAD",                         .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   13, .title ="Radius of the second geofence circle",
    .unit = "m",        .scale = "0.01",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceUseFence3 =
{
    .id = 0x10240040, .name = "CFG-GEOFENCE-USE_FENCE3",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   14, .title ="Use third geofence"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence3Lat =
{
    .id = 0x40240041, .name = "CFG-GEOFENCE-FENCE3_LAT",                         .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   15, .title ="Latitude of the third geofence circle center",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence3Lon =
{
    .id = 0x40240042, .name = "CFG-GEOFENCE-FENCE3_LON",                         .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   16, .title ="Longitude of the third geofence circle center",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence3Rad =
{
    .id = 0x40240043, .name = "CFG-GEOFENCE-FENCE3_RAD",                         .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   17, .title ="Radius of the third geofence circle",
    .unit = "m",        .scale = "0.01",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceUseFence4 =
{
    .id = 0x10240050, .name = "CFG-GEOFENCE-USE_FENCE4",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   18, .title ="Use fourth geofence"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence4Lat =
{
    .id = 0x40240051, .name = "CFG-GEOFENCE-FENCE4_LAT",                         .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   19, .title ="Latitude of the fourth geofence circle center",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence4Lon =
{
    .id = 0x40240052, .name = "CFG-GEOFENCE-FENCE4_LON",                         .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   20, .title ="Longitude of the fourth geofence circle center",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgGeofenceFence4Rad =
{
    .id = 0x40240053, .name = "CFG-GEOFENCE-FENCE4_RAD",                         .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   21, .title ="Radius of the fourth geofence circle",
    .unit = "m",        .scale = "0.01",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntCfgVoltctrl =
{
    .id = 0x10a3002e, .name = "CFG-HW-ANT_CFG_VOLTCTRL",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   22, .title ="Active antenna voltage control flag"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntCfgShortdet =
{
    .id = 0x10a3002f, .name = "CFG-HW-ANT_CFG_SHORTDET",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   23, .title ="Short antenna detection flag"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntCfgShortdetPol =
{
    .id = 0x10a30030, .name = "CFG-HW-ANT_CFG_SHORTDET_POL",                     .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   24, .title ="Short antenna detection polarity"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntCfgOpendet =
{
    .id = 0x10a30031, .name = "CFG-HW-ANT_CFG_OPENDET",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   25, .title ="Open antenna detection flag"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntCfgOpendetPol =
{
    .id = 0x10a30032, .name = "CFG-HW-ANT_CFG_OPENDET_POL",                      .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   26, .title ="Open antenna detection polarity"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntCfgPwrdown =
{
    .id = 0x10a30033, .name = "CFG-HW-ANT_CFG_PWRDOWN",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   27, .title ="Power down antenna flag"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntCfgPwrdownPol =
{
    .id = 0x10a30034, .name = "CFG-HW-ANT_CFG_PWRDOWN_POL",                      .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   28, .title ="Power down antenna logic polarity"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntCfgRecover =
{
    .id = 0x10a30035, .name = "CFG-HW-ANT_CFG_RECOVER",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   29, .title ="Automatic recovery from short state flag"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntSupSwitchPin =
{
    .id = 0x20a30036, .name = "CFG-HW-ANT_SUP_SWITCH_PIN",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   30, .title ="ANT1 PIO number"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntSupShortPin =
{
    .id = 0x20a30037, .name = "CFG-HW-ANT_SUP_SHORT_PIN",                        .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   31, .title ="ANT0 PIO number"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntSupOpenPin =
{
    .id = 0x20a30038, .name = "CFG-HW-ANT_SUP_OPEN_PIN",                         .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   32, .title ="ANT2 PIO number"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgHwAntSupEngine_consts[2] =
{
    {
        .name = "EXT",               .value = "0",                 .val = { .E = 0 },
        .title = "Uses external comparators for current measurement"
    },
    {
        .name = "MADC",              .value = "1",                 .val = { .E = 1 },
        .title = "Uses built-in ADC and a shunt for current measurement"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntSupEngine =
{
    .id = 0x20a30054, .name = "CFG-HW-ANT_SUP_ENGINE",                           .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =   33, .title ="Antenna supervisor engine selection",
    .nConsts =   2, .consts = ubloxcfg_cfgHwAntSupEngine_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntSupShortThr =
{
    .id = 0x20a30055, .name = "CFG-HW-ANT_SUP_SHORT_THR",                        .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   34, .title ="Antenna supervisor MADC engine short detection threshold",
        .unit = "mV"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgHwAntSupOpenThr =
{
    .id = 0x20a30056, .name = "CFG-HW-ANT_SUP_OPEN_THR",                         .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   35, .title ="Antenna supervisor MADC engine open detection threshold",
        .unit = "mV"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgI2cAddress =
{
    .id = 0x20510001, .name = "CFG-I2C-ADDRESS",                                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   36, .title ="I2C slave address of the receiver (7 bits)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgI2cExtendedtimeout =
{
    .id = 0x10510002, .name = "CFG-I2C-EXTENDEDTIMEOUT",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   37, .title ="Flag to disable timeouting the interface after 1.5 s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgI2cEnabled =
{
    .id = 0x10510003, .name = "CFG-I2C-ENABLED",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   38, .title ="Flag to indicate if the I2C interface should be enabled"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgI2cinprotUbx =
{
    .id = 0x10710001, .name = "CFG-I2CINPROT-UBX",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   39, .title ="Flag to indicate if UBX should be an input protocol on I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgI2cinprotNmea =
{
    .id = 0x10710002, .name = "CFG-I2CINPROT-NMEA",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   40, .title ="Flag to indicate if NMEA should be an input protocol on I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgI2cinprotRtcm3x =
{
    .id = 0x10710004, .name = "CFG-I2CINPROT-RTCM3X",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   41, .title ="Flag to indicate if RTCM3X should be an input protocol on I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgI2coutprotUbx =
{
    .id = 0x10720001, .name = "CFG-I2COUTPROT-UBX",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   42, .title ="Flag to indicate if UBX should be an output protocol on I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgI2coutprotNmea =
{
    .id = 0x10720002, .name = "CFG-I2COUTPROT-NMEA",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   43, .title ="Flag to indicate if NMEA should be an output protocol on I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgI2coutprotRtcm3x =
{
    .id = 0x10720004, .name = "CFG-I2COUTPROT-RTCM3X",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   44, .title ="Flag to indicate if RTCM3X should be an output protocol on I2C"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgUbxI2c_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgUbxI2c =
{
    .id = 0x20920001, .name = "CFG-INFMSG-UBX_I2C",                              .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   45, .title ="Information message enable flags for the UBX protocol on the I2C interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgUbxI2c_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgUbxUart1_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgUbxUart1 =
{
    .id = 0x20920002, .name = "CFG-INFMSG-UBX_UART1",                            .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   46, .title ="Information message enable flags for the UBX protocol on the UART1 interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgUbxUart1_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgUbxUart2_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgUbxUart2 =
{
    .id = 0x20920003, .name = "CFG-INFMSG-UBX_UART2",                            .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   47, .title ="Information message enable flags for the UBX protocol on the UART2 interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgUbxUart2_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgUbxUsb_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgUbxUsb =
{
    .id = 0x20920004, .name = "CFG-INFMSG-UBX_USB",                              .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   48, .title ="Information message enable flags for the UBX protocol on the USB interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgUbxUsb_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgUbxSpi_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgUbxSpi =
{
    .id = 0x20920005, .name = "CFG-INFMSG-UBX_SPI",                              .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   49, .title ="Information message enable flags for the UBX protocol on the SPI interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgUbxSpi_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgNmeaI2c_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgNmeaI2c =
{
    .id = 0x20920006, .name = "CFG-INFMSG-NMEA_I2C",                             .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   50, .title ="Information message enable flags for the NMEA protocol on the I2C interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgNmeaI2c_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgNmeaUart1_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgNmeaUart1 =
{
    .id = 0x20920007, .name = "CFG-INFMSG-NMEA_UART1",                           .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   51, .title ="Information message enable flags for the NMEA protocol on the UART1 interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgNmeaUart1_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgNmeaUart2_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgNmeaUart2 =
{
    .id = 0x20920008, .name = "CFG-INFMSG-NMEA_UART2",                           .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   52, .title ="Information message enable flags for the NMEA protocol on the UART2 interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgNmeaUart2_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgNmeaUsb_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgNmeaUsb =
{
    .id = 0x20920009, .name = "CFG-INFMSG-NMEA_USB",                             .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   53, .title ="Information message enable flags for the NMEA protocol on the USB interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgNmeaUsb_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgInfmsgNmeaSpi_consts[5] =
{
    {
        .name = "ERROR",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "Enable ERROR information messages"
    },
    {
        .name = "WARNING",           .value = "0x02",              .val = { .X = 0x02 },
        .title = "Enable WARNING information messages"
    },
    {
        .name = "NOTICE",            .value = "0x04",              .val = { .X = 0x04 },
        .title = "Enable NOTICE information messages"
    },
    {
        .name = "TEST",              .value = "0x08",              .val = { .X = 0x08 },
        .title = "Enable TEST information messages"
    },
    {
        .name = "DEBUG",             .value = "0x10",              .val = { .X = 0x10 },
        .title = "Enable DEBUG information messages"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgInfmsgNmeaSpi =
{
    .id = 0x2092000a, .name = "CFG-INFMSG-NMEA_SPI",                             .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =   54, .title ="Information message enable flags for the NMEA protocol on the SPI interface",
    .nConsts =   5, .consts = ubloxcfg_cfgInfmsgNmeaSpi_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgItfmBbthreshold =
{
    .id = 0x20410001, .name = "CFG-ITFM-BBTHRESHOLD",                            .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   55, .title ="Broadband jamming detection threshold"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgItfmCwthreshold =
{
    .id = 0x20410002, .name = "CFG-ITFM-CWTHRESHOLD",                            .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   56, .title ="CW jamming detection threshold"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgItfmEnable =
{
    .id = 0x1041000d, .name = "CFG-ITFM-ENABLE",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   57, .title ="Enable interference detection"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgItfmAntsetting_consts[3] =
{
    {
        .name = "UNKNOWN",           .value = "0",                 .val = { .E = 0 },
        .title = "Unknown"
    },
    {
        .name = "PASSIVE",           .value = "1",                 .val = { .E = 1 },
        .title = "Passive"
    },
    {
        .name = "ACTIVE",            .value = "2",                 .val = { .E = 2 },
        .title = "Active"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgItfmAntsetting =
{
    .id = 0x20410010, .name = "CFG-ITFM-ANTSETTING",                             .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =   58, .title ="Antenna setting",
    .nConsts =   3, .consts = ubloxcfg_cfgItfmAntsetting_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgItfmEnableAux =
{
    .id = 0x10410013, .name = "CFG-ITFM-ENABLE_AUX",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   59, .title ="Scan auxiliary bands"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgLogfilterRecordEna =
{
    .id = 0x10de0002, .name = "CFG-LOGFILTER-RECORD_ENA",                        .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   60, .title ="Recording enabled"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgLogfilterOncePerWakeUpEna =
{
    .id = 0x10de0003, .name = "CFG-LOGFILTER-ONCE_PER_WAKE_UP_ENA",              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   61, .title ="Once per wake up"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgLogfilterApplyAllFilters =
{
    .id = 0x10de0004, .name = "CFG-LOGFILTER-APPLY_ALL_FILTERS",                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =   62, .title ="Apply all filter settings"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgLogfilterMinInterval =
{
    .id = 0x30de0005, .name = "CFG-LOGFILTER-MIN_INTERVAL",                      .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =   63, .title ="Minimum time interval between logged positions",
        .unit = "s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgLogfilterTimeThrs =
{
    .id = 0x30de0006, .name = "CFG-LOGFILTER-TIME_THRS",                         .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =   64, .title ="Time threshold",
        .unit = "s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgLogfilterSpeedThrs =
{
    .id = 0x30de0007, .name = "CFG-LOGFILTER-SPEED_THRS",                        .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =   65, .title ="Speed threshold",
        .unit = "m/s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgLogfilterPositionThrs =
{
    .id = 0x40de0008, .name = "CFG-LOGFILTER-POSITION_THRS",                     .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =   66, .title ="Position threshold",
        .unit = "m"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMotGnssspeedThrs =
{
    .id = 0x20250038, .name = "CFG-MOT-GNSSSPEED_THRS",                          .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   67, .title ="GNSS speed threshold below which platform is considered as stationary (a.k.a. static hold threshold)",
    .unit = "m/s",      .scale = "0.01",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMotGnssdistThrs =
{
    .id = 0x3025003b, .name = "CFG-MOT-GNSSDIST_THRS",                           .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =   68, .title ="Distance above which GNSS-based stationary motion is exit (a.k.a. static hold distance threshold)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdDtmUart1 =
{
    .id = 0x209100a7, .name = "CFG-MSGOUT-NMEA_ID_DTM_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   69, .title ="Output rate of the NMEA-STANDARD-DTM message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdDtmUart2 =
{
    .id = 0x209100a8, .name = "CFG-MSGOUT-NMEA_ID_DTM_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   70, .title ="Output rate of the NMEA-STANDARD-DTM message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdDtmSpi =
{
    .id = 0x209100aa, .name = "CFG-MSGOUT-NMEA_ID_DTM_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   71, .title ="Output rate of the NMEA-STANDARD-DTM message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdDtmI2c =
{
    .id = 0x209100a6, .name = "CFG-MSGOUT-NMEA_ID_DTM_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   72, .title ="Output rate of the NMEA-STANDARD-DTM message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdDtmUsb =
{
    .id = 0x209100a9, .name = "CFG-MSGOUT-NMEA_ID_DTM_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   73, .title ="Output rate of the NMEA-STANDARD-DTM message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGbsUart1 =
{
    .id = 0x209100de, .name = "CFG-MSGOUT-NMEA_ID_GBS_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   74, .title ="Output rate of the NMEA-STANDARD-GBS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGbsUart2 =
{
    .id = 0x209100df, .name = "CFG-MSGOUT-NMEA_ID_GBS_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   75, .title ="Output rate of the NMEA-STANDARD-GBS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGbsSpi =
{
    .id = 0x209100e1, .name = "CFG-MSGOUT-NMEA_ID_GBS_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   76, .title ="Output rate of the NMEA-STANDARD-GBS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGbsI2c =
{
    .id = 0x209100dd, .name = "CFG-MSGOUT-NMEA_ID_GBS_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   77, .title ="Output rate of the NMEA-STANDARD-GBS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGbsUsb =
{
    .id = 0x209100e0, .name = "CFG-MSGOUT-NMEA_ID_GBS_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   78, .title ="Output rate of the NMEA-STANDARD-GBS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGgaUart1 =
{
    .id = 0x209100bb, .name = "CFG-MSGOUT-NMEA_ID_GGA_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   79, .title ="Output rate of the NMEA-STANDARD-GGA message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGgaUart2 =
{
    .id = 0x209100bc, .name = "CFG-MSGOUT-NMEA_ID_GGA_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   80, .title ="Output rate of the NMEA-STANDARD-GGA message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGgaSpi =
{
    .id = 0x209100be, .name = "CFG-MSGOUT-NMEA_ID_GGA_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   81, .title ="Output rate of the NMEA-STANDARD-GGA message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGgaI2c =
{
    .id = 0x209100ba, .name = "CFG-MSGOUT-NMEA_ID_GGA_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   82, .title ="Output rate of the NMEA-STANDARD-GGA message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGgaUsb =
{
    .id = 0x209100bd, .name = "CFG-MSGOUT-NMEA_ID_GGA_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   83, .title ="Output rate of the NMEA-STANDARD-GGA message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGllUart1 =
{
    .id = 0x209100ca, .name = "CFG-MSGOUT-NMEA_ID_GLL_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   84, .title ="Output rate of the NMEA-STANDARD-GLL message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGllUart2 =
{
    .id = 0x209100cb, .name = "CFG-MSGOUT-NMEA_ID_GLL_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   85, .title ="Output rate of the NMEA-STANDARD-GLL message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGllSpi =
{
    .id = 0x209100cd, .name = "CFG-MSGOUT-NMEA_ID_GLL_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   86, .title ="Output rate of the NMEA-STANDARD-GLL message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGllI2c =
{
    .id = 0x209100c9, .name = "CFG-MSGOUT-NMEA_ID_GLL_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   87, .title ="Output rate of the NMEA-STANDARD-GLL message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGllUsb =
{
    .id = 0x209100cc, .name = "CFG-MSGOUT-NMEA_ID_GLL_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   88, .title ="Output rate of the NMEA-STANDARD-GLL message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGnsUart1 =
{
    .id = 0x209100b6, .name = "CFG-MSGOUT-NMEA_ID_GNS_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   89, .title ="Output rate of the NMEA-STANDARD-GNS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGnsUart2 =
{
    .id = 0x209100b7, .name = "CFG-MSGOUT-NMEA_ID_GNS_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   90, .title ="Output rate of the NMEA-STANDARD-GNS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGnsSpi =
{
    .id = 0x209100b9, .name = "CFG-MSGOUT-NMEA_ID_GNS_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   91, .title ="Output rate of the NMEA-STANDARD-GNS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGnsI2c =
{
    .id = 0x209100b5, .name = "CFG-MSGOUT-NMEA_ID_GNS_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   92, .title ="Output rate of the NMEA-STANDARD-GNS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGnsUsb =
{
    .id = 0x209100b8, .name = "CFG-MSGOUT-NMEA_ID_GNS_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   93, .title ="Output rate of the NMEA-STANDARD-GNS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGrsUart1 =
{
    .id = 0x209100cf, .name = "CFG-MSGOUT-NMEA_ID_GRS_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   94, .title ="Output rate of the NMEA-STANDARD-GRS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGrsUart2 =
{
    .id = 0x209100d0, .name = "CFG-MSGOUT-NMEA_ID_GRS_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   95, .title ="Output rate of the NMEA-STANDARD-GRS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGrsSpi =
{
    .id = 0x209100d2, .name = "CFG-MSGOUT-NMEA_ID_GRS_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   96, .title ="Output rate of the NMEA-STANDARD-GRS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGrsI2c =
{
    .id = 0x209100ce, .name = "CFG-MSGOUT-NMEA_ID_GRS_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   97, .title ="Output rate of the NMEA-STANDARD-GRS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGrsUsb =
{
    .id = 0x209100d1, .name = "CFG-MSGOUT-NMEA_ID_GRS_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   98, .title ="Output rate of the NMEA-STANDARD-GRS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsaUart1 =
{
    .id = 0x209100c0, .name = "CFG-MSGOUT-NMEA_ID_GSA_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =   99, .title ="Output rate of the NMEA-STANDARD-GSA message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsaUart2 =
{
    .id = 0x209100c1, .name = "CFG-MSGOUT-NMEA_ID_GSA_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  100, .title ="Output rate of the NMEA-STANDARD-GSA message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsaSpi =
{
    .id = 0x209100c3, .name = "CFG-MSGOUT-NMEA_ID_GSA_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  101, .title ="Output rate of the NMEA-STANDARD-GSA message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsaI2c =
{
    .id = 0x209100bf, .name = "CFG-MSGOUT-NMEA_ID_GSA_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  102, .title ="Output rate of the NMEA-STANDARD-GSA message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsaUsb =
{
    .id = 0x209100c2, .name = "CFG-MSGOUT-NMEA_ID_GSA_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  103, .title ="Output rate of the NMEA-STANDARD-GSA message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGstUart1 =
{
    .id = 0x209100d4, .name = "CFG-MSGOUT-NMEA_ID_GST_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  104, .title ="Output rate of the NMEA-STANDARD-GST message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGstUart2 =
{
    .id = 0x209100d5, .name = "CFG-MSGOUT-NMEA_ID_GST_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  105, .title ="Output rate of the NMEA-STANDARD-GST message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGstSpi =
{
    .id = 0x209100d7, .name = "CFG-MSGOUT-NMEA_ID_GST_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  106, .title ="Output rate of the NMEA-STANDARD-GST message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGstI2c =
{
    .id = 0x209100d3, .name = "CFG-MSGOUT-NMEA_ID_GST_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  107, .title ="Output rate of the NMEA-STANDARD-GST message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGstUsb =
{
    .id = 0x209100d6, .name = "CFG-MSGOUT-NMEA_ID_GST_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  108, .title ="Output rate of the NMEA-STANDARD-GST message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsvUart1 =
{
    .id = 0x209100c5, .name = "CFG-MSGOUT-NMEA_ID_GSV_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  109, .title ="Output rate of the NMEA-STANDARD-GSV message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsvUart2 =
{
    .id = 0x209100c6, .name = "CFG-MSGOUT-NMEA_ID_GSV_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  110, .title ="Output rate of the NMEA-STANDARD-GSV message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsvSpi =
{
    .id = 0x209100c8, .name = "CFG-MSGOUT-NMEA_ID_GSV_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  111, .title ="Output rate of the NMEA-STANDARD-GSV message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsvI2c =
{
    .id = 0x209100c4, .name = "CFG-MSGOUT-NMEA_ID_GSV_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  112, .title ="Output rate of the NMEA-STANDARD-GSV message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdGsvUsb =
{
    .id = 0x209100c7, .name = "CFG-MSGOUT-NMEA_ID_GSV_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  113, .title ="Output rate of the NMEA-STANDARD-GSV message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRlmUart1 =
{
    .id = 0x20910401, .name = "CFG-MSGOUT-NMEA_ID_RLM_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  114, .title ="Output rate of the NMEA-STANDARD-RLM message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRlmUart2 =
{
    .id = 0x20910402, .name = "CFG-MSGOUT-NMEA_ID_RLM_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  115, .title ="Output rate of the NMEA-STANDARD-RLM message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRlmSpi =
{
    .id = 0x20910404, .name = "CFG-MSGOUT-NMEA_ID_RLM_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  116, .title ="Output rate of the NMEA-STANDARD-RLM message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRlmI2c =
{
    .id = 0x20910400, .name = "CFG-MSGOUT-NMEA_ID_RLM_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  117, .title ="Output rate of the NMEA-STANDARD-RLM message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRlmUsb =
{
    .id = 0x20910403, .name = "CFG-MSGOUT-NMEA_ID_RLM_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  118, .title ="Output rate of the NMEA-STANDARD-RLM message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRmcUart1 =
{
    .id = 0x209100ac, .name = "CFG-MSGOUT-NMEA_ID_RMC_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  119, .title ="Output rate of the NMEA-STANDARD-RMC message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRmcUart2 =
{
    .id = 0x209100ad, .name = "CFG-MSGOUT-NMEA_ID_RMC_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  120, .title ="Output rate of the NMEA-STANDARD-RMC message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRmcSpi =
{
    .id = 0x209100af, .name = "CFG-MSGOUT-NMEA_ID_RMC_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  121, .title ="Output rate of the NMEA-STANDARD-RMC message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRmcI2c =
{
    .id = 0x209100ab, .name = "CFG-MSGOUT-NMEA_ID_RMC_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  122, .title ="Output rate of the NMEA-STANDARD-RMC message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdRmcUsb =
{
    .id = 0x209100ae, .name = "CFG-MSGOUT-NMEA_ID_RMC_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  123, .title ="Output rate of the NMEA-STANDARD-RMC message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVlwUart1 =
{
    .id = 0x209100e8, .name = "CFG-MSGOUT-NMEA_ID_VLW_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  124, .title ="Output rate of the NMEA-STANDARD-VLW message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVlwUart2 =
{
    .id = 0x209100e9, .name = "CFG-MSGOUT-NMEA_ID_VLW_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  125, .title ="Output rate of the NMEA-STANDARD-VLW message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVlwSpi =
{
    .id = 0x209100eb, .name = "CFG-MSGOUT-NMEA_ID_VLW_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  126, .title ="Output rate of the NMEA-STANDARD-VLW message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVlwI2c =
{
    .id = 0x209100e7, .name = "CFG-MSGOUT-NMEA_ID_VLW_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  127, .title ="Output rate of the NMEA-STANDARD-VLW message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVlwUsb =
{
    .id = 0x209100ea, .name = "CFG-MSGOUT-NMEA_ID_VLW_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  128, .title ="Output rate of the NMEA-STANDARD-VLW message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVtgUart1 =
{
    .id = 0x209100b1, .name = "CFG-MSGOUT-NMEA_ID_VTG_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  129, .title ="Output rate of the NMEA-STANDARD-VTG message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVtgUart2 =
{
    .id = 0x209100b2, .name = "CFG-MSGOUT-NMEA_ID_VTG_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  130, .title ="Output rate of the NMEA-STANDARD-VTG message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVtgSpi =
{
    .id = 0x209100b4, .name = "CFG-MSGOUT-NMEA_ID_VTG_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  131, .title ="Output rate of the NMEA-STANDARD-VTG message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVtgI2c =
{
    .id = 0x209100b0, .name = "CFG-MSGOUT-NMEA_ID_VTG_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  132, .title ="Output rate of the NMEA-STANDARD-VTG message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdVtgUsb =
{
    .id = 0x209100b3, .name = "CFG-MSGOUT-NMEA_ID_VTG_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  133, .title ="Output rate of the NMEA-STANDARD-VTG message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdZdaUart1 =
{
    .id = 0x209100d9, .name = "CFG-MSGOUT-NMEA_ID_ZDA_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  134, .title ="Output rate of the NMEA-STANDARD-ZDA message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdZdaUart2 =
{
    .id = 0x209100da, .name = "CFG-MSGOUT-NMEA_ID_ZDA_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  135, .title ="Output rate of the NMEA-STANDARD-ZDA message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdZdaSpi =
{
    .id = 0x209100dc, .name = "CFG-MSGOUT-NMEA_ID_ZDA_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  136, .title ="Output rate of the NMEA-STANDARD-ZDA message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdZdaI2c =
{
    .id = 0x209100d8, .name = "CFG-MSGOUT-NMEA_ID_ZDA_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  137, .title ="Output rate of the NMEA-STANDARD-ZDA message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutNmeaIdZdaUsb =
{
    .id = 0x209100db, .name = "CFG-MSGOUT-NMEA_ID_ZDA_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  138, .title ="Output rate of the NMEA-STANDARD-ZDA message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolypUart1 =
{
    .id = 0x209100ed, .name = "CFG-MSGOUT-PUBX_ID_POLYP_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  139, .title ="Output rate of the NMEA-PUBX-POSITION message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolypUart2 =
{
    .id = 0x209100ee, .name = "CFG-MSGOUT-PUBX_ID_POLYP_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  140, .title ="Output rate of the NMEA-PUBX-POSITION message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolypSpi =
{
    .id = 0x209100f0, .name = "CFG-MSGOUT-PUBX_ID_POLYP_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  141, .title ="Output rate of the NMEA-PUBX-POSITION message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolypI2c =
{
    .id = 0x209100ec, .name = "CFG-MSGOUT-PUBX_ID_POLYP_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  142, .title ="Output rate of the NMEA-PUBX-POSITION message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolypUsb =
{
    .id = 0x209100ef, .name = "CFG-MSGOUT-PUBX_ID_POLYP_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  143, .title ="Output rate of the NMEA-PUBX-POSITION message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolysUart1 =
{
    .id = 0x209100f2, .name = "CFG-MSGOUT-PUBX_ID_POLYS_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  144, .title ="Output rate of the NMEA-PUBX-SVSTATUS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolysUart2 =
{
    .id = 0x209100f3, .name = "CFG-MSGOUT-PUBX_ID_POLYS_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  145, .title ="Output rate of the NMEA-PUBX-SVSTATUS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolysSpi =
{
    .id = 0x209100f5, .name = "CFG-MSGOUT-PUBX_ID_POLYS_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  146, .title ="Output rate of the NMEA-PUBX-SVSTATUS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolysI2c =
{
    .id = 0x209100f1, .name = "CFG-MSGOUT-PUBX_ID_POLYS_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  147, .title ="Output rate of the NMEA-PUBX-SVSTATUS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolysUsb =
{
    .id = 0x209100f4, .name = "CFG-MSGOUT-PUBX_ID_POLYS_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  148, .title ="Output rate of the NMEA-PUBX-SVSTATUS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolytUart1 =
{
    .id = 0x209100f7, .name = "CFG-MSGOUT-PUBX_ID_POLYT_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  149, .title ="Output rate of the NMEA-PUBX-TIME message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolytUart2 =
{
    .id = 0x209100f8, .name = "CFG-MSGOUT-PUBX_ID_POLYT_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  150, .title ="Output rate of the NMEA-PUBX-TIME message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolytSpi =
{
    .id = 0x209100fa, .name = "CFG-MSGOUT-PUBX_ID_POLYT_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  151, .title ="Output rate of the NMEA-PUBX-TIME message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolytI2c =
{
    .id = 0x209100f6, .name = "CFG-MSGOUT-PUBX_ID_POLYT_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  152, .title ="Output rate of the NMEA-PUBX-TIME message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutPubxIdPolytUsb =
{
    .id = 0x209100f9, .name = "CFG-MSGOUT-PUBX_ID_POLYT_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  153, .title ="Output rate of the NMEA-PUBX-TIME message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1005Uart1 =
{
    .id = 0x209102be, .name = "CFG-MSGOUT-RTCM_3X_TYPE1005_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  154, .title ="Output rate of the RTCM-3X-TYPE1005 (Stationary RTK reference station ARP) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1005Uart2 =
{
    .id = 0x209102bf, .name = "CFG-MSGOUT-RTCM_3X_TYPE1005_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  155, .title ="Output rate of the RTCM-3X-TYPE1005 (Stationary RTK reference station ARP) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1005Spi =
{
    .id = 0x209102c1, .name = "CFG-MSGOUT-RTCM_3X_TYPE1005_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  156, .title ="Output rate of the RTCM-3X-TYPE1005 (Stationary RTK reference station ARP) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1005I2c =
{
    .id = 0x209102bd, .name = "CFG-MSGOUT-RTCM_3X_TYPE1005_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  157, .title ="Output rate of the RTCM-3X-TYPE1005 (Stationary RTK reference station ARP) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1005Usb =
{
    .id = 0x209102c0, .name = "CFG-MSGOUT-RTCM_3X_TYPE1005_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  158, .title ="Output rate of the RTCM-3X-TYPE1005 (Stationary RTK reference station ARP) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1074Uart1 =
{
    .id = 0x2091035f, .name = "CFG-MSGOUT-RTCM_3X_TYPE1074_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  159, .title ="Output rate of the RTCM-3X-TYPE1074 (GPS MSM4: full C, full L, S) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1074Uart2 =
{
    .id = 0x20910360, .name = "CFG-MSGOUT-RTCM_3X_TYPE1074_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  160, .title ="Output rate of the RTCM-3X-TYPE1074 (GPS MSM4: full C, full L, S) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1074Spi =
{
    .id = 0x20910362, .name = "CFG-MSGOUT-RTCM_3X_TYPE1074_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  161, .title ="Output rate of the RTCM-3X-TYPE1074 (GPS MSM4: full C, full L, S) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1074I2c =
{
    .id = 0x2091035e, .name = "CFG-MSGOUT-RTCM_3X_TYPE1074_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  162, .title ="Output rate of the RTCM-3X-TYPE1074 (GPS MSM4: full C, full L, S) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1074Usb =
{
    .id = 0x20910361, .name = "CFG-MSGOUT-RTCM_3X_TYPE1074_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  163, .title ="Output rate of the RTCM-3X-TYPE1074 (GPS MSM4: full C, full L, S) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1077Uart1 =
{
    .id = 0x209102cd, .name = "CFG-MSGOUT-RTCM_3X_TYPE1077_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  164, .title ="Output rate of the RTCM-3X-TYPE1077 (GPS MSM7: ext full C, ext full L, S, D) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1077Uart2 =
{
    .id = 0x209102ce, .name = "CFG-MSGOUT-RTCM_3X_TYPE1077_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  165, .title ="Output rate of the RTCM-3X-TYPE1077 (GPS MSM7: ext full C, ext full L, S, D) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1077Spi =
{
    .id = 0x209102d0, .name = "CFG-MSGOUT-RTCM_3X_TYPE1077_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  166, .title ="Output rate of the RTCM-3X-TYPE1077 (GPS MSM7: ext full C, ext full L, S, D) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1077I2c =
{
    .id = 0x209102cc, .name = "CFG-MSGOUT-RTCM_3X_TYPE1077_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  167, .title ="Output rate of the RTCM-3X-TYPE1077 (GPS MSM7: ext full C, ext full L, S, D) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1077Usb =
{
    .id = 0x209102cf, .name = "CFG-MSGOUT-RTCM_3X_TYPE1077_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  168, .title ="Output rate of the RTCM-3X-TYPE1077 (GPS MSM7: ext full C, ext full L, S, D) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1084Uart1 =
{
    .id = 0x20910364, .name = "CFG-MSGOUT-RTCM_3X_TYPE1084_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  169, .title ="Output rate of the RTCM-3X-TYPE1084 (GLONASS MSM4: full C, full L, S) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1084Uart2 =
{
    .id = 0x20910365, .name = "CFG-MSGOUT-RTCM_3X_TYPE1084_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  170, .title ="Output rate of the RTCM-3X-TYPE1084 (GLONASS MSM4: full C, full L, S) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1084Spi =
{
    .id = 0x20910367, .name = "CFG-MSGOUT-RTCM_3X_TYPE1084_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  171, .title ="Output rate of the RTCM-3X-TYPE1084 (GLONASS MSM4: full C, full L, S) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1084I2c =
{
    .id = 0x20910363, .name = "CFG-MSGOUT-RTCM_3X_TYPE1084_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  172, .title ="Output rate of the RTCM-3X-TYPE1084 (GLONASS MSM4: full C, full L, S) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1084Usb =
{
    .id = 0x20910366, .name = "CFG-MSGOUT-RTCM_3X_TYPE1084_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  173, .title ="Output rate of the RTCM-3X-TYPE1084 (GLONASS MSM4: full C, full L, S) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1087Uart1 =
{
    .id = 0x209102d2, .name = "CFG-MSGOUT-RTCM_3X_TYPE1087_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  174, .title ="Output rate of the RTCM-3X-TYPE1087 (GLONASS MSM7: ext full C, ext full L, S, D) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1087Uart2 =
{
    .id = 0x209102d3, .name = "CFG-MSGOUT-RTCM_3X_TYPE1087_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  175, .title ="Output rate of the RTCM-3X-TYPE1087 (GLONASS MSM7: ext full C, ext full L, S, D) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1087Spi =
{
    .id = 0x209102d5, .name = "CFG-MSGOUT-RTCM_3X_TYPE1087_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  176, .title ="Output rate of the RTCM-3X-TYPE1087 (GLONASS MSM7: ext full C, ext full L, S, D) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1087I2c =
{
    .id = 0x209102d1, .name = "CFG-MSGOUT-RTCM_3X_TYPE1087_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  177, .title ="Output rate of the RTCM-3X-TYPE1087 (GLONASS MSM7: ext full C, ext full L, S, D) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1087Usb =
{
    .id = 0x209102d4, .name = "CFG-MSGOUT-RTCM_3X_TYPE1087_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  178, .title ="Output rate of the RTCM-3X-TYPE1087 (GLONASS MSM7: ext full C, ext full L, S, D) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1094Uart1 =
{
    .id = 0x20910369, .name = "CFG-MSGOUT-RTCM_3X_TYPE1094_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  179, .title ="Output rate of the RTCM-3X-TYPE1094 (Galileo MSM4: full C, full L, S) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1094Uart2 =
{
    .id = 0x2091036a, .name = "CFG-MSGOUT-RTCM_3X_TYPE1094_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  180, .title ="Output rate of the RTCM-3X-TYPE1094 (Galileo MSM4: full C, full L, S) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1094Spi =
{
    .id = 0x2091036c, .name = "CFG-MSGOUT-RTCM_3X_TYPE1094_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  181, .title ="Output rate of the RTCM-3X-TYPE1094 (Galileo MSM4: full C, full L, S) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1094I2c =
{
    .id = 0x20910368, .name = "CFG-MSGOUT-RTCM_3X_TYPE1094_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  182, .title ="Output rate of the RTCM-3X-TYPE1094 (Galileo MSM4: full C, full L, S) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1094Usb =
{
    .id = 0x2091036b, .name = "CFG-MSGOUT-RTCM_3X_TYPE1094_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  183, .title ="Output rate of the RTCM-3X-TYPE1094 (Galileo MSM4: full C, full L, S) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1097Uart1 =
{
    .id = 0x20910319, .name = "CFG-MSGOUT-RTCM_3X_TYPE1097_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  184, .title ="Output rate of the RTCM-3X-TYPE1097 (Galileo MSM7: ext full C, ext full L, S, D) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1097Uart2 =
{
    .id = 0x2091031a, .name = "CFG-MSGOUT-RTCM_3X_TYPE1097_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  185, .title ="Output rate of the RTCM-3X-TYPE1097 (Galileo MSM7: ext full C, ext full L, S, D) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1097Spi =
{
    .id = 0x2091031c, .name = "CFG-MSGOUT-RTCM_3X_TYPE1097_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  186, .title ="Output rate of the RTCM-3X-TYPE1097 (Galileo MSM7: ext full C, ext full L, S, D) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1097I2c =
{
    .id = 0x20910318, .name = "CFG-MSGOUT-RTCM_3X_TYPE1097_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  187, .title ="Output rate of the RTCM-3X-TYPE1097 (Galileo MSM7: ext full C, ext full L, S, D) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1097Usb =
{
    .id = 0x2091031b, .name = "CFG-MSGOUT-RTCM_3X_TYPE1097_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  188, .title ="Output rate of the RTCM-3X-TYPE1097 (Galileo MSM7: ext full C, ext full L, S, D) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1124Uart1 =
{
    .id = 0x2091036e, .name = "CFG-MSGOUT-RTCM_3X_TYPE1124_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  189, .title ="Output rate of the RTCM-3X-TYPE1124 (BeiDou MSM4: full C, full L, S) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1124Uart2 =
{
    .id = 0x2091036f, .name = "CFG-MSGOUT-RTCM_3X_TYPE1124_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  190, .title ="Output rate of the RTCM-3X-TYPE1124 (BeiDou MSM4: full C, full L, S) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1124Spi =
{
    .id = 0x20910371, .name = "CFG-MSGOUT-RTCM_3X_TYPE1124_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  191, .title ="Output rate of the RTCM-3X-TYPE1124 (BeiDou MSM4: full C, full L, S) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1124I2c =
{
    .id = 0x2091036d, .name = "CFG-MSGOUT-RTCM_3X_TYPE1124_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  192, .title ="Output rate of the RTCM-3X-TYPE1124 (BeiDou MSM4: full C, full L, S) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1124Usb =
{
    .id = 0x20910370, .name = "CFG-MSGOUT-RTCM_3X_TYPE1124_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  193, .title ="Output rate of the RTCM-3X-TYPE1124 (BeiDou MSM4: full C, full L, S) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1127Uart1 =
{
    .id = 0x209102d7, .name = "CFG-MSGOUT-RTCM_3X_TYPE1127_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  194, .title ="Output rate of the RTCM-3X-TYPE1127 (BeiDou MSM7: ext full C, ext full L, S, D) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1127Uart2 =
{
    .id = 0x209102d8, .name = "CFG-MSGOUT-RTCM_3X_TYPE1127_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  195, .title ="Output rate of the RTCM-3X-TYPE1127 (BeiDou MSM7: ext full C, ext full L, S, D) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1127Spi =
{
    .id = 0x209102da, .name = "CFG-MSGOUT-RTCM_3X_TYPE1127_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  196, .title ="Output rate of the RTCM-3X-TYPE1127 (BeiDou MSM7: ext full C, ext full L, S, D) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1127I2c =
{
    .id = 0x209102d6, .name = "CFG-MSGOUT-RTCM_3X_TYPE1127_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  197, .title ="Output rate of the RTCM-3X-TYPE1127 (BeiDou MSM7: ext full C, ext full L, S, D) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1127Usb =
{
    .id = 0x209102d9, .name = "CFG-MSGOUT-RTCM_3X_TYPE1127_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  198, .title ="Output rate of the RTCM-3X-TYPE1127 (BeiDou MSM7: ext full C, ext full L, S, D) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1230Uart1 =
{
    .id = 0x20910304, .name = "CFG-MSGOUT-RTCM_3X_TYPE1230_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  199, .title ="Output rate of the RTCM-3X-TYPE1230 (GLONASS code-phase biases) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1230Uart2 =
{
    .id = 0x20910305, .name = "CFG-MSGOUT-RTCM_3X_TYPE1230_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  200, .title ="Output rate of the RTCM-3X-TYPE1230 (GLONASS code-phase biases) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1230Spi =
{
    .id = 0x20910307, .name = "CFG-MSGOUT-RTCM_3X_TYPE1230_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  201, .title ="Output rate of the RTCM-3X-TYPE1230 (GLONASS code-phase biases) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1230I2c =
{
    .id = 0x20910303, .name = "CFG-MSGOUT-RTCM_3X_TYPE1230_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  202, .title ="Output rate of the RTCM-3X-TYPE1230 (GLONASS code-phase biases) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType1230Usb =
{
    .id = 0x20910306, .name = "CFG-MSGOUT-RTCM_3X_TYPE1230_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  203, .title ="Output rate of the RTCM-3X-TYPE1230 (GLONASS code-phase biases) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40720Uart1 =
{
    .id = 0x209102ff, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_0_UART1",             .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  204, .title ="Output rate of the RTCM-3X-TYPE4072_0 (u-blox proprietary: Reference station PVT) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40720Uart2 =
{
    .id = 0x20910300, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_0_UART2",             .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  205, .title ="Output rate of the RTCM-3X-TYPE4072_0 (u-blox proprietary: Reference station PVT) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40720Spi =
{
    .id = 0x20910302, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_0_SPI",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  206, .title ="Output rate of the RTCM-3X-TYPE4072_0 (u-blox proprietary: Reference station PVT) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40720I2c =
{
    .id = 0x209102fe, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_0_I2C",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  207, .title ="Output rate of the RTCM-3X-TYPE4072_0 (u-blox proprietary: Reference station PVT) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40720Usb =
{
    .id = 0x20910301, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_0_USB",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  208, .title ="Output rate of the RTCM-3X-TYPE4072_0 (u-blox proprietary: Reference station PVT) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40721Uart1 =
{
    .id = 0x20910382, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_1_UART1",             .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  209, .title ="Output rate of the RTCM-3X-TYPE4072_1 (u-blox proprietary: Additional reference station information) message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40721Uart2 =
{
    .id = 0x20910383, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_1_UART2",             .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  210, .title ="Output rate of the RTCM-3X-TYPE4072_1 (u-blox proprietary: Additional reference station information) message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40721Spi =
{
    .id = 0x20910385, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_1_SPI",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  211, .title ="Output rate of the RTCM-3X-TYPE4072_1 (u-blox proprietary: Additional reference station information) message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40721I2c =
{
    .id = 0x20910381, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_1_I2C",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  212, .title ="Output rate of the RTCM-3X-TYPE4072_1 (u-blox proprietary: Additional reference station information) message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutRtcm3xType40721Usb =
{
    .id = 0x20910384, .name = "CFG-MSGOUT-RTCM_3X_TYPE4072_1_USB",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  213, .title ="Output rate of the RTCM-3X-TYPE4072_1 (u-blox proprietary: Additional reference station information) message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfAlgUart1 =
{
    .id = 0x20910110, .name = "CFG-MSGOUT-UBX_ESF_ALG_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  214, .title ="Output rate of the UBX-ESF-ALG message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfAlgUart2 =
{
    .id = 0x20910111, .name = "CFG-MSGOUT-UBX_ESF_ALG_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  215, .title ="Output rate of the UBX-ESF-ALG message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfAlgSpi =
{
    .id = 0x20910113, .name = "CFG-MSGOUT-UBX_ESF_ALG_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  216, .title ="Output rate of the UBX-ESF-ALG message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfAlgI2c =
{
    .id = 0x2091010f, .name = "CFG-MSGOUT-UBX_ESF_ALG_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  217, .title ="Output rate of the UBX-ESF-ALG message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfAlgUsb =
{
    .id = 0x20910112, .name = "CFG-MSGOUT-UBX_ESF_ALG_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  218, .title ="Output rate of the UBX-ESF-ALG message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfInsUart1 =
{
    .id = 0x20910115, .name = "CFG-MSGOUT-UBX_ESF_INS_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  219, .title ="Output rate of the UBX-ESF-INS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfInsUart2 =
{
    .id = 0x20910116, .name = "CFG-MSGOUT-UBX_ESF_INS_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  220, .title ="Output rate of the UBX-ESF-INS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfInsSpi =
{
    .id = 0x20910118, .name = "CFG-MSGOUT-UBX_ESF_INS_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  221, .title ="Output rate of the UBX-ESF-INS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfInsI2c =
{
    .id = 0x20910114, .name = "CFG-MSGOUT-UBX_ESF_INS_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  222, .title ="Output rate of the UBX-ESF-INS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfInsUsb =
{
    .id = 0x20910117, .name = "CFG-MSGOUT-UBX_ESF_INS_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  223, .title ="Output rate of the UBX-ESF-INS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfMeasUart1 =
{
    .id = 0x20910278, .name = "CFG-MSGOUT-UBX_ESF_MEAS_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  224, .title ="Output rate of the UBX-ESF-MEAS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfMeasUart2 =
{
    .id = 0x20910279, .name = "CFG-MSGOUT-UBX_ESF_MEAS_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  225, .title ="Output rate of the UBX-ESF-MEAS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfMeasSpi =
{
    .id = 0x2091027b, .name = "CFG-MSGOUT-UBX_ESF_MEAS_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  226, .title ="Output rate of the UBX-ESF-MEAS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfMeasI2c =
{
    .id = 0x20910277, .name = "CFG-MSGOUT-UBX_ESF_MEAS_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  227, .title ="Output rate of the UBX-ESF-MEAS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfMeasUsb =
{
    .id = 0x2091027a, .name = "CFG-MSGOUT-UBX_ESF_MEAS_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  228, .title ="Output rate of the UBX-ESF-MEAS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfRawUart1 =
{
    .id = 0x209102a0, .name = "CFG-MSGOUT-UBX_ESF_RAW_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  229, .title ="Output rate of the UBX-ESF-RAW message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfRawUart2 =
{
    .id = 0x209102a1, .name = "CFG-MSGOUT-UBX_ESF_RAW_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  230, .title ="Output rate of the UBX-ESF-RAW message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfRawSpi =
{
    .id = 0x209102a3, .name = "CFG-MSGOUT-UBX_ESF_RAW_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  231, .title ="Output rate of the UBX-ESF-RAW message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfRawI2c =
{
    .id = 0x2091029f, .name = "CFG-MSGOUT-UBX_ESF_RAW_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  232, .title ="Output rate of the UBX-ESF-RAW message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfRawUsb =
{
    .id = 0x209102a2, .name = "CFG-MSGOUT-UBX_ESF_RAW_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  233, .title ="Output rate of the UBX-ESF-RAW message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfStatusUart1 =
{
    .id = 0x20910106, .name = "CFG-MSGOUT-UBX_ESF_STATUS_UART1",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  234, .title ="Output rate of the UBX-ESF-STATUS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfStatusUart2 =
{
    .id = 0x20910107, .name = "CFG-MSGOUT-UBX_ESF_STATUS_UART2",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  235, .title ="Output rate of the UBX-ESF-STATUS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfStatusSpi =
{
    .id = 0x20910109, .name = "CFG-MSGOUT-UBX_ESF_STATUS_SPI",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  236, .title ="Output rate of the UBX-ESF-STATUS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfStatusI2c =
{
    .id = 0x20910105, .name = "CFG-MSGOUT-UBX_ESF_STATUS_I2C",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  237, .title ="Output rate of the UBX-ESF-STATUS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxEsfStatusUsb =
{
    .id = 0x20910108, .name = "CFG-MSGOUT-UBX_ESF_STATUS_USB",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  238, .title ="Output rate of the UBX-ESF-STATUS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxLogInfoUart1 =
{
    .id = 0x2091025a, .name = "CFG-MSGOUT-UBX_LOG_INFO_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  239, .title ="Output rate of the UBX-LOG-INFO message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxLogInfoUart2 =
{
    .id = 0x2091025b, .name = "CFG-MSGOUT-UBX_LOG_INFO_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  240, .title ="Output rate of the UBX-LOG-INFO message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxLogInfoSpi =
{
    .id = 0x2091025d, .name = "CFG-MSGOUT-UBX_LOG_INFO_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  241, .title ="Output rate of the UBX-LOG-INFO message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxLogInfoI2c =
{
    .id = 0x20910259, .name = "CFG-MSGOUT-UBX_LOG_INFO_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  242, .title ="Output rate of the UBX-LOG-INFO message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxLogInfoUsb =
{
    .id = 0x2091025c, .name = "CFG-MSGOUT-UBX_LOG_INFO_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  243, .title ="Output rate of the UBX-LOG-INFO message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonCommsUart1 =
{
    .id = 0x20910350, .name = "CFG-MSGOUT-UBX_MON_COMMS_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  244, .title ="Output rate of the UBX-MON-COMMS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonCommsUart2 =
{
    .id = 0x20910351, .name = "CFG-MSGOUT-UBX_MON_COMMS_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  245, .title ="Output rate of the UBX-MON-COMMS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonCommsSpi =
{
    .id = 0x20910353, .name = "CFG-MSGOUT-UBX_MON_COMMS_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  246, .title ="Output rate of the UBX-MON-COMMS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonCommsI2c =
{
    .id = 0x2091034f, .name = "CFG-MSGOUT-UBX_MON_COMMS_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  247, .title ="Output rate of the UBX-MON-COMMS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonCommsUsb =
{
    .id = 0x20910352, .name = "CFG-MSGOUT-UBX_MON_COMMS_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  248, .title ="Output rate of the UBX-MON-COMMS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw2Uart1 =
{
    .id = 0x209101ba, .name = "CFG-MSGOUT-UBX_MON_HW2_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  249, .title ="Output rate of the UBX-MON-HW2 message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw2Uart2 =
{
    .id = 0x209101bb, .name = "CFG-MSGOUT-UBX_MON_HW2_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  250, .title ="Output rate of the UBX-MON-HW2 message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw2Spi =
{
    .id = 0x209101bd, .name = "CFG-MSGOUT-UBX_MON_HW2_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  251, .title ="Output rate of the UBX-MON-HW2 message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw2I2c =
{
    .id = 0x209101b9, .name = "CFG-MSGOUT-UBX_MON_HW2_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  252, .title ="Output rate of the UBX-MON-HW2 message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw2Usb =
{
    .id = 0x209101bc, .name = "CFG-MSGOUT-UBX_MON_HW2_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  253, .title ="Output rate of the UBX-MON-HW2 message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw3Uart1 =
{
    .id = 0x20910355, .name = "CFG-MSGOUT-UBX_MON_HW3_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  254, .title ="Output rate of the UBX-MON-HW3 message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw3Uart2 =
{
    .id = 0x20910356, .name = "CFG-MSGOUT-UBX_MON_HW3_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  255, .title ="Output rate of the UBX-MON-HW3 message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw3Spi =
{
    .id = 0x20910358, .name = "CFG-MSGOUT-UBX_MON_HW3_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  256, .title ="Output rate of the UBX-MON-HW3 message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw3I2c =
{
    .id = 0x20910354, .name = "CFG-MSGOUT-UBX_MON_HW3_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  257, .title ="Output rate of the UBX-MON-HW3 message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHw3Usb =
{
    .id = 0x20910357, .name = "CFG-MSGOUT-UBX_MON_HW3_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  258, .title ="Output rate of the UBX-MON-HW3 message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHwUart1 =
{
    .id = 0x209101b5, .name = "CFG-MSGOUT-UBX_MON_HW_UART1",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  259, .title ="Output rate of the UBX-MON-HW message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHwUart2 =
{
    .id = 0x209101b6, .name = "CFG-MSGOUT-UBX_MON_HW_UART2",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  260, .title ="Output rate of the UBX-MON-HW message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHwSpi =
{
    .id = 0x209101b8, .name = "CFG-MSGOUT-UBX_MON_HW_SPI",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  261, .title ="Output rate of the UBX-MON-HW message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHwI2c =
{
    .id = 0x209101b4, .name = "CFG-MSGOUT-UBX_MON_HW_I2C",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  262, .title ="Output rate of the UBX-MON-HW message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonHwUsb =
{
    .id = 0x209101b7, .name = "CFG-MSGOUT-UBX_MON_HW_USB",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  263, .title ="Output rate of the UBX-MON-HW message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonIoUart1 =
{
    .id = 0x209101a6, .name = "CFG-MSGOUT-UBX_MON_IO_UART1",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  264, .title ="Output rate of the UBX-MON-IO message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonIoUart2 =
{
    .id = 0x209101a7, .name = "CFG-MSGOUT-UBX_MON_IO_UART2",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  265, .title ="Output rate of the UBX-MON-IO message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonIoSpi =
{
    .id = 0x209101a9, .name = "CFG-MSGOUT-UBX_MON_IO_SPI",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  266, .title ="Output rate of the UBX-MON-IO message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonIoI2c =
{
    .id = 0x209101a5, .name = "CFG-MSGOUT-UBX_MON_IO_I2C",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  267, .title ="Output rate of the UBX-MON-IO message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonIoUsb =
{
    .id = 0x209101a8, .name = "CFG-MSGOUT-UBX_MON_IO_USB",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  268, .title ="Output rate of the UBX-MON-IO message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonMsgppUart1 =
{
    .id = 0x20910197, .name = "CFG-MSGOUT-UBX_MON_MSGPP_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  269, .title ="Output rate of the UBX-MON-MSGPP message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonMsgppUart2 =
{
    .id = 0x20910198, .name = "CFG-MSGOUT-UBX_MON_MSGPP_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  270, .title ="Output rate of the UBX-MON-MSGPP message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonMsgppSpi =
{
    .id = 0x2091019a, .name = "CFG-MSGOUT-UBX_MON_MSGPP_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  271, .title ="Output rate of the UBX-MON-MSGPP message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonMsgppI2c =
{
    .id = 0x20910196, .name = "CFG-MSGOUT-UBX_MON_MSGPP_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  272, .title ="Output rate of the UBX-MON-MSGPP message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonMsgppUsb =
{
    .id = 0x20910199, .name = "CFG-MSGOUT-UBX_MON_MSGPP_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  273, .title ="Output rate of the UBX-MON-MSGPP message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRfUart1 =
{
    .id = 0x2091035a, .name = "CFG-MSGOUT-UBX_MON_RF_UART1",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  274, .title ="Output rate of the UBX-MON-RF message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRfUart2 =
{
    .id = 0x2091035b, .name = "CFG-MSGOUT-UBX_MON_RF_UART2",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  275, .title ="Output rate of the UBX-MON-RF message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRfSpi =
{
    .id = 0x2091035d, .name = "CFG-MSGOUT-UBX_MON_RF_SPI",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  276, .title ="Output rate of the UBX-MON-RF message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRfI2c =
{
    .id = 0x20910359, .name = "CFG-MSGOUT-UBX_MON_RF_I2C",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  277, .title ="Output rate of the UBX-MON-RF message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRfUsb =
{
    .id = 0x2091035c, .name = "CFG-MSGOUT-UBX_MON_RF_USB",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  278, .title ="Output rate of the UBX-MON-RF message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxbufUart1 =
{
    .id = 0x209101a1, .name = "CFG-MSGOUT-UBX_MON_RXBUF_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  279, .title ="Output rate of the UBX-MON-RXBUF message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxbufUart2 =
{
    .id = 0x209101a2, .name = "CFG-MSGOUT-UBX_MON_RXBUF_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  280, .title ="Output rate of the UBX-MON-RXBUF message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxbufSpi =
{
    .id = 0x209101a4, .name = "CFG-MSGOUT-UBX_MON_RXBUF_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  281, .title ="Output rate of the UBX-MON-RXBUF message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxbufI2c =
{
    .id = 0x209101a0, .name = "CFG-MSGOUT-UBX_MON_RXBUF_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  282, .title ="Output rate of the UBX-MON-RXBUF message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxbufUsb =
{
    .id = 0x209101a3, .name = "CFG-MSGOUT-UBX_MON_RXBUF_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  283, .title ="Output rate of the UBX-MON-RXBUF message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxrUart1 =
{
    .id = 0x20910188, .name = "CFG-MSGOUT-UBX_MON_RXR_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  284, .title ="Output rate of the UBX-MON-RXR message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxrUart2 =
{
    .id = 0x20910189, .name = "CFG-MSGOUT-UBX_MON_RXR_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  285, .title ="Output rate of the UBX-MON-RXR message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxrSpi =
{
    .id = 0x2091018b, .name = "CFG-MSGOUT-UBX_MON_RXR_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  286, .title ="Output rate of the UBX-MON-RXR message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxrI2c =
{
    .id = 0x20910187, .name = "CFG-MSGOUT-UBX_MON_RXR_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  287, .title ="Output rate of the UBX-MON-RXR message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonRxrUsb =
{
    .id = 0x2091018a, .name = "CFG-MSGOUT-UBX_MON_RXR_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  288, .title ="Output rate of the UBX-MON-RXR message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonSpanUart1 =
{
    .id = 0x2091038c, .name = "CFG-MSGOUT-UBX_MON_SPAN_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  289, .title ="Output rate of the UBX-MON-SPAN message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonSpanUart2 =
{
    .id = 0x2091038d, .name = "CFG-MSGOUT-UBX_MON_SPAN_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  290, .title ="Output rate of the UBX-MON-SPAN message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonSpanSpi =
{
    .id = 0x2091038f, .name = "CFG-MSGOUT-UBX_MON_SPAN_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  291, .title ="Output rate of the UBX-MON-SPAN message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonSpanI2c =
{
    .id = 0x2091038b, .name = "CFG-MSGOUT-UBX_MON_SPAN_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  292, .title ="Output rate of the UBX-MON-SPAN message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonSpanUsb =
{
    .id = 0x2091038e, .name = "CFG-MSGOUT-UBX_MON_SPAN_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  293, .title ="Output rate of the UBX-MON-SPAN message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTempUart1 =
{
    .id = 0x20910332, .name = "CFG-MSGOUT-UBX_MON_TEMP_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  294, .title ="Output rate of the UBX-MON-TEMP message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTempUart2 =
{
    .id = 0x20910333, .name = "CFG-MSGOUT-UBX_MON_TEMP_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  295, .title ="Output rate of the UBX-MON-TEMP message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTempSpi =
{
    .id = 0x20910335, .name = "CFG-MSGOUT-UBX_MON_TEMP_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  296, .title ="Output rate of the UBX-MON-TEMP message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTempI2c =
{
    .id = 0x20910331, .name = "CFG-MSGOUT-UBX_MON_TEMP_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  297, .title ="Output rate of the UBX-MON-TEMP message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTempUsb =
{
    .id = 0x20910334, .name = "CFG-MSGOUT-UBX_MON_TEMP_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  298, .title ="Output rate of the UBX-MON-TEMP message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTxbufUart1 =
{
    .id = 0x2091019c, .name = "CFG-MSGOUT-UBX_MON_TXBUF_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  299, .title ="Output rate of the UBX-MON-TXBUF message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTxbufUart2 =
{
    .id = 0x2091019d, .name = "CFG-MSGOUT-UBX_MON_TXBUF_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  300, .title ="Output rate of the UBX-MON-TXBUF message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTxbufSpi =
{
    .id = 0x2091019f, .name = "CFG-MSGOUT-UBX_MON_TXBUF_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  301, .title ="Output rate of the UBX-MON-TXBUF message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTxbufI2c =
{
    .id = 0x2091019b, .name = "CFG-MSGOUT-UBX_MON_TXBUF_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  302, .title ="Output rate of the UBX-MON-TXBUF message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxMonTxbufUsb =
{
    .id = 0x2091019e, .name = "CFG-MSGOUT-UBX_MON_TXBUF_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  303, .title ="Output rate of the UBX-MON-TXBUF message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAopstatusUart1 =
{
    .id = 0x2091007a, .name = "CFG-MSGOUT-UBX_NAV_AOPSTATUS_UART1",              .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  304, .title ="Output rate of the UBX-NAV-AOPSTATUS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAopstatusUart2 =
{
    .id = 0x2091007b, .name = "CFG-MSGOUT-UBX_NAV_AOPSTATUS_UART2",              .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  305, .title ="Output rate of the UBX-NAV-AOPSTATUS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAopstatusSpi =
{
    .id = 0x2091007d, .name = "CFG-MSGOUT-UBX_NAV_AOPSTATUS_SPI",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  306, .title ="Output rate of the UBX-NAV-AOPSTATUS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAopstatusI2c =
{
    .id = 0x20910079, .name = "CFG-MSGOUT-UBX_NAV_AOPSTATUS_I2C",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  307, .title ="Output rate of the UBX-NAV-AOPSTATUS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAopstatusUsb =
{
    .id = 0x2091007c, .name = "CFG-MSGOUT-UBX_NAV_AOPSTATUS_USB",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  308, .title ="Output rate of the UBX-NAV-AOPSTATUS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAttUart1 =
{
    .id = 0x20910020, .name = "CFG-MSGOUT-UBX_NAV_ATT_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  309, .title ="Output rate of the UBX-NAV-ATT message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAttUart2 =
{
    .id = 0x20910021, .name = "CFG-MSGOUT-UBX_NAV_ATT_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  310, .title ="Output rate of the UBX-NAV-ATT message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAttSpi =
{
    .id = 0x20910023, .name = "CFG-MSGOUT-UBX_NAV_ATT_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  311, .title ="Output rate of the UBX-NAV-ATT message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAttI2c =
{
    .id = 0x2091001f, .name = "CFG-MSGOUT-UBX_NAV_ATT_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  312, .title ="Output rate of the UBX-NAV-ATT message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavAttUsb =
{
    .id = 0x20910022, .name = "CFG-MSGOUT-UBX_NAV_ATT_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  313, .title ="Output rate of the UBX-NAV-ATT message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavClockUart1 =
{
    .id = 0x20910066, .name = "CFG-MSGOUT-UBX_NAV_CLOCK_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  314, .title ="Output rate of the UBX-NAV-CLOCK message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavClockUart2 =
{
    .id = 0x20910067, .name = "CFG-MSGOUT-UBX_NAV_CLOCK_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  315, .title ="Output rate of the UBX-NAV-CLOCK message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavClockSpi =
{
    .id = 0x20910069, .name = "CFG-MSGOUT-UBX_NAV_CLOCK_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  316, .title ="Output rate of the UBX-NAV-CLOCK message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavClockI2c =
{
    .id = 0x20910065, .name = "CFG-MSGOUT-UBX_NAV_CLOCK_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  317, .title ="Output rate of the UBX-NAV-CLOCK message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavClockUsb =
{
    .id = 0x20910068, .name = "CFG-MSGOUT-UBX_NAV_CLOCK_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  318, .title ="Output rate of the UBX-NAV-CLOCK message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavCovUart1 =
{
    .id = 0x20910084, .name = "CFG-MSGOUT-UBX_NAV_COV_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  319, .title ="Output rate of the UBX-NAV-COV message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavCovUart2 =
{
    .id = 0x20910085, .name = "CFG-MSGOUT-UBX_NAV_COV_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  320, .title ="Output rate of the UBX-NAV-COV message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavCovSpi =
{
    .id = 0x20910087, .name = "CFG-MSGOUT-UBX_NAV_COV_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  321, .title ="Output rate of the UBX-NAV-COV message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavCovI2c =
{
    .id = 0x20910083, .name = "CFG-MSGOUT-UBX_NAV_COV_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  322, .title ="Output rate of the UBX-NAV-COV message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavCovUsb =
{
    .id = 0x20910086, .name = "CFG-MSGOUT-UBX_NAV_COV_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  323, .title ="Output rate of the UBX-NAV-COV message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavDopUart1 =
{
    .id = 0x20910039, .name = "CFG-MSGOUT-UBX_NAV_DOP_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  324, .title ="Output rate of the UBX-NAV-DOP message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavDopUart2 =
{
    .id = 0x2091003a, .name = "CFG-MSGOUT-UBX_NAV_DOP_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  325, .title ="Output rate of the UBX-NAV-DOP message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavDopSpi =
{
    .id = 0x2091003c, .name = "CFG-MSGOUT-UBX_NAV_DOP_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  326, .title ="Output rate of the UBX-NAV-DOP message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavDopI2c =
{
    .id = 0x20910038, .name = "CFG-MSGOUT-UBX_NAV_DOP_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  327, .title ="Output rate of the UBX-NAV-DOP message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavDopUsb =
{
    .id = 0x2091003b, .name = "CFG-MSGOUT-UBX_NAV_DOP_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  328, .title ="Output rate of the UBX-NAV-DOP message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEellUart1 =
{
    .id = 0x20910314, .name = "CFG-MSGOUT-UBX_NAV_EELL_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  329, .title ="Output rate of the UBX-NAV-EELL message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEellUart2 =
{
    .id = 0x20910315, .name = "CFG-MSGOUT-UBX_NAV_EELL_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  330, .title ="Output rate of the UBX-NAV-EELL message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEellSpi =
{
    .id = 0x20910317, .name = "CFG-MSGOUT-UBX_NAV_EELL_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  331, .title ="Output rate of the UBX-NAV-EELL message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEellUsb =
{
    .id = 0x20910316, .name = "CFG-MSGOUT-UBX_NAV_EELL_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  332, .title ="Output rate of the UBX-NAV-EELL message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEellI2c =
{
    .id = 0x20910313, .name = "CFG-MSGOUT-UBX_NAV_EELL_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  333, .title ="Output rate of the UBX-NAV-EELL message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEoeUart1 =
{
    .id = 0x20910160, .name = "CFG-MSGOUT-UBX_NAV_EOE_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  334, .title ="Output rate of the UBX-NAV-EOE message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEoeUart2 =
{
    .id = 0x20910161, .name = "CFG-MSGOUT-UBX_NAV_EOE_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  335, .title ="Output rate of the UBX-NAV-EOE message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEoeSpi =
{
    .id = 0x20910163, .name = "CFG-MSGOUT-UBX_NAV_EOE_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  336, .title ="Output rate of the UBX-NAV-EOE message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEoeI2c =
{
    .id = 0x2091015f, .name = "CFG-MSGOUT-UBX_NAV_EOE_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  337, .title ="Output rate of the UBX-NAV-EOE message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavEoeUsb =
{
    .id = 0x20910162, .name = "CFG-MSGOUT-UBX_NAV_EOE_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  338, .title ="Output rate of the UBX-NAV-EOE message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavGeofenceUart1 =
{
    .id = 0x209100a2, .name = "CFG-MSGOUT-UBX_NAV_GEOFENCE_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  339, .title ="Output rate of the UBX-NAV-GEOFENCE message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavGeofenceUart2 =
{
    .id = 0x209100a3, .name = "CFG-MSGOUT-UBX_NAV_GEOFENCE_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  340, .title ="Output rate of the UBX-NAV-GEOFENCE message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavGeofenceSpi =
{
    .id = 0x209100a5, .name = "CFG-MSGOUT-UBX_NAV_GEOFENCE_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  341, .title ="Output rate of the UBX-NAV-GEOFENCE message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavGeofenceI2c =
{
    .id = 0x209100a1, .name = "CFG-MSGOUT-UBX_NAV_GEOFENCE_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  342, .title ="Output rate of the UBX-NAV-GEOFENCE message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavGeofenceUsb =
{
    .id = 0x209100a4, .name = "CFG-MSGOUT-UBX_NAV_GEOFENCE_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  343, .title ="Output rate of the UBX-NAV-GEOFENCE message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposecefUart1 =
{
    .id = 0x2091002f, .name = "CFG-MSGOUT-UBX_NAV_HPPOSECEF_UART1",              .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  344, .title ="Output rate of the UBX-NAV-HPPOSECEF message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposecefUart2 =
{
    .id = 0x20910030, .name = "CFG-MSGOUT-UBX_NAV_HPPOSECEF_UART2",              .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  345, .title ="Output rate of the UBX-NAV-HPPOSECEF message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposecefSpi =
{
    .id = 0x20910032, .name = "CFG-MSGOUT-UBX_NAV_HPPOSECEF_SPI",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  346, .title ="Output rate of the UBX-NAV-HPPOSECEF message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposecefI2c =
{
    .id = 0x2091002e, .name = "CFG-MSGOUT-UBX_NAV_HPPOSECEF_I2C",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  347, .title ="Output rate of the UBX-NAV-HPPOSECEF message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposecefUsb =
{
    .id = 0x20910031, .name = "CFG-MSGOUT-UBX_NAV_HPPOSECEF_USB",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  348, .title ="Output rate of the UBX-NAV-HPPOSECEF message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposllhUart1 =
{
    .id = 0x20910034, .name = "CFG-MSGOUT-UBX_NAV_HPPOSLLH_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  349, .title ="Output rate of the UBX-NAV-HPPOSLLH message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposllhUart2 =
{
    .id = 0x20910035, .name = "CFG-MSGOUT-UBX_NAV_HPPOSLLH_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  350, .title ="Output rate of the UBX-NAV-HPPOSLLH message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposllhSpi =
{
    .id = 0x20910037, .name = "CFG-MSGOUT-UBX_NAV_HPPOSLLH_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  351, .title ="Output rate of the UBX-NAV-HPPOSLLH message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposllhI2c =
{
    .id = 0x20910033, .name = "CFG-MSGOUT-UBX_NAV_HPPOSLLH_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  352, .title ="Output rate of the UBX-NAV-HPPOSLLH message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavHpposllhUsb =
{
    .id = 0x20910036, .name = "CFG-MSGOUT-UBX_NAV_HPPOSLLH_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  353, .title ="Output rate of the UBX-NAV-HPPOSLLH message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOdoUart1 =
{
    .id = 0x2091007f, .name = "CFG-MSGOUT-UBX_NAV_ODO_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  354, .title ="Output rate of the UBX-NAV-ODO message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOdoUart2 =
{
    .id = 0x20910080, .name = "CFG-MSGOUT-UBX_NAV_ODO_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  355, .title ="Output rate of the UBX-NAV-ODO message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOdoSpi =
{
    .id = 0x20910082, .name = "CFG-MSGOUT-UBX_NAV_ODO_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  356, .title ="Output rate of the UBX-NAV-ODO message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOdoI2c =
{
    .id = 0x2091007e, .name = "CFG-MSGOUT-UBX_NAV_ODO_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  357, .title ="Output rate of the UBX-NAV-ODO message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOdoUsb =
{
    .id = 0x20910081, .name = "CFG-MSGOUT-UBX_NAV_ODO_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  358, .title ="Output rate of the UBX-NAV-ODO message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOrbUart1 =
{
    .id = 0x20910011, .name = "CFG-MSGOUT-UBX_NAV_ORB_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  359, .title ="Output rate of the UBX-NAV-ORB message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOrbUart2 =
{
    .id = 0x20910012, .name = "CFG-MSGOUT-UBX_NAV_ORB_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  360, .title ="Output rate of the UBX-NAV-ORB message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOrbSpi =
{
    .id = 0x20910014, .name = "CFG-MSGOUT-UBX_NAV_ORB_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  361, .title ="Output rate of the UBX-NAV-ORB message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOrbI2c =
{
    .id = 0x20910010, .name = "CFG-MSGOUT-UBX_NAV_ORB_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  362, .title ="Output rate of the UBX-NAV-ORB message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavOrbUsb =
{
    .id = 0x20910013, .name = "CFG-MSGOUT-UBX_NAV_ORB_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  363, .title ="Output rate of the UBX-NAV-ORB message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosecefUart1 =
{
    .id = 0x20910025, .name = "CFG-MSGOUT-UBX_NAV_POSECEF_UART1",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  364, .title ="Output rate of the UBX-NAV-POSECEF message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosecefUart2 =
{
    .id = 0x20910026, .name = "CFG-MSGOUT-UBX_NAV_POSECEF_UART2",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  365, .title ="Output rate of the UBX-NAV-POSECEF message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosecefSpi =
{
    .id = 0x20910028, .name = "CFG-MSGOUT-UBX_NAV_POSECEF_SPI",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  366, .title ="Output rate of the UBX-NAV-POSECEF message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosecefI2c =
{
    .id = 0x20910024, .name = "CFG-MSGOUT-UBX_NAV_POSECEF_I2C",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  367, .title ="Output rate of the UBX-NAV-POSECEF message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosecefUsb =
{
    .id = 0x20910027, .name = "CFG-MSGOUT-UBX_NAV_POSECEF_USB",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  368, .title ="Output rate of the UBX-NAV-POSECEF message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosllhUart1 =
{
    .id = 0x2091002a, .name = "CFG-MSGOUT-UBX_NAV_POSLLH_UART1",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  369, .title ="Output rate of the UBX-NAV-POSLLH message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosllhUart2 =
{
    .id = 0x2091002b, .name = "CFG-MSGOUT-UBX_NAV_POSLLH_UART2",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  370, .title ="Output rate of the UBX-NAV-POSLLH message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosllhSpi =
{
    .id = 0x2091002d, .name = "CFG-MSGOUT-UBX_NAV_POSLLH_SPI",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  371, .title ="Output rate of the UBX-NAV-POSLLH message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosllhI2c =
{
    .id = 0x20910029, .name = "CFG-MSGOUT-UBX_NAV_POSLLH_I2C",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  372, .title ="Output rate of the UBX-NAV-POSLLH message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPosllhUsb =
{
    .id = 0x2091002c, .name = "CFG-MSGOUT-UBX_NAV_POSLLH_USB",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  373, .title ="Output rate of the UBX-NAV-POSLLH message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPvtUart1 =
{
    .id = 0x20910007, .name = "CFG-MSGOUT-UBX_NAV_PVT_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  374, .title ="Output rate of the UBX-NAV-PVT message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPvtUart2 =
{
    .id = 0x20910008, .name = "CFG-MSGOUT-UBX_NAV_PVT_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  375, .title ="Output rate of the UBX-NAV-PVT message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPvtSpi =
{
    .id = 0x2091000a, .name = "CFG-MSGOUT-UBX_NAV_PVT_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  376, .title ="Output rate of the UBX-NAV-PVT message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPvtI2c =
{
    .id = 0x20910006, .name = "CFG-MSGOUT-UBX_NAV_PVT_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  377, .title ="Output rate of the UBX-NAV-PVT message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavPvtUsb =
{
    .id = 0x20910009, .name = "CFG-MSGOUT-UBX_NAV_PVT_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  378, .title ="Output rate of the UBX-NAV-PVT message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavRelposnedUart1 =
{
    .id = 0x2091008e, .name = "CFG-MSGOUT-UBX_NAV_RELPOSNED_UART1",              .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  379, .title ="Output rate of the UBX-NAV-RELPOSNED message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavRelposnedUart2 =
{
    .id = 0x2091008f, .name = "CFG-MSGOUT-UBX_NAV_RELPOSNED_UART2",              .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  380, .title ="Output rate of the UBX-NAV-RELPOSNED message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavRelposnedSpi =
{
    .id = 0x20910091, .name = "CFG-MSGOUT-UBX_NAV_RELPOSNED_SPI",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  381, .title ="Output rate of the UBX-NAV-RELPOSNED message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavRelposnedI2c =
{
    .id = 0x2091008d, .name = "CFG-MSGOUT-UBX_NAV_RELPOSNED_I2C",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  382, .title ="Output rate of the UBX-NAV-RELPOSNED message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavRelposnedUsb =
{
    .id = 0x20910090, .name = "CFG-MSGOUT-UBX_NAV_RELPOSNED_USB",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  383, .title ="Output rate of the UBX-NAV-RELPOSNED message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSatUart1 =
{
    .id = 0x20910016, .name = "CFG-MSGOUT-UBX_NAV_SAT_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  384, .title ="Output rate of the UBX-NAV-SAT message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSatUart2 =
{
    .id = 0x20910017, .name = "CFG-MSGOUT-UBX_NAV_SAT_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  385, .title ="Output rate of the UBX-NAV-SAT message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSatSpi =
{
    .id = 0x20910019, .name = "CFG-MSGOUT-UBX_NAV_SAT_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  386, .title ="Output rate of the UBX-NAV-SAT message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSatI2c =
{
    .id = 0x20910015, .name = "CFG-MSGOUT-UBX_NAV_SAT_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  387, .title ="Output rate of the UBX-NAV-SAT message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSatUsb =
{
    .id = 0x20910018, .name = "CFG-MSGOUT-UBX_NAV_SAT_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  388, .title ="Output rate of the UBX-NAV-SAT message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSbasUart1 =
{
    .id = 0x2091006b, .name = "CFG-MSGOUT-UBX_NAV_SBAS_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  389, .title ="Output rate of the UBX-NAV-SBAS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSbasUart2 =
{
    .id = 0x2091006c, .name = "CFG-MSGOUT-UBX_NAV_SBAS_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  390, .title ="Output rate of the UBX-NAV-SBAS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSbasSpi =
{
    .id = 0x2091006e, .name = "CFG-MSGOUT-UBX_NAV_SBAS_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  391, .title ="Output rate of the UBX-NAV-SBAS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSbasI2c =
{
    .id = 0x2091006a, .name = "CFG-MSGOUT-UBX_NAV_SBAS_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  392, .title ="Output rate of the UBX-NAV-SBAS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSbasUsb =
{
    .id = 0x2091006d, .name = "CFG-MSGOUT-UBX_NAV_SBAS_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  393, .title ="Output rate of the UBX-NAV-SBAS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSigUart1 =
{
    .id = 0x20910346, .name = "CFG-MSGOUT-UBX_NAV_SIG_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  394, .title ="Output rate of the UBX-NAV-SIG message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSigUart2 =
{
    .id = 0x20910347, .name = "CFG-MSGOUT-UBX_NAV_SIG_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  395, .title ="Output rate of the UBX-NAV-SIG message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSigSpi =
{
    .id = 0x20910349, .name = "CFG-MSGOUT-UBX_NAV_SIG_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  396, .title ="Output rate of the UBX-NAV-SIG message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSigI2c =
{
    .id = 0x20910345, .name = "CFG-MSGOUT-UBX_NAV_SIG_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  397, .title ="Output rate of the UBX-NAV-SIG message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSigUsb =
{
    .id = 0x20910348, .name = "CFG-MSGOUT-UBX_NAV_SIG_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  398, .title ="Output rate of the UBX-NAV-SIG message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSlasUart1 =
{
    .id = 0x20910337, .name = "CFG-MSGOUT-UBX_NAV_SLAS_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  399, .title ="Output rate of the UBX-NAV-SLAS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSlasUart2 =
{
    .id = 0x20910338, .name = "CFG-MSGOUT-UBX_NAV_SLAS_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  400, .title ="Output rate of the UBX-NAV-SLAS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSlasSpi =
{
    .id = 0x2091033a, .name = "CFG-MSGOUT-UBX_NAV_SLAS_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  401, .title ="Output rate of the UBX-NAV-SLAS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSlasI2c =
{
    .id = 0x20910336, .name = "CFG-MSGOUT-UBX_NAV_SLAS_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  402, .title ="Output rate of the UBX-NAV-SLAS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSlasUsb =
{
    .id = 0x20910339, .name = "CFG-MSGOUT-UBX_NAV_SLAS_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  403, .title ="Output rate of the UBX-NAV-SLAS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavStatusUart1 =
{
    .id = 0x2091001b, .name = "CFG-MSGOUT-UBX_NAV_STATUS_UART1",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  404, .title ="Output rate of the UBX-NAV-STATUS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavStatusUart2 =
{
    .id = 0x2091001c, .name = "CFG-MSGOUT-UBX_NAV_STATUS_UART2",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  405, .title ="Output rate of the UBX-NAV-STATUS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavStatusSpi =
{
    .id = 0x2091001e, .name = "CFG-MSGOUT-UBX_NAV_STATUS_SPI",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  406, .title ="Output rate of the UBX-NAV-STATUS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavStatusI2c =
{
    .id = 0x2091001a, .name = "CFG-MSGOUT-UBX_NAV_STATUS_I2C",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  407, .title ="Output rate of the UBX-NAV-STATUS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavStatusUsb =
{
    .id = 0x2091001d, .name = "CFG-MSGOUT-UBX_NAV_STATUS_USB",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  408, .title ="Output rate of the UBX-NAV-STATUS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSvinUart1 =
{
    .id = 0x20910089, .name = "CFG-MSGOUT-UBX_NAV_SVIN_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  409, .title ="Output rate of the UBX-NAV-SVIN message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSvinUart2 =
{
    .id = 0x2091008a, .name = "CFG-MSGOUT-UBX_NAV_SVIN_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  410, .title ="Output rate of the UBX-NAV-SVIN message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSvinSpi =
{
    .id = 0x2091008c, .name = "CFG-MSGOUT-UBX_NAV_SVIN_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  411, .title ="Output rate of the UBX-NAV-SVIN message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSvinI2c =
{
    .id = 0x20910088, .name = "CFG-MSGOUT-UBX_NAV_SVIN_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  412, .title ="Output rate of the UBX-NAV-SVIN message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavSvinUsb =
{
    .id = 0x2091008b, .name = "CFG-MSGOUT-UBX_NAV_SVIN_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  413, .title ="Output rate of the UBX-NAV-SVIN message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimebdsUart1 =
{
    .id = 0x20910052, .name = "CFG-MSGOUT-UBX_NAV_TIMEBDS_UART1",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  414, .title ="Output rate of the UBX-NAV-TIMEBDS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimebdsUart2 =
{
    .id = 0x20910053, .name = "CFG-MSGOUT-UBX_NAV_TIMEBDS_UART2",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  415, .title ="Output rate of the UBX-NAV-TIMEBDS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimebdsSpi =
{
    .id = 0x20910055, .name = "CFG-MSGOUT-UBX_NAV_TIMEBDS_SPI",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  416, .title ="Output rate of the UBX-NAV-TIMEBDS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimebdsI2c =
{
    .id = 0x20910051, .name = "CFG-MSGOUT-UBX_NAV_TIMEBDS_I2C",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  417, .title ="Output rate of the UBX-NAV-TIMEBDS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimebdsUsb =
{
    .id = 0x20910054, .name = "CFG-MSGOUT-UBX_NAV_TIMEBDS_USB",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  418, .title ="Output rate of the UBX-NAV-TIMEBDS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegalUart1 =
{
    .id = 0x20910057, .name = "CFG-MSGOUT-UBX_NAV_TIMEGAL_UART1",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  419, .title ="Output rate of the UBX-NAV-TIMEGAL message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegalUart2 =
{
    .id = 0x20910058, .name = "CFG-MSGOUT-UBX_NAV_TIMEGAL_UART2",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  420, .title ="Output rate of the UBX-NAV-TIMEGAL message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegalSpi =
{
    .id = 0x2091005a, .name = "CFG-MSGOUT-UBX_NAV_TIMEGAL_SPI",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  421, .title ="Output rate of the UBX-NAV-TIMEGAL message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegalI2c =
{
    .id = 0x20910056, .name = "CFG-MSGOUT-UBX_NAV_TIMEGAL_I2C",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  422, .title ="Output rate of the UBX-NAV-TIMEGAL message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegalUsb =
{
    .id = 0x20910059, .name = "CFG-MSGOUT-UBX_NAV_TIMEGAL_USB",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  423, .title ="Output rate of the UBX-NAV-TIMEGAL message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegloUart1 =
{
    .id = 0x2091004d, .name = "CFG-MSGOUT-UBX_NAV_TIMEGLO_UART1",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  424, .title ="Output rate of the UBX-NAV-TIMEGLO message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegloUart2 =
{
    .id = 0x2091004e, .name = "CFG-MSGOUT-UBX_NAV_TIMEGLO_UART2",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  425, .title ="Output rate of the UBX-NAV-TIMEGLO message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegloSpi =
{
    .id = 0x20910050, .name = "CFG-MSGOUT-UBX_NAV_TIMEGLO_SPI",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  426, .title ="Output rate of the UBX-NAV-TIMEGLO message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegloI2c =
{
    .id = 0x2091004c, .name = "CFG-MSGOUT-UBX_NAV_TIMEGLO_I2C",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  427, .title ="Output rate of the UBX-NAV-TIMEGLO message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegloUsb =
{
    .id = 0x2091004f, .name = "CFG-MSGOUT-UBX_NAV_TIMEGLO_USB",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  428, .title ="Output rate of the UBX-NAV-TIMEGLO message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegpsUart1 =
{
    .id = 0x20910048, .name = "CFG-MSGOUT-UBX_NAV_TIMEGPS_UART1",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  429, .title ="Output rate of the UBX-NAV-TIMEGPS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegpsUart2 =
{
    .id = 0x20910049, .name = "CFG-MSGOUT-UBX_NAV_TIMEGPS_UART2",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  430, .title ="Output rate of the UBX-NAV-TIMEGPS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegpsSpi =
{
    .id = 0x2091004b, .name = "CFG-MSGOUT-UBX_NAV_TIMEGPS_SPI",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  431, .title ="Output rate of the UBX-NAV-TIMEGPS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegpsI2c =
{
    .id = 0x20910047, .name = "CFG-MSGOUT-UBX_NAV_TIMEGPS_I2C",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  432, .title ="Output rate of the UBX-NAV-TIMEGPS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimegpsUsb =
{
    .id = 0x2091004a, .name = "CFG-MSGOUT-UBX_NAV_TIMEGPS_USB",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  433, .title ="Output rate of the UBX-NAV-TIMEGPS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimelsUart1 =
{
    .id = 0x20910061, .name = "CFG-MSGOUT-UBX_NAV_TIMELS_UART1",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  434, .title ="Output rate of the UBX-NAV-TIMELS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimelsUart2 =
{
    .id = 0x20910062, .name = "CFG-MSGOUT-UBX_NAV_TIMELS_UART2",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  435, .title ="Output rate of the UBX-NAV-TIMELS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimelsSpi =
{
    .id = 0x20910064, .name = "CFG-MSGOUT-UBX_NAV_TIMELS_SPI",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  436, .title ="Output rate of the UBX-NAV-TIMELS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimelsI2c =
{
    .id = 0x20910060, .name = "CFG-MSGOUT-UBX_NAV_TIMELS_I2C",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  437, .title ="Output rate of the UBX-NAV-TIMELS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimelsUsb =
{
    .id = 0x20910063, .name = "CFG-MSGOUT-UBX_NAV_TIMELS_USB",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  438, .title ="Output rate of the UBX-NAV-TIMELS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeqzssUart1 =
{
    .id = 0x20910387, .name = "CFG-MSGOUT-UBX_NAV_TIMEQZSS_UART1",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  439, .title ="Output rate of the UBX-NAV-TIMEQZSS message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeqzssUart2 =
{
    .id = 0x20910388, .name = "CFG-MSGOUT-UBX_NAV_TIMEQZSS_UART2",               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  440, .title ="Output rate of the UBX-NAV-TIMEQZSS message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeqzssSpi =
{
    .id = 0x2091038a, .name = "CFG-MSGOUT-UBX_NAV_TIMEQZSS_SPI",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  441, .title ="Output rate of the UBX-NAV-TIMEQZSS message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeqzssI2c =
{
    .id = 0x20910386, .name = "CFG-MSGOUT-UBX_NAV_TIMEQZSS_I2C",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  442, .title ="Output rate of the UBX-NAV-TIMEQZSS message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeqzssUsb =
{
    .id = 0x20910389, .name = "CFG-MSGOUT-UBX_NAV_TIMEQZSS_USB",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  443, .title ="Output rate of the UBX-NAV-TIMEQZSS message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeutcUart1 =
{
    .id = 0x2091005c, .name = "CFG-MSGOUT-UBX_NAV_TIMEUTC_UART1",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  444, .title ="Output rate of the UBX-NAV-TIMEUTC message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeutcUart2 =
{
    .id = 0x2091005d, .name = "CFG-MSGOUT-UBX_NAV_TIMEUTC_UART2",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  445, .title ="Output rate of the UBX-NAV-TIMEUTC message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeutcSpi =
{
    .id = 0x2091005f, .name = "CFG-MSGOUT-UBX_NAV_TIMEUTC_SPI",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  446, .title ="Output rate of the UBX-NAV-TIMEUTC message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeutcI2c =
{
    .id = 0x2091005b, .name = "CFG-MSGOUT-UBX_NAV_TIMEUTC_I2C",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  447, .title ="Output rate of the UBX-NAV-TIMEUTC message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavTimeutcUsb =
{
    .id = 0x2091005e, .name = "CFG-MSGOUT-UBX_NAV_TIMEUTC_USB",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  448, .title ="Output rate of the UBX-NAV-TIMEUTC message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelecefUart1 =
{
    .id = 0x2091003e, .name = "CFG-MSGOUT-UBX_NAV_VELECEF_UART1",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  449, .title ="Output rate of the UBX-NAV-VELECEF message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelecefUart2 =
{
    .id = 0x2091003f, .name = "CFG-MSGOUT-UBX_NAV_VELECEF_UART2",                .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  450, .title ="Output rate of the UBX-NAV-VELECEF message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelecefSpi =
{
    .id = 0x20910041, .name = "CFG-MSGOUT-UBX_NAV_VELECEF_SPI",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  451, .title ="Output rate of the UBX-NAV-VELECEF message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelecefI2c =
{
    .id = 0x2091003d, .name = "CFG-MSGOUT-UBX_NAV_VELECEF_I2C",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  452, .title ="Output rate of the UBX-NAV-VELECEF message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelecefUsb =
{
    .id = 0x20910040, .name = "CFG-MSGOUT-UBX_NAV_VELECEF_USB",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  453, .title ="Output rate of the UBX-NAV-VELECEF message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelnedUart1 =
{
    .id = 0x20910043, .name = "CFG-MSGOUT-UBX_NAV_VELNED_UART1",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  454, .title ="Output rate of the UBX-NAV-VELNED message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelnedUart2 =
{
    .id = 0x20910044, .name = "CFG-MSGOUT-UBX_NAV_VELNED_UART2",                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  455, .title ="Output rate of the UBX-NAV-VELNED message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelnedSpi =
{
    .id = 0x20910046, .name = "CFG-MSGOUT-UBX_NAV_VELNED_SPI",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  456, .title ="Output rate of the UBX-NAV-VELNED message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelnedI2c =
{
    .id = 0x20910042, .name = "CFG-MSGOUT-UBX_NAV_VELNED_I2C",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  457, .title ="Output rate of the UBX-NAV-VELNED message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxNavVelnedUsb =
{
    .id = 0x20910045, .name = "CFG-MSGOUT-UBX_NAV_VELNED_USB",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  458, .title ="Output rate of the UBX-NAV-VELNED message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmMeasxUart1 =
{
    .id = 0x20910205, .name = "CFG-MSGOUT-UBX_RXM_MEASX_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  459, .title ="Output rate of the UBX-RXM-MEASX message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmMeasxUart2 =
{
    .id = 0x20910206, .name = "CFG-MSGOUT-UBX_RXM_MEASX_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  460, .title ="Output rate of the UBX-RXM-MEASX message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmMeasxSpi =
{
    .id = 0x20910208, .name = "CFG-MSGOUT-UBX_RXM_MEASX_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  461, .title ="Output rate of the UBX-RXM-MEASX message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmMeasxI2c =
{
    .id = 0x20910204, .name = "CFG-MSGOUT-UBX_RXM_MEASX_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  462, .title ="Output rate of the UBX-RXM-MEASX message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmMeasxUsb =
{
    .id = 0x20910207, .name = "CFG-MSGOUT-UBX_RXM_MEASX_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  463, .title ="Output rate of the UBX-RXM-MEASX message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRawxUart1 =
{
    .id = 0x209102a5, .name = "CFG-MSGOUT-UBX_RXM_RAWX_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  464, .title ="Output rate of the UBX-RXM-RAWX message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRawxUart2 =
{
    .id = 0x209102a6, .name = "CFG-MSGOUT-UBX_RXM_RAWX_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  465, .title ="Output rate of the UBX-RXM-RAWX message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRawxSpi =
{
    .id = 0x209102a8, .name = "CFG-MSGOUT-UBX_RXM_RAWX_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  466, .title ="Output rate of the UBX-RXM-RAWX message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRawxI2c =
{
    .id = 0x209102a4, .name = "CFG-MSGOUT-UBX_RXM_RAWX_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  467, .title ="Output rate of the UBX-RXM-RAWX message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRawxUsb =
{
    .id = 0x209102a7, .name = "CFG-MSGOUT-UBX_RXM_RAWX_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  468, .title ="Output rate of the UBX-RXM-RAWX message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRlmUart1 =
{
    .id = 0x2091025f, .name = "CFG-MSGOUT-UBX_RXM_RLM_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  469, .title ="Output rate of the UBX-RXM-RLM message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRlmUart2 =
{
    .id = 0x20910260, .name = "CFG-MSGOUT-UBX_RXM_RLM_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  470, .title ="Output rate of the UBX-RXM-RLM message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRlmSpi =
{
    .id = 0x20910262, .name = "CFG-MSGOUT-UBX_RXM_RLM_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  471, .title ="Output rate of the UBX-RXM-RLM message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRlmI2c =
{
    .id = 0x2091025e, .name = "CFG-MSGOUT-UBX_RXM_RLM_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  472, .title ="Output rate of the UBX-RXM-RLM message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRlmUsb =
{
    .id = 0x20910261, .name = "CFG-MSGOUT-UBX_RXM_RLM_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  473, .title ="Output rate of the UBX-RXM-RLM message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRtcmUart1 =
{
    .id = 0x20910269, .name = "CFG-MSGOUT-UBX_RXM_RTCM_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  474, .title ="Output rate of the UBX-RXM-RTCM message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRtcmUart2 =
{
    .id = 0x2091026a, .name = "CFG-MSGOUT-UBX_RXM_RTCM_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  475, .title ="Output rate of the UBX-RXM-RTCM message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRtcmSpi =
{
    .id = 0x2091026c, .name = "CFG-MSGOUT-UBX_RXM_RTCM_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  476, .title ="Output rate of the UBX-RXM-RTCM message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRtcmI2c =
{
    .id = 0x20910268, .name = "CFG-MSGOUT-UBX_RXM_RTCM_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  477, .title ="Output rate of the UBX-RXM-RTCM message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmRtcmUsb =
{
    .id = 0x2091026b, .name = "CFG-MSGOUT-UBX_RXM_RTCM_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  478, .title ="Output rate of the UBX-RXM-RTCM message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmSfrbxUart1 =
{
    .id = 0x20910232, .name = "CFG-MSGOUT-UBX_RXM_SFRBX_UART1",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  479, .title ="Output rate of the UBX-RXM-SFRBX message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmSfrbxUart2 =
{
    .id = 0x20910233, .name = "CFG-MSGOUT-UBX_RXM_SFRBX_UART2",                  .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  480, .title ="Output rate of the UBX-RXM-SFRBX message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmSfrbxSpi =
{
    .id = 0x20910235, .name = "CFG-MSGOUT-UBX_RXM_SFRBX_SPI",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  481, .title ="Output rate of the UBX-RXM-SFRBX message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmSfrbxI2c =
{
    .id = 0x20910231, .name = "CFG-MSGOUT-UBX_RXM_SFRBX_I2C",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  482, .title ="Output rate of the UBX-RXM-SFRBX message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxRxmSfrbxUsb =
{
    .id = 0x20910234, .name = "CFG-MSGOUT-UBX_RXM_SFRBX_USB",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  483, .title ="Output rate of the UBX-RXM-SFRBX message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTm2Uart1 =
{
    .id = 0x20910179, .name = "CFG-MSGOUT-UBX_TIM_TM2_UART1",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  484, .title ="Output rate of the UBX-TIM-TM2 message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTm2Uart2 =
{
    .id = 0x2091017a, .name = "CFG-MSGOUT-UBX_TIM_TM2_UART2",                    .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  485, .title ="Output rate of the UBX-TIM-TM2 message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTm2Spi =
{
    .id = 0x2091017c, .name = "CFG-MSGOUT-UBX_TIM_TM2_SPI",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  486, .title ="Output rate of the UBX-TIM-TM2 message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTm2I2c =
{
    .id = 0x20910178, .name = "CFG-MSGOUT-UBX_TIM_TM2_I2C",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  487, .title ="Output rate of the UBX-TIM-TM2 message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTm2Usb =
{
    .id = 0x2091017b, .name = "CFG-MSGOUT-UBX_TIM_TM2_USB",                      .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  488, .title ="Output rate of the UBX-TIM-TM2 message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTpUart1 =
{
    .id = 0x2091017e, .name = "CFG-MSGOUT-UBX_TIM_TP_UART1",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  489, .title ="Output rate of the UBX-TIM-TP message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTpUart2 =
{
    .id = 0x2091017f, .name = "CFG-MSGOUT-UBX_TIM_TP_UART2",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  490, .title ="Output rate of the UBX-TIM-TP message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTpSpi =
{
    .id = 0x20910181, .name = "CFG-MSGOUT-UBX_TIM_TP_SPI",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  491, .title ="Output rate of the UBX-TIM-TP message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTpI2c =
{
    .id = 0x2091017d, .name = "CFG-MSGOUT-UBX_TIM_TP_I2C",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  492, .title ="Output rate of the UBX-TIM-TP message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimTpUsb =
{
    .id = 0x20910180, .name = "CFG-MSGOUT-UBX_TIM_TP_USB",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  493, .title ="Output rate of the UBX-TIM-TP message on port USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimVrfyUart1 =
{
    .id = 0x20910093, .name = "CFG-MSGOUT-UBX_TIM_VRFY_UART1",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  494, .title ="Output rate of the UBX-TIM-VRFY message on port UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimVrfyUart2 =
{
    .id = 0x20910094, .name = "CFG-MSGOUT-UBX_TIM_VRFY_UART2",                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  495, .title ="Output rate of the UBX-TIM-VRFY message on port UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimVrfySpi =
{
    .id = 0x20910096, .name = "CFG-MSGOUT-UBX_TIM_VRFY_SPI",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  496, .title ="Output rate of the UBX-TIM-VRFY message on port SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimVrfyI2c =
{
    .id = 0x20910092, .name = "CFG-MSGOUT-UBX_TIM_VRFY_I2C",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  497, .title ="Output rate of the UBX-TIM-VRFY message on port I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgMsgoutUbxTimVrfyUsb =
{
    .id = 0x20910095, .name = "CFG-MSGOUT-UBX_TIM_VRFY_USB",                     .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  498, .title ="Output rate of the UBX-TIM-VRFY message on port USB"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNavhpgDgnssmode_consts[2] =
{
    {
        .name = "RTK_FLOAT",         .value = "2",                 .val = { .E = 2 },
        .title = "No attempts made to fix ambiguities"
    },
    {
        .name = "RTK_FIXED",         .value = "3",                 .val = { .E = 3 },
        .title = "Ambiguities are fixed whenever possible"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavhpgDgnssmode =
{
    .id = 0x20140011, .name = "CFG-NAVHPG-DGNSSMODE",                            .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  499, .title ="Differential corrections mode",
    .nConsts =   2, .consts = ubloxcfg_cfgNavhpgDgnssmode_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNavspgFixmode_consts[3] =
{
    {
        .name = "2DONLY",            .value = "1",                 .val = { .E = 1 },
        .title = "2D only"
    },
    {
        .name = "3DONLY",            .value = "2",                 .val = { .E = 2 },
        .title = "3D only"
    },
    {
        .name = "AUTO",              .value = "3",                 .val = { .E = 3 },
        .title = "Auto 2D/3D"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgFixmode =
{
    .id = 0x20110011, .name = "CFG-NAVSPG-FIXMODE",                              .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  500, .title ="Position fix mode",
    .nConsts =   3, .consts = ubloxcfg_cfgNavspgFixmode_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgInifix3d =
{
    .id = 0x10110013, .name = "CFG-NAVSPG-INIFIX3D",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  501, .title ="Initial fix must be a 3D fix"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgWknrollover =
{
    .id = 0x30110017, .name = "CFG-NAVSPG-WKNROLLOVER",                          .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  502, .title ="GPS week rollover number"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsePpp =
{
    .id = 0x10110019, .name = "CFG-NAVSPG-USE_PPP",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  503, .title ="Use precise point positioning (PPP)"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNavspgUtcstandard_consts[5] =
{
    {
        .name = "AUTO",              .value = "0",                 .val = { .E = 0 },
        .title = "Automatic; receiver selects based on GNSS configuration"
    },
    {
        .name = "USNO",              .value = "3",                 .val = { .E = 3 },
        .title = "UTC as operated by the U.S. Naval Observatory (USNO); derived from GPS time"
    },
    {
        .name = "EU",                .value = "5",                 .val = { .E = 5 },
        .title = "UTC as combined from multiple European laboratories; derived from Galileo time"
    },
    {
        .name = "SU",                .value = "6",                 .val = { .E = 6 },
        .title = "UTC as operated by the former Soviet Union (SU); derived from GLONASS time"
    },
    {
        .name = "NTSC",              .value = "7",                 .val = { .E = 7 },
        .title = "UTC as operated by the National Time Service Center (NTSC), China; derived from BeiDou time"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUtcstandard =
{
    .id = 0x2011001c, .name = "CFG-NAVSPG-UTCSTANDARD",                          .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  504, .title ="UTC standard to be used",
    .nConsts =   5, .consts = ubloxcfg_cfgNavspgUtcstandard_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNavspgDynmodel_consts[9] =
{
    {
        .name = "PORT",              .value = "0",                 .val = { .E = 0 },
        .title = "Portable"
    },
    {
        .name = "STAT",              .value = "2",                 .val = { .E = 2 },
        .title = "Stationary"
    },
    {
        .name = "PED",               .value = "3",                 .val = { .E = 3 },
        .title = "Pedestrian"
    },
    {
        .name = "AUTOMOT",           .value = "4",                 .val = { .E = 4 },
        .title = "Automotive"
    },
    {
        .name = "SEA",               .value = "5",                 .val = { .E = 5 },
        .title = "Sea"
    },
    {
        .name = "AIR1",              .value = "6",                 .val = { .E = 6 },
        .title = "Airborne with <1g acceleration"
    },
    {
        .name = "AIR2",              .value = "7",                 .val = { .E = 7 },
        .title = "Airborne with <2g acceleration"
    },
    {
        .name = "AIR4",              .value = "8",                 .val = { .E = 8 },
        .title = "Airborne with <4g acceleration"
    },
    {
        .name = "WRIST",             .value = "9",                 .val = { .E = 9 },
        .title = "Wrist-worn watch (not available in all products)"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgDynmodel =
{
    .id = 0x20110021, .name = "CFG-NAVSPG-DYNMODEL",                             .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  505, .title ="Dynamic platform model",
    .nConsts =   9, .consts = ubloxcfg_cfgNavspgDynmodel_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgAckaiding =
{
    .id = 0x10110025, .name = "CFG-NAVSPG-ACKAIDING",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  506, .title ="Acknowledge assistance input messages"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUseUsrdat =
{
    .id = 0x10110061, .name = "CFG-NAVSPG-USE_USRDAT",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  507, .title ="Use user geodetic datum parameters"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsrdatMaja =
{
    .id = 0x50110062, .name = "CFG-NAVSPG-USRDAT_MAJA",                          .type = UBLOXCFG_TYPE_R8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  508, .title ="Geodetic datum semi-major axis",
        .unit = "m"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsrdatFlat =
{
    .id = 0x50110063, .name = "CFG-NAVSPG-USRDAT_FLAT",                          .type = UBLOXCFG_TYPE_R8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  509, .title ="Geodetic datum 1.0 / flattening"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsrdatDx =
{
    .id = 0x40110064, .name = "CFG-NAVSPG-USRDAT_DX",                            .type = UBLOXCFG_TYPE_R4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  510, .title ="Geodetic datum X axis shift at the origin",
        .unit = "m"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsrdatDy =
{
    .id = 0x40110065, .name = "CFG-NAVSPG-USRDAT_DY",                            .type = UBLOXCFG_TYPE_R4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  511, .title ="Geodetic datum Y axis shift at the origin",
        .unit = "m"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsrdatDz =
{
    .id = 0x40110066, .name = "CFG-NAVSPG-USRDAT_DZ",                            .type = UBLOXCFG_TYPE_R4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  512, .title ="Geodetic datum Z axis shift at the origin",
        .unit = "m"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsrdatRotx =
{
    .id = 0x40110067, .name = "CFG-NAVSPG-USRDAT_ROTX",                          .type = UBLOXCFG_TYPE_R4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  513, .title ="Geodetic datum rotation about the X axis",
        .unit = "arcsec"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsrdatRoty =
{
    .id = 0x40110068, .name = "CFG-NAVSPG-USRDAT_ROTY",                          .type = UBLOXCFG_TYPE_R4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  514, .title ="Geodetic datum rotation about the Y axis ()",
        .unit = "arcsec"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsrdatRotz =
{
    .id = 0x40110069, .name = "CFG-NAVSPG-USRDAT_ROTZ",                          .type = UBLOXCFG_TYPE_R4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  515, .title ="Geodetic datum rotation about the Z axis",
        .unit = "arcsec"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgUsrdatScale =
{
    .id = 0x4011006a, .name = "CFG-NAVSPG-USRDAT_SCALE",                         .type = UBLOXCFG_TYPE_R4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  516, .title ="Geodetic datum scale factor",
        .unit = "ppm"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgInfilMinsvs =
{
    .id = 0x201100a1, .name = "CFG-NAVSPG-INFIL_MINSVS",                         .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  517, .title ="Minimum number of satellites for navigation"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgInfilMaxsvs =
{
    .id = 0x201100a2, .name = "CFG-NAVSPG-INFIL_MAXSVS",                         .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  518, .title ="Maximum number of satellites for navigation"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgInfilMincno =
{
    .id = 0x201100a3, .name = "CFG-NAVSPG-INFIL_MINCNO",                         .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  519, .title ="Minimum satellite signal level for navigation",
        .unit = "dBHz"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgInfilMinelev =
{
    .id = 0x201100a4, .name = "CFG-NAVSPG-INFIL_MINELEV",                        .type = UBLOXCFG_TYPE_I1, .size = UBLOXCFG_SIZE_ONE,
    .order =  520, .title ="Minimum elevation for a GNSS satellite to be used in navigation",
        .unit = "deg"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgInfilNcnothrs =
{
    .id = 0x201100aa, .name = "CFG-NAVSPG-INFIL_NCNOTHRS",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  521, .title ="Number of satellites required to have C/N0 above CFG-NAVSPG-INFIL_CNOTHRS for a fix to be attempted"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgInfilCnothrs =
{
    .id = 0x201100ab, .name = "CFG-NAVSPG-INFIL_CNOTHRS",                        .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  522, .title ="C/N0 threshold for deciding whether to attempt a fix"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgOutfilPdop =
{
    .id = 0x301100b1, .name = "CFG-NAVSPG-OUTFIL_PDOP",                          .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  523, .title ="Output filter position DOP mask (threshold)",
                            .scale = "0.1",     .scalefact = +0x1.999999999999ap-4 /* = 1.00000000000000005551e-01 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgOutfilTdop =
{
    .id = 0x301100b2, .name = "CFG-NAVSPG-OUTFIL_TDOP",                          .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  524, .title ="Output filter time DOP mask (threshold)",
                            .scale = "0.1",     .scalefact = +0x1.999999999999ap-4 /* = 1.00000000000000005551e-01 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgOutfilPacc =
{
    .id = 0x301100b3, .name = "CFG-NAVSPG-OUTFIL_PACC",                          .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  525, .title ="Output filter position accuracy mask (threshold)",
        .unit = "m"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgOutfilTacc =
{
    .id = 0x301100b4, .name = "CFG-NAVSPG-OUTFIL_TACC",                          .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  526, .title ="Output filter time accuracy mask (threshold)",
        .unit = "m"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgOutfilFacc =
{
    .id = 0x301100b5, .name = "CFG-NAVSPG-OUTFIL_FACC",                          .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  527, .title ="Output filter frequency accuracy mask (threshold)",
    .unit = "m/s",      .scale = "0.01",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgConstrAlt =
{
    .id = 0x401100c1, .name = "CFG-NAVSPG-CONSTR_ALT",                           .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  528, .title ="Fixed altitude (mean sea level) for 2D fix mode",
    .unit = "m",        .scale = "0.01",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgConstrAltvar =
{
    .id = 0x401100c2, .name = "CFG-NAVSPG-CONSTR_ALTVAR",                        .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  529, .title ="Fixed altitude variance for 2D mode",
    .unit = "m^2",      .scale = "0.0001",  .scalefact = +0x1.a36e2eb1c432dp-14 /* = 1.00000000000000004792e-04 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgConstrDgnssto =
{
    .id = 0x201100c4, .name = "CFG-NAVSPG-CONSTR_DGNSSTO",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  530, .title ="DGNSS timeout",
        .unit = "s"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNavspgSigattcomp_consts[65] =
{
    {
        .name = "DIS",               .value = "0",                 .val = { .E = 0 },
        .title = "Disabled"
    },
    {
        .name = "AUTO",              .value = "255",               .val = { .E = 255 },
        .title = "Automatic"
    },
    {
        .name = "01DBHZ",            .value = "1",                 .val = { .E = 1 },
        .title = "Maximum expected C/N0 level is 1 dBHz"
    },
    {
        .name = "02DBHZ",            .value = "2",                 .val = { .E = 2 },
        .title = "Maximum expected C/N0 level is 2 dBHz"
    },
    {
        .name = "03DBHZ",            .value = "3",                 .val = { .E = 3 },
        .title = "Maximum expected C/N0 level is 3 dBHz"
    },
    {
        .name = "04DBHZ",            .value = "4",                 .val = { .E = 4 },
        .title = "Maximum expected C/N0 level is 4 dBHz"
    },
    {
        .name = "05DBHZ",            .value = "5",                 .val = { .E = 5 },
        .title = "Maximum expected C/N0 level is 5 dBHz"
    },
    {
        .name = "06DBHZ",            .value = "6",                 .val = { .E = 6 },
        .title = "Maximum expected C/N0 level is 6 dBHz"
    },
    {
        .name = "07DBHZ",            .value = "7",                 .val = { .E = 7 },
        .title = "Maximum expected C/N0 level is 7 dBHz"
    },
    {
        .name = "08DBHZ",            .value = "8",                 .val = { .E = 8 },
        .title = "Maximum expected C/N0 level is 8 dBHz"
    },
    {
        .name = "09DBHZ",            .value = "9",                 .val = { .E = 9 },
        .title = "Maximum expected C/N0 level is 9 dBHz"
    },
    {
        .name = "10DBHZ",            .value = "10",                .val = { .E = 10 },
        .title = "Maximum expected C/N0 level is 10 dBHz"
    },
    {
        .name = "11DBHZ",            .value = "11",                .val = { .E = 11 },
        .title = "Maximum expected C/N0 level is 11 dBHz"
    },
    {
        .name = "12DBHZ",            .value = "12",                .val = { .E = 12 },
        .title = "Maximum expected C/N0 level is 12 dBHz"
    },
    {
        .name = "13DBHZ",            .value = "13",                .val = { .E = 13 },
        .title = "Maximum expected C/N0 level is 13 dBHz"
    },
    {
        .name = "14DBHZ",            .value = "14",                .val = { .E = 14 },
        .title = "Maximum expected C/N0 level is 14 dBHz"
    },
    {
        .name = "15DBHZ",            .value = "15",                .val = { .E = 15 },
        .title = "Maximum expected C/N0 level is 15 dBHz"
    },
    {
        .name = "16DBHZ",            .value = "16",                .val = { .E = 16 },
        .title = "Maximum expected C/N0 level is 16 dBHz"
    },
    {
        .name = "17DBHZ",            .value = "17",                .val = { .E = 17 },
        .title = "Maximum expected C/N0 level is 17 dBHz"
    },
    {
        .name = "18DBHZ",            .value = "18",                .val = { .E = 18 },
        .title = "Maximum expected C/N0 level is 18 dBHz"
    },
    {
        .name = "19DBHZ",            .value = "19",                .val = { .E = 19 },
        .title = "Maximum expected C/N0 level is 19 dBHz"
    },
    {
        .name = "20DBHZ",            .value = "20",                .val = { .E = 20 },
        .title = "Maximum expected C/N0 level is 20 dBHz"
    },
    {
        .name = "21DBHZ",            .value = "21",                .val = { .E = 21 },
        .title = "Maximum expected C/N0 level is 21 dBHz"
    },
    {
        .name = "22DBHZ",            .value = "22",                .val = { .E = 22 },
        .title = "Maximum expected C/N0 level is 22 dBHz"
    },
    {
        .name = "23DBHZ",            .value = "23",                .val = { .E = 23 },
        .title = "Maximum expected C/N0 level is 23 dBHz"
    },
    {
        .name = "24DBHZ",            .value = "24",                .val = { .E = 24 },
        .title = "Maximum expected C/N0 level is 24 dBHz"
    },
    {
        .name = "25DBHZ",            .value = "25",                .val = { .E = 25 },
        .title = "Maximum expected C/N0 level is 25 dBHz"
    },
    {
        .name = "26DBHZ",            .value = "26",                .val = { .E = 26 },
        .title = "Maximum expected C/N0 level is 26 dBHz"
    },
    {
        .name = "27DBHZ",            .value = "27",                .val = { .E = 27 },
        .title = "Maximum expected C/N0 level is 27 dBHz"
    },
    {
        .name = "28DBHZ",            .value = "28",                .val = { .E = 28 },
        .title = "Maximum expected C/N0 level is 28 dBHz"
    },
    {
        .name = "29DBHZ",            .value = "29",                .val = { .E = 29 },
        .title = "Maximum expected C/N0 level is 29 dBHz"
    },
    {
        .name = "30DBHZ",            .value = "30",                .val = { .E = 30 },
        .title = "Maximum expected C/N0 level is 30 dBHz"
    },
    {
        .name = "31DBHZ",            .value = "31",                .val = { .E = 31 },
        .title = "Maximum expected C/N0 level is 31 dBHz"
    },
    {
        .name = "32DBHZ",            .value = "32",                .val = { .E = 32 },
        .title = "Maximum expected C/N0 level is 32 dBHz"
    },
    {
        .name = "33DBHZ",            .value = "33",                .val = { .E = 33 },
        .title = "Maximum expected C/N0 level is 33 dBHz"
    },
    {
        .name = "34DBHZ",            .value = "34",                .val = { .E = 34 },
        .title = "Maximum expected C/N0 level is 34 dBHz"
    },
    {
        .name = "35DBHZ",            .value = "35",                .val = { .E = 35 },
        .title = "Maximum expected C/N0 level is 35 dBHz"
    },
    {
        .name = "36DBHZ",            .value = "36",                .val = { .E = 36 },
        .title = "Maximum expected C/N0 level is 36 dBHz"
    },
    {
        .name = "37DBHZ",            .value = "37",                .val = { .E = 37 },
        .title = "Maximum expected C/N0 level is 37 dBHz"
    },
    {
        .name = "38DBHZ",            .value = "38",                .val = { .E = 38 },
        .title = "Maximum expected C/N0 level is 38 dBHz"
    },
    {
        .name = "39DBHZ",            .value = "39",                .val = { .E = 39 },
        .title = "Maximum expected C/N0 level is 39 dBHz"
    },
    {
        .name = "40DBHZ",            .value = "40",                .val = { .E = 40 },
        .title = "Maximum expected C/N0 level is 40 dBHz"
    },
    {
        .name = "41DBHZ",            .value = "41",                .val = { .E = 41 },
        .title = "Maximum expected C/N0 level is 41 dBHz"
    },
    {
        .name = "42DBHZ",            .value = "42",                .val = { .E = 42 },
        .title = "Maximum expected C/N0 level is 42 dBHz"
    },
    {
        .name = "43DBHZ",            .value = "43",                .val = { .E = 43 },
        .title = "Maximum expected C/N0 level is 43 dBHz"
    },
    {
        .name = "44DBHZ",            .value = "44",                .val = { .E = 44 },
        .title = "Maximum expected C/N0 level is 44 dBHz"
    },
    {
        .name = "45DBHZ",            .value = "45",                .val = { .E = 45 },
        .title = "Maximum expected C/N0 level is 45 dBHz"
    },
    {
        .name = "46DBHZ",            .value = "46",                .val = { .E = 46 },
        .title = "Maximum expected C/N0 level is 46 dBHz"
    },
    {
        .name = "47DBHZ",            .value = "47",                .val = { .E = 47 },
        .title = "Maximum expected C/N0 level is 47 dBHz"
    },
    {
        .name = "48DBHZ",            .value = "48",                .val = { .E = 48 },
        .title = "Maximum expected C/N0 level is 48 dBHz"
    },
    {
        .name = "49DBHZ",            .value = "49",                .val = { .E = 49 },
        .title = "Maximum expected C/N0 level is 49 dBHz"
    },
    {
        .name = "50DBHZ",            .value = "50",                .val = { .E = 50 },
        .title = "Maximum expected C/N0 level is 50 dBHz"
    },
    {
        .name = "51DBHZ",            .value = "51",                .val = { .E = 51 },
        .title = "Maximum expected C/N0 level is 51 dBHz"
    },
    {
        .name = "52DBHZ",            .value = "52",                .val = { .E = 52 },
        .title = "Maximum expected C/N0 level is 52 dBHz"
    },
    {
        .name = "53DBHZ",            .value = "53",                .val = { .E = 53 },
        .title = "Maximum expected C/N0 level is 53 dBHz"
    },
    {
        .name = "54DBHZ",            .value = "54",                .val = { .E = 54 },
        .title = "Maximum expected C/N0 level is 54 dBHz"
    },
    {
        .name = "55DBHZ",            .value = "55",                .val = { .E = 55 },
        .title = "Maximum expected C/N0 level is 55 dBHz"
    },
    {
        .name = "56DBHZ",            .value = "56",                .val = { .E = 56 },
        .title = "Maximum expected C/N0 level is 56 dBHz"
    },
    {
        .name = "57DBHZ",            .value = "57",                .val = { .E = 57 },
        .title = "Maximum expected C/N0 level is 57 dBHz"
    },
    {
        .name = "58DBHZ",            .value = "58",                .val = { .E = 58 },
        .title = "Maximum expected C/N0 level is 58 dBHz"
    },
    {
        .name = "59DBHZ",            .value = "59",                .val = { .E = 59 },
        .title = "Maximum expected C/N0 level is 59 dBHz"
    },
    {
        .name = "60DBHZ",            .value = "60",                .val = { .E = 60 },
        .title = "Maximum expected C/N0 level is 60 dBHz"
    },
    {
        .name = "61DBHZ",            .value = "61",                .val = { .E = 61 },
        .title = "Maximum expected C/N0 level is 61 dBHz"
    },
    {
        .name = "62DBHZ",            .value = "62",                .val = { .E = 62 },
        .title = "Maximum expected C/N0 level is 62 dBHz"
    },
    {
        .name = "63DBHZ",            .value = "63",                .val = { .E = 63 },
        .title = "Maximum expected C/N0 level is 63 dBHz"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNavspgSigattcomp =
{
    .id = 0x201100d6, .name = "CFG-NAVSPG-SIGATTCOMP",                           .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  531, .title ="Permanently attenuated signal compensation mode",
    .nConsts =  65, .consts = ubloxcfg_cfgNavspgSigattcomp_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNmeaProtver_consts[5] =
{
    {
        .name = "V21",               .value = "21",                .val = { .E = 21 },
        .title = "NMEA protocol version 2.1"
    },
    {
        .name = "V23",               .value = "23",                .val = { .E = 23 },
        .title = "NMEA protocol version 2.3"
    },
    {
        .name = "V40",               .value = "40",                .val = { .E = 40 },
        .title = "NMEA protocol version 4.0 (not available in all products)"
    },
    {
        .name = "V41",               .value = "41",                .val = { .E = 41 },
        .title = "NMEA protocol version 4.10 (not available in all products)"
    },
    {
        .name = "V411",              .value = "42",                .val = { .E = 42 },
        .title = "NMEA protocol version 4.11 (not available in all products)"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaProtver =
{
    .id = 0x20930001, .name = "CFG-NMEA-PROTVER",                                .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  532, .title ="NMEA protocol version",
    .nConsts =   5, .consts = ubloxcfg_cfgNmeaProtver_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNmeaMaxsvs_consts[4] =
{
    {
        .name = "UNLIM",             .value = "0",                 .val = { .E = 0 },
        .title = "Unlimited"
    },
    {
        .name = "8SVS",              .value = "8",                 .val = { .E = 8 },
        .title = "8 SVs"
    },
    {
        .name = "12SVS",             .value = "12",                .val = { .E = 12 },
        .title = "12 SVs"
    },
    {
        .name = "16SVS",             .value = "16",                .val = { .E = 16 },
        .title = "16 SVs"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaMaxsvs =
{
    .id = 0x20930002, .name = "CFG-NMEA-MAXSVS",                                 .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  533, .title ="Maximum number of SVs to report per Talker ID",
    .nConsts =   4, .consts = ubloxcfg_cfgNmeaMaxsvs_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaCompat =
{
    .id = 0x10930003, .name = "CFG-NMEA-COMPAT",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  534, .title ="Enable compatibility mode"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaConsider =
{
    .id = 0x10930004, .name = "CFG-NMEA-CONSIDER",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  535, .title ="Enable considering mode"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaLimit82 =
{
    .id = 0x10930005, .name = "CFG-NMEA-LIMIT82",                                .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  536, .title ="Enable strict limit to 82 characters maximum NMEA message length"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaHighprec =
{
    .id = 0x10930006, .name = "CFG-NMEA-HIGHPREC",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  537, .title ="Enable high precision mode"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNmeaSvnumbering_consts[2] =
{
    {
        .name = "STRICT",            .value = "0",                 .val = { .E = 0 },
        .title = "Strict - satellites are not output"
    },
    {
        .name = "EXTENDED",          .value = "1",                 .val = { .E = 1 },
        .title = "Extended - use proprietary numbering"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaSvnumbering =
{
    .id = 0x20930007, .name = "CFG-NMEA-SVNUMBERING",                            .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  538, .title ="Display configuration for SVs that do not have value defined in NMEA",
    .nConsts =   2, .consts = ubloxcfg_cfgNmeaSvnumbering_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaFiltGps =
{
    .id = 0x10930011, .name = "CFG-NMEA-FILT_GPS",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  539, .title ="Disable reporting of GPS satellites"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaFiltSbas =
{
    .id = 0x10930012, .name = "CFG-NMEA-FILT_SBAS",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  540, .title ="Disable reporting of SBAS satellites"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaFiltGal =
{
    .id = 0x10930013, .name = "CFG-NMEA-FILT_GAL",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  541, .title ="Disable reporting of Galileo satellites"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaFiltQzss =
{
    .id = 0x10930015, .name = "CFG-NMEA-FILT_QZSS",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  542, .title ="Disable reporting of QZSS satellites"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaFiltGlo =
{
    .id = 0x10930016, .name = "CFG-NMEA-FILT_GLO",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  543, .title ="Disable reporting of GLONASS satellites"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaFiltBds =
{
    .id = 0x10930017, .name = "CFG-NMEA-FILT_BDS",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  544, .title ="Disable reporting of BeiDou satellites"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaOutInvfix =
{
    .id = 0x10930021, .name = "CFG-NMEA-OUT_INVFIX",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  545, .title ="Enable position output for failed or invalid fixes"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaOutMskfix =
{
    .id = 0x10930022, .name = "CFG-NMEA-OUT_MSKFIX",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  546, .title ="Enable position output for invalid fixes"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaOutInvtime =
{
    .id = 0x10930023, .name = "CFG-NMEA-OUT_INVTIME",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  547, .title ="Enable time output for invalid times"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaOutInvdate =
{
    .id = 0x10930024, .name = "CFG-NMEA-OUT_INVDATE",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  548, .title ="Enable date output for invalid dates"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaOutOnlygps =
{
    .id = 0x10930025, .name = "CFG-NMEA-OUT_ONLYGPS",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  549, .title ="Restrict output to GPS satellites only"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaOutFrozencog =
{
    .id = 0x10930026, .name = "CFG-NMEA-OUT_FROZENCOG",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  550, .title ="Enable course over ground output even if it is frozen"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNmeaMaintalkerid_consts[7] =
{
    {
        .name = "AUTO",              .value = "0",                 .val = { .E = 0 },
        .title = "Main Talker ID is not overridden"
    },
    {
        .name = "GP",                .value = "1",                 .val = { .E = 1 },
        .title = "Set main Talker ID to 'GP'"
    },
    {
        .name = "GL",                .value = "2",                 .val = { .E = 2 },
        .title = "Set main Talker ID to 'GL'"
    },
    {
        .name = "GN",                .value = "3",                 .val = { .E = 3 },
        .title = "Set main Talker ID to 'GN'"
    },
    {
        .name = "GA",                .value = "4",                 .val = { .E = 4 },
        .title = "Set main Talker ID to 'GA' (not available in all products)"
    },
    {
        .name = "GB",                .value = "5",                 .val = { .E = 5 },
        .title = "Set main Talker ID to 'GB' (not available in all products)"
    },
    {
        .name = "GQ",                .value = "7",                 .val = { .E = 7 },
        .title = "Set main Talker ID to 'GQ' (not available in all products)"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaMaintalkerid =
{
    .id = 0x20930031, .name = "CFG-NMEA-MAINTALKERID",                           .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  551, .title ="Main Talker ID",
    .nConsts =   7, .consts = ubloxcfg_cfgNmeaMaintalkerid_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgNmeaGsvtalkerid_consts[2] =
{
    {
        .name = "GNSS",              .value = "0",                 .val = { .E = 0 },
        .title = "Use GNSS-specific Talker ID (as defined by NMEA)"
    },
    {
        .name = "MAIN",              .value = "1",                 .val = { .E = 1 },
        .title = "Use the main Talker ID"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaGsvtalkerid =
{
    .id = 0x20930032, .name = "CFG-NMEA-GSVTALKERID",                            .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  552, .title ="Talker ID for GSV NMEA messages",
    .nConsts =   2, .consts = ubloxcfg_cfgNmeaGsvtalkerid_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgNmeaBdstalkerid =
{
    .id = 0x30930033, .name = "CFG-NMEA-BDSTALKERID",                            .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  553, .title ="BeiDou Talker ID"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgOdoUseOdo =
{
    .id = 0x10220001, .name = "CFG-ODO-USE_ODO",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  554, .title ="Use odometer"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgOdoUseCog =
{
    .id = 0x10220002, .name = "CFG-ODO-USE_COG",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  555, .title ="Use low-speed course over ground filter"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgOdoOutlpvel =
{
    .id = 0x10220003, .name = "CFG-ODO-OUTLPVEL",                                .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  556, .title ="Output low-pass filtered velocity"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgOdoOutlpcog =
{
    .id = 0x10220004, .name = "CFG-ODO-OUTLPCOG",                                .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  557, .title ="Output low-pass filtered course over ground (heading)"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgOdoProfile_consts[5] =
{
    {
        .name = "RUN",               .value = "0",                 .val = { .E = 0 },
        .title = "Running"
    },
    {
        .name = "CYCL",              .value = "1",                 .val = { .E = 1 },
        .title = "Cycling"
    },
    {
        .name = "SWIM",              .value = "2",                 .val = { .E = 2 },
        .title = "Swimming"
    },
    {
        .name = "CAR",               .value = "3",                 .val = { .E = 3 },
        .title = "Car"
    },
    {
        .name = "CUSTOM",            .value = "4",                 .val = { .E = 4 },
        .title = "Custom"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgOdoProfile =
{
    .id = 0x20220005, .name = "CFG-ODO-PROFILE",                                 .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  558, .title ="Odometer profile configuration",
    .nConsts =   5, .consts = ubloxcfg_cfgOdoProfile_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgOdoCogmaxspeed =
{
    .id = 0x20220021, .name = "CFG-ODO-COGMAXSPEED",                             .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  559, .title ="Upper speed limit for low-speed course over ground filter",
        .unit = "m/s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgOdoCogmaxposacc =
{
    .id = 0x20220022, .name = "CFG-ODO-COGMAXPOSACC",                            .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  560, .title ="Maximum acceptable position accuracy for computing low-speed filtered course over ground"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgOdoVellpgain =
{
    .id = 0x20220031, .name = "CFG-ODO-VELLPGAIN",                               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  561, .title ="Velocity low-pass filter level"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgOdoCoglpgain =
{
    .id = 0x20220032, .name = "CFG-ODO-COGLPGAIN",                               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  562, .title ="Course over ground low-pass filter level (at speed < 8 m/s)"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgPmOperatemode_consts[3] =
{
    {
        .name = "FULL",              .value = "0",                 .val = { .E = 0 },
        .title = "Normal operation, no power save mode active"
    },
    {
        .name = "PSMOO",             .value = "1",                 .val = { .E = 1 },
        .title = "PSM ON/OFF operation"
    },
    {
        .name = "PSMCT",             .value = "2",                 .val = { .E = 2 },
        .title = "PSM cyclic tracking operation"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmOperatemode =
{
    .id = 0x20d00001, .name = "CFG-PM-OPERATEMODE",                              .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  563, .title ="General receiver power management mode of operation",
    .nConsts =   3, .consts = ubloxcfg_cfgPmOperatemode_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmPosupdateperiod =
{
    .id = 0x40d00002, .name = "CFG-PM-POSUPDATEPERIOD",                          .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  564, .title ="Position update period for PSMOO, 0 = no retry, >5"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmAcqperiod =
{
    .id = 0x40d00003, .name = "CFG-PM-ACQPERIOD",                                .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  565, .title ="Acquisition period used if the receiver previously failed to achieve a position fix",
        .unit = "s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmGridoffset =
{
    .id = 0x40d00004, .name = "CFG-PM-GRIDOFFSET",                               .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  566, .title ="Position update period grid offset relative to GPS start of week",
        .unit = "s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmOntime =
{
    .id = 0x30d00005, .name = "CFG-PM-ONTIME",                                   .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  567, .title ="Time to stay in tracking state",
        .unit = "s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmMinacqtime =
{
    .id = 0x20d00006, .name = "CFG-PM-MINACQTIME",                               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  568, .title ="Minimum time to spend in acquisition state",
        .unit = "s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmMaxacqtime =
{
    .id = 0x20d00007, .name = "CFG-PM-MAXACQTIME",                               .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  569, .title ="Maximum time to spend in acquisition state",
        .unit = "s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmDonotenteroff =
{
    .id = 0x10d00008, .name = "CFG-PM-DONOTENTEROFF",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  570, .title ="Disable to make the receiver enter (inactive) awaiting next search state, enable to make the receiver not enter (inactive)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmWaittimefix =
{
    .id = 0x10d00009, .name = "CFG-PM-WAITTIMEFIX",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  571, .title ="Wait for time fix"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmUpdateeph =
{
    .id = 0x10d0000a, .name = "CFG-PM-UPDATEEPH",                                .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  572, .title ="Update ephemeris regularly"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgPmExtintsel_consts[2] =
{
    {
        .name = "EXTINT0",           .value = "0",                 .val = { .E = 0 },
        .title = "EXTINT0 pin"
    },
    {
        .name = "EXTINT1",           .value = "1",                 .val = { .E = 1 },
        .title = "EXTINT1 pin"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmExtintsel =
{
    .id = 0x20d0000b, .name = "CFG-PM-EXTINTSEL",                                .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  573, .title ="EXTINT pin select",
    .nConsts =   2, .consts = ubloxcfg_cfgPmExtintsel_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmExtintwake =
{
    .id = 0x10d0000c, .name = "CFG-PM-EXTINTWAKE",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  574, .title ="Enable to keep receiver awake as long as selected EXTINT pin is high"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmExtintbackup =
{
    .id = 0x10d0000d, .name = "CFG-PM-EXTINTBACKUP",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  575, .title ="EXTINT pin control (Backup)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmExtintinactive =
{
    .id = 0x10d0000e, .name = "CFG-PM-EXTINTINACTIVE",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  576, .title ="EXTINT pin control (Inactive)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmExtintinactivity =
{
    .id = 0x40d0000f, .name = "CFG-PM-EXTINTINACTIVITY",                         .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  577, .title ="Inactivity time out on EXTINT pin if enabled",
    .unit = "s",        .scale = "0.001",   .scalefact = +0x1.0624dd2f1a9fcp-10 /* = 1.00000000000000002082e-03 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgPmLimitpeakcurr =
{
    .id = 0x10d00010, .name = "CFG-PM-LIMITPEAKCURR",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  578, .title ="Limit peak current"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgQzssUseSlasDgnss =
{
    .id = 0x10370005, .name = "CFG-QZSS-USE_SLAS_DGNSS",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  579, .title ="Apply QZSS SLAS DGNSS corrections"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgQzssUseSlasTestmode =
{
    .id = 0x10370006, .name = "CFG-QZSS-USE_SLAS_TESTMODE",                      .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  580, .title ="Use QZSS SLAS data when it is in test mode (SLAS msg 0)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgQzssUseSlasRaimUncorr =
{
    .id = 0x10370007, .name = "CFG-QZSS-USE_SLAS_RAIM_UNCORR",                   .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  581, .title ="Raim out measurements that are not corrected by QZSS SLAS, if at least 5 measurements are corrected"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRateMeas =
{
    .id = 0x30210001, .name = "CFG-RATE-MEAS",                                   .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  582, .title ="Nominal time between GNSS measurements",
    .unit = "s",        .scale = "0.001",   .scalefact = +0x1.0624dd2f1a9fcp-10 /* = 1.00000000000000002082e-03 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRateNav =
{
    .id = 0x30210002, .name = "CFG-RATE-NAV",                                    .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  583, .title ="Ratio of number of measurements to number of navigation solutions"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgRateTimeref_consts[5] =
{
    {
        .name = "UTC",               .value = "0",                 .val = { .E = 0 },
        .title = "Align measurements to UTC time"
    },
    {
        .name = "GPS",               .value = "1",                 .val = { .E = 1 },
        .title = "Align measurements to GPS time"
    },
    {
        .name = "GLO",               .value = "2",                 .val = { .E = 2 },
        .title = "Align measurements to GLONASS time"
    },
    {
        .name = "BDS",               .value = "3",                 .val = { .E = 3 },
        .title = "Align measurements to BeiDou time"
    },
    {
        .name = "GAL",               .value = "4",                 .val = { .E = 4 },
        .title = "Align measurements to Galileo time"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRateTimeref =
{
    .id = 0x20210003, .name = "CFG-RATE-TIMEREF",                                .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  584, .title ="Time system to which measurements are aligned",
    .nConsts =   5, .consts = ubloxcfg_cfgRateTimeref_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRinvDump =
{
    .id = 0x10c70001, .name = "CFG-RINV-DUMP",                                   .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  585, .title ="Dump data at startup"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRinvBinary =
{
    .id = 0x10c70002, .name = "CFG-RINV-BINARY",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  586, .title ="Data is binary"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRinvDataSize =
{
    .id = 0x20c70003, .name = "CFG-RINV-DATA_SIZE",                              .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  587, .title ="Size of data"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRinvChunk0 =
{
    .id = 0x50c70004, .name = "CFG-RINV-CHUNK0",                                 .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  588, .title ="Data bytes 1-8 (LSB)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRinvChunk1 =
{
    .id = 0x50c70005, .name = "CFG-RINV-CHUNK1",                                 .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  589, .title ="Data bytes 9-16"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRinvChunk2 =
{
    .id = 0x50c70006, .name = "CFG-RINV-CHUNK2",                                 .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  590, .title ="Data bytes 17-24"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRinvChunk3 =
{
    .id = 0x50c70007, .name = "CFG-RINV-CHUNK3",                                 .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  591, .title ="Data bytes 25-30 (MSB)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRtcmDf003Out =
{
    .id = 0x30090001, .name = "CFG-RTCM-DF003_OUT",                              .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  592, .title ="RTCM DF003 (Reference station ID) output value (0...4095)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRtcmDf003In =
{
    .id = 0x30090008, .name = "CFG-RTCM-DF003_IN",                               .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  593, .title ="RTCM DF003 (Reference station ID) input value (0...4095)"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgRtcmDf003InFilter_consts[3] =
{
    {
        .name = "DISABLED",          .value = "0",                 .val = { .E = 0 },
        .title = "Disabled RTCM input filter; all input messages allowed"
    },
    {
        .name = "RELAXED",           .value = "1",                 .val = { .E = 1 },
        .title = "Relaxed RTCM input filter; input messages allowed must contain a DF003 data field matching the CFG-RTCM-DF003_IN value or not contain by specification the DF003 data field"
    },
    {
        .name = "STRICT",            .value = "2",                 .val = { .E = 2 },
        .title = "Strict RTCM input filter; input messages allowed must contain a DF003 data field matching the CFG-RTCM-DF003 value"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgRtcmDf003InFilter =
{
    .id = 0x20090009, .name = "CFG-RTCM-DF003_IN_FILTER",                        .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  594, .title ="RTCM input filter configuration based on RTCM DF003 (Reference station ID) value",
    .nConsts =   3, .consts = ubloxcfg_cfgRtcmDf003InFilter_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSbasUseTestmode =
{
    .id = 0x10360002, .name = "CFG-SBAS-USE_TESTMODE",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  595, .title ="Use SBAS data when it is in test mode (SBAS msg 0)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSbasUseRanging =
{
    .id = 0x10360003, .name = "CFG-SBAS-USE_RANGING",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  596, .title ="Use SBAS GEOs as a ranging source (for navigation)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSbasUseDiffcorr =
{
    .id = 0x10360004, .name = "CFG-SBAS-USE_DIFFCORR",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  597, .title ="Use SBAS differential corrections"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSbasUseIntegrity =
{
    .id = 0x10360005, .name = "CFG-SBAS-USE_INTEGRITY",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  598, .title ="Use SBAS integrity information"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgSbasPrnscanmask_consts[40] =
{
    {
        .name = "ALL",               .value = "0x0000000000000000", .val = { .X = 0x0000000000000000 },
        .title = "Enable search for all SBAS PRNs"
    },
    {
        .name = "PRN120",            .value = "0x0000000000000001", .val = { .X = 0x0000000000000001 },
        .title = "Enable search for SBAS PRN120"
    },
    {
        .name = "PRN121",            .value = "0x0000000000000002", .val = { .X = 0x0000000000000002 },
        .title = "Enable search for SBAS PRN121"
    },
    {
        .name = "PRN122",            .value = "0x0000000000000004", .val = { .X = 0x0000000000000004 },
        .title = "Enable search for SBAS PRN122"
    },
    {
        .name = "PRN123",            .value = "0x0000000000000008", .val = { .X = 0x0000000000000008 },
        .title = "Enable search for SBAS PRN123"
    },
    {
        .name = "PRN124",            .value = "0x0000000000000010", .val = { .X = 0x0000000000000010 },
        .title = "Enable search for SBAS PRN124"
    },
    {
        .name = "PRN125",            .value = "0x0000000000000020", .val = { .X = 0x0000000000000020 },
        .title = "Enable search for SBAS PRN125"
    },
    {
        .name = "PRN126",            .value = "0x0000000000000040", .val = { .X = 0x0000000000000040 },
        .title = "Enable search for SBAS PRN126"
    },
    {
        .name = "PRN127",            .value = "0x0000000000000080", .val = { .X = 0x0000000000000080 },
        .title = "Enable search for SBAS PRN127"
    },
    {
        .name = "PRN128",            .value = "0x0000000000000100", .val = { .X = 0x0000000000000100 },
        .title = "Enable search for SBAS PRN128"
    },
    {
        .name = "PRN129",            .value = "0x0000000000000200", .val = { .X = 0x0000000000000200 },
        .title = "Enable search for SBAS PRN129"
    },
    {
        .name = "PRN130",            .value = "0x0000000000000400", .val = { .X = 0x0000000000000400 },
        .title = "Enable search for SBAS PRN130"
    },
    {
        .name = "PRN131",            .value = "0x0000000000000800", .val = { .X = 0x0000000000000800 },
        .title = "Enable search for SBAS PRN131"
    },
    {
        .name = "PRN132",            .value = "0x0000000000001000", .val = { .X = 0x0000000000001000 },
        .title = "Enable search for SBAS PRN132"
    },
    {
        .name = "PRN133",            .value = "0x0000000000002000", .val = { .X = 0x0000000000002000 },
        .title = "Enable search for SBAS PRN133"
    },
    {
        .name = "PRN134",            .value = "0x0000000000004000", .val = { .X = 0x0000000000004000 },
        .title = "Enable search for SBAS PRN134"
    },
    {
        .name = "PRN135",            .value = "0x0000000000008000", .val = { .X = 0x0000000000008000 },
        .title = "Enable search for SBAS PRN135"
    },
    {
        .name = "PRN136",            .value = "0x0000000000010000", .val = { .X = 0x0000000000010000 },
        .title = "Enable search for SBAS PRN136"
    },
    {
        .name = "PRN137",            .value = "0x0000000000020000", .val = { .X = 0x0000000000020000 },
        .title = "Enable search for SBAS PRN137"
    },
    {
        .name = "PRN138",            .value = "0x0000000000040000", .val = { .X = 0x0000000000040000 },
        .title = "Enable search for SBAS PRN138"
    },
    {
        .name = "PRN139",            .value = "0x0000000000080000", .val = { .X = 0x0000000000080000 },
        .title = "Enable search for SBAS PRN139"
    },
    {
        .name = "PRN140",            .value = "0x0000000000100000", .val = { .X = 0x0000000000100000 },
        .title = "Enable search for SBAS PRN140"
    },
    {
        .name = "PRN141",            .value = "0x0000000000200000", .val = { .X = 0x0000000000200000 },
        .title = "Enable search for SBAS PRN141"
    },
    {
        .name = "PRN142",            .value = "0x0000000000400000", .val = { .X = 0x0000000000400000 },
        .title = "Enable search for SBAS PRN142"
    },
    {
        .name = "PRN143",            .value = "0x0000000000800000", .val = { .X = 0x0000000000800000 },
        .title = "Enable search for SBAS PRN143"
    },
    {
        .name = "PRN144",            .value = "0x0000000001000000", .val = { .X = 0x0000000001000000 },
        .title = "Enable search for SBAS PRN144"
    },
    {
        .name = "PRN145",            .value = "0x0000000002000000", .val = { .X = 0x0000000002000000 },
        .title = "Enable search for SBAS PRN145"
    },
    {
        .name = "PRN146",            .value = "0x0000000004000000", .val = { .X = 0x0000000004000000 },
        .title = "Enable search for SBAS PRN146"
    },
    {
        .name = "PRN147",            .value = "0x0000000008000000", .val = { .X = 0x0000000008000000 },
        .title = "Enable search for SBAS PRN147"
    },
    {
        .name = "PRN148",            .value = "0x0000000010000000", .val = { .X = 0x0000000010000000 },
        .title = "Enable search for SBAS PRN148"
    },
    {
        .name = "PRN149",            .value = "0x0000000020000000", .val = { .X = 0x0000000020000000 },
        .title = "Enable search for SBAS PRN149"
    },
    {
        .name = "PRN150",            .value = "0x0000000040000000", .val = { .X = 0x0000000040000000 },
        .title = "Enable search for SBAS PRN150"
    },
    {
        .name = "PRN151",            .value = "0x0000000080000000", .val = { .X = 0x0000000080000000 },
        .title = "Enable search for SBAS PRN151"
    },
    {
        .name = "PRN152",            .value = "0x0000000100000000", .val = { .X = 0x0000000100000000 },
        .title = "Enable search for SBAS PRN152"
    },
    {
        .name = "PRN153",            .value = "0x0000000200000000", .val = { .X = 0x0000000200000000 },
        .title = "Enable search for SBAS PRN153"
    },
    {
        .name = "PRN154",            .value = "0x0000000400000000", .val = { .X = 0x0000000400000000 },
        .title = "Enable search for SBAS PRN154"
    },
    {
        .name = "PRN155",            .value = "0x0000000800000000", .val = { .X = 0x0000000800000000 },
        .title = "Enable search for SBAS PRN155"
    },
    {
        .name = "PRN156",            .value = "0x0000001000000000", .val = { .X = 0x0000001000000000 },
        .title = "Enable search for SBAS PRN156"
    },
    {
        .name = "PRN157",            .value = "0x0000002000000000", .val = { .X = 0x0000002000000000 },
        .title = "Enable search for SBAS PRN157"
    },
    {
        .name = "PRN158",            .value = "0x0000004000000000", .val = { .X = 0x0000004000000000 },
        .title = "Enable search for SBAS PRN158"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSbasPrnscanmask =
{
    .id = 0x50360006, .name = "CFG-SBAS-PRNSCANMASK",                            .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  599, .title ="SBAS PRN search configuration",
    .nConsts =  40, .consts = ubloxcfg_cfgSbasPrnscanmask_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSecCfgLock =
{
    .id = 0x10f60009, .name = "CFG-SEC-CFG_LOCK",                                .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  600, .title ="Configuration lockdown"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSecCfgLockUnlockgrp1 =
{
    .id = 0x30f6000a, .name = "CFG-SEC-CFG_LOCK_UNLOCKGRP1",                     .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  601, .title ="Configuration lockdown exempted group 1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSecCfgLockUnlockgrp2 =
{
    .id = 0x30f6000b, .name = "CFG-SEC-CFG_LOCK_UNLOCKGRP2",                     .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  602, .title ="Configuration lockdown exempted group 1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfcoreUseSf =
{
    .id = 0x10080001, .name = "CFG-SFCORE-USE_SF",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  603, .title ="Use ADR/UDR sensor fusion"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuGyroTcUpdatePeriod =
{
    .id = 0x30060007, .name = "CFG-SFIMU-GYRO_TC_UPDATE_PERIOD",                 .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  604, .title ="Time period between each update for the saved temperature-dependent gyroscope bias table",
        .unit = "s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuGyroRmsthdl =
{
    .id = 0x20060008, .name = "CFG-SFIMU-GYRO_RMSTHDL",                          .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  605, .title ="Gyroscope sensor RMS threshold",
    .unit = "deg/s",    .scale = "2^-8",    .scalefact = +0x1.0000000000000p-8 /* = 3.90625000000000000000e-03 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuGyroFrequency =
{
    .id = 0x20060009, .name = "CFG-SFIMU-GYRO_FREQUENCY",                        .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  606, .title ="Nominal gyroscope sensor data sampling frequency",
        .unit = "Hz"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuGyroLatency =
{
    .id = 0x3006000a, .name = "CFG-SFIMU-GYRO_LATENCY",                          .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  607, .title ="Gyroscope sensor data latency due to e.g. CAN bus",
        .unit = "ms"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuGyroAccuracy =
{
    .id = 0x3006000b, .name = "CFG-SFIMU-GYRO_ACCURACY",                         .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  608, .title ="Gyroscope sensor data accuracy",
    .unit = "deg/s",    .scale = "1e-3",    .scalefact = +0x1.0624dd2f1a9fcp-10 /* = 1.00000000000000002082e-03 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuAccelRmsthdl =
{
    .id = 0x20060015, .name = "CFG-SFIMU-ACCEL_RMSTHDL",                         .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  609, .title ="Accelerometer RMS threshold",
    .unit = "m/s^2",    .scale = "2^-6",    .scalefact = +0x1.0000000000000p-6 /* = 1.56250000000000000000e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuAccelFrequency =
{
    .id = 0x20060016, .name = "CFG-SFIMU-ACCEL_FREQUENCY",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  610, .title ="Nominal accelerometer sensor data sampling",
        .unit = "Hz"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuAccelLatency =
{
    .id = 0x30060017, .name = "CFG-SFIMU-ACCEL_LATENCY",                         .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  611, .title ="Accelerometer sensor data latency due to e.g. CAN bus",
        .unit = "ms"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuAccelAccuracy =
{
    .id = 0x30060018, .name = "CFG-SFIMU-ACCEL_ACCURACY",                        .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  612, .title ="Accelerometer sensor data accuracy",
    .unit = "m/s^2",    .scale = "1e-4",    .scalefact = +0x1.a36e2eb1c432dp-14 /* = 1.00000000000000004792e-04 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuImuI2cSclPio =
{
    .id = 0x2006001e, .name = "CFG-SFIMU-IMU_I2C_SCL_PIO",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  613, .title ="PIO of the IMU I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuImuI2cSdaPio =
{
    .id = 0x2006001f, .name = "CFG-SFIMU-IMU_I2C_SDA_PIO",                       .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  614, .title ="SDA PIO of the IMU I2C"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuAutoMntalgEna =
{
    .id = 0x10060027, .name = "CFG-SFIMU-AUTO_MNTALG_ENA",                       .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  615, .title ="Enable automatic IMU-mount alignment"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuImuMntalgYaw =
{
    .id = 0x4006002d, .name = "CFG-SFIMU-IMU_MNTALG_YAW",                        .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  616, .title ="User-defined IMU-mount yaw angle (0..360)",
    .unit = "deg",      .scale = "1e-2",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuImuMntalgPitch =
{
    .id = 0x3006002e, .name = "CFG-SFIMU-IMU_MNTALG_PITCH",                      .type = UBLOXCFG_TYPE_I2, .size = UBLOXCFG_SIZE_TWO,
    .order =  617, .title ="User-defined IMU-mount pitch angle (-90..90)",
    .unit = "deg",      .scale = "1e-2",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSfimuImuMntalgRoll =
{
    .id = 0x3006002f, .name = "CFG-SFIMU-IMU_MNTALG_ROLL",                       .type = UBLOXCFG_TYPE_I2, .size = UBLOXCFG_SIZE_TWO,
    .order =  618, .title ="User-defined IMU-mount roll angle (-180..180)",
    .unit = "deg",      .scale = "1e-2",    .scalefact = +0x1.47ae147ae147bp-7 /* = 1.00000000000000002082e-02 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalGpsEna =
{
    .id = 0x1031001f, .name = "CFG-SIGNAL-GPS_ENA",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  619, .title ="GPS enable"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalGpsL1caEna =
{
    .id = 0x10310001, .name = "CFG-SIGNAL-GPS_L1CA_ENA",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  620, .title ="GPS L1C/A"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalGpsL2cEna =
{
    .id = 0x10310003, .name = "CFG-SIGNAL-GPS_L2C_ENA",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  621, .title ="GPS L2C (only on u-blox F9 platform products)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalSbasEna =
{
    .id = 0x10310020, .name = "CFG-SIGNAL-SBAS_ENA",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  622, .title ="SBAS enable"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalSbasL1caEna =
{
    .id = 0x10310005, .name = "CFG-SIGNAL-SBAS_L1CA_ENA",                        .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  623, .title ="SBAS L1C/A"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalGalEna =
{
    .id = 0x10310021, .name = "CFG-SIGNAL-GAL_ENA",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  624, .title ="Galileo enable"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalGalE1Ena =
{
    .id = 0x10310007, .name = "CFG-SIGNAL-GAL_E1_ENA",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  625, .title ="Galileo E1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalGalE5bEna =
{
    .id = 0x1031000a, .name = "CFG-SIGNAL-GAL_E5B_ENA",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  626, .title ="Galileo E5b (only on u-blox F9 platform products)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalBdsEna =
{
    .id = 0x10310022, .name = "CFG-SIGNAL-BDS_ENA",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  627, .title ="BeiDou Enable"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalBdsB1Ena =
{
    .id = 0x1031000d, .name = "CFG-SIGNAL-BDS_B1_ENA",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  628, .title ="BeiDou B1I"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalBdsB2Ena =
{
    .id = 0x1031000e, .name = "CFG-SIGNAL-BDS_B2_ENA",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  629, .title ="BeiDou B2I (only on u-blox F9 platform products)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalQzssEna =
{
    .id = 0x10310024, .name = "CFG-SIGNAL-QZSS_ENA",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  630, .title ="QZSS enable"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalQzssL1caEna =
{
    .id = 0x10310012, .name = "CFG-SIGNAL-QZSS_L1CA_ENA",                        .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  631, .title ="QZSS L1C/A"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalQzssL1sEna =
{
    .id = 0x10310014, .name = "CFG-SIGNAL-QZSS_L1S_ENA",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  632, .title ="QZSS L1S"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalQzssL2cEna =
{
    .id = 0x10310015, .name = "CFG-SIGNAL-QZSS_L2C_ENA",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  633, .title ="QZSS L2C (only on u-blox F9 platform products)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalGloEna =
{
    .id = 0x10310025, .name = "CFG-SIGNAL-GLO_ENA",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  634, .title ="GLONASS enable"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalGloL1Ena =
{
    .id = 0x10310018, .name = "CFG-SIGNAL-GLO_L1_ENA",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  635, .title ="GLONASS L1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSignalGloL2Ena =
{
    .id = 0x1031001a, .name = "CFG-SIGNAL-GLO_L2_ENA",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  636, .title ="GLONASS L2 (only on u-blox F9 platform products)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpiMaxff =
{
    .id = 0x20640001, .name = "CFG-SPI-MAXFF",                                   .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  637, .title ="Number of bytes containing 0xFF to receive before switching off reception. Range: 0 (mechanism off) - 63"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpiCpolarity =
{
    .id = 0x10640002, .name = "CFG-SPI-CPOLARITY",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  638, .title ="Clock polarity select: 0: Active Hight Clock, SCLK idles low, 1: Active Low Clock, SCLK idles high"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpiCphase =
{
    .id = 0x10640003, .name = "CFG-SPI-CPHASE",                                  .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  639, .title ="Clock phase select: 0: Data captured on first edge of SCLK, 1: Data captured on second edge of SCLK"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpiExtendedtimeout =
{
    .id = 0x10640005, .name = "CFG-SPI-EXTENDEDTIMEOUT",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  640, .title ="Flag to disable timeouting the interface after 1.5s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpiEnabled =
{
    .id = 0x10640006, .name = "CFG-SPI-ENABLED",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  641, .title ="Flag to indicate if the SPI interface should be enabled"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpiinprotUbx =
{
    .id = 0x10790001, .name = "CFG-SPIINPROT-UBX",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  642, .title ="Flag to indicate if UBX should be an input protocol on SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpiinprotNmea =
{
    .id = 0x10790002, .name = "CFG-SPIINPROT-NMEA",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  643, .title ="Flag to indicate if NMEA should be an input protocol on SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpiinprotRtcm3x =
{
    .id = 0x10790004, .name = "CFG-SPIINPROT-RTCM3X",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  644, .title ="Flag to indicate if RTCM3X should be an input protocol on SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpioutprotUbx =
{
    .id = 0x107a0001, .name = "CFG-SPIOUTPROT-UBX",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  645, .title ="Flag to indicate if UBX should be an output protocol on SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpioutprotNmea =
{
    .id = 0x107a0002, .name = "CFG-SPIOUTPROT-NMEA",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  646, .title ="Flag to indicate if NMEA should be an output protocol on SPI"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgSpioutprotRtcm3x =
{
    .id = 0x107a0004, .name = "CFG-SPIOUTPROT-RTCM3X",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  647, .title ="Flag to indicate if RTCM3X should be an output protocol on SPI"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgTmodeMode_consts[3] =
{
    {
        .name = "DISABLED",          .value = "0",                 .val = { .E = 0 },
        .title = "Disabled"
    },
    {
        .name = "SURVEY_IN",         .value = "1",                 .val = { .E = 1 },
        .title = "Survey in"
    },
    {
        .name = "FIXED",             .value = "2",                 .val = { .E = 2 },
        .title = "Fixed mode (true ARP position information required)"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeMode =
{
    .id = 0x20030001, .name = "CFG-TMODE-MODE",                                  .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  648, .title ="Receiver mode",
    .nConsts =   3, .consts = ubloxcfg_cfgTmodeMode_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgTmodePosType_consts[2] =
{
    {
        .name = "ECEF",              .value = "0",                 .val = { .E = 0 },
        .title = "Position is ECEF"
    },
    {
        .name = "LLH",               .value = "1",                 .val = { .E = 1 },
        .title = "Position is Lat/Lon/Height"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodePosType =
{
    .id = 0x20030002, .name = "CFG-TMODE-POS_TYPE",                              .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  649, .title ="Determines whether the ARP position is given in ECEF or LAT/LON/HEIGHT?",
    .nConsts =   2, .consts = ubloxcfg_cfgTmodePosType_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeEcefX =
{
    .id = 0x40030003, .name = "CFG-TMODE-ECEF_X",                                .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  650, .title ="ECEF X coordinate of the ARP position.",
        .unit = "cm"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeEcefY =
{
    .id = 0x40030004, .name = "CFG-TMODE-ECEF_Y",                                .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  651, .title ="ECEF Y coordinate of the ARP position.",
        .unit = "cm"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeEcefZ =
{
    .id = 0x40030005, .name = "CFG-TMODE-ECEF_Z",                                .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  652, .title ="ECEF Z coordinate of the ARP position.",
        .unit = "cm"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeEcefXHp =
{
    .id = 0x20030006, .name = "CFG-TMODE-ECEF_X_HP",                             .type = UBLOXCFG_TYPE_I1, .size = UBLOXCFG_SIZE_ONE,
    .order =  653, .title ="High-precision ECEF X coordinate of the ARP position.",
    .unit = "mm",       .scale = "0.1",     .scalefact = +0x1.999999999999ap-4 /* = 1.00000000000000005551e-01 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeEcefYHp =
{
    .id = 0x20030007, .name = "CFG-TMODE-ECEF_Y_HP",                             .type = UBLOXCFG_TYPE_I1, .size = UBLOXCFG_SIZE_ONE,
    .order =  654, .title ="High-precision ECEF Y coordinate of the ARP position.",
    .unit = "mm",       .scale = "0.1",     .scalefact = +0x1.999999999999ap-4 /* = 1.00000000000000005551e-01 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeEcefZHp =
{
    .id = 0x20030008, .name = "CFG-TMODE-ECEF_Z_HP",                             .type = UBLOXCFG_TYPE_I1, .size = UBLOXCFG_SIZE_ONE,
    .order =  655, .title ="High-precision ECEF Z coordinate of the ARP position.",
    .unit = "mm",       .scale = "0.1",     .scalefact = +0x1.999999999999ap-4 /* = 1.00000000000000005551e-01 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeLat =
{
    .id = 0x40030009, .name = "CFG-TMODE-LAT",                                   .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  656, .title ="Latitude of the ARP position.",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeLon =
{
    .id = 0x4003000a, .name = "CFG-TMODE-LON",                                   .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  657, .title ="Longitude of the ARP position.",
    .unit = "deg",      .scale = "1e-7",    .scalefact = +0x1.ad7f29abcaf48p-24 /* = 9.99999999999999954748e-08 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeHeight =
{
    .id = 0x4003000b, .name = "CFG-TMODE-HEIGHT",                                .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  658, .title ="Height of the ARP position.",
        .unit = "cm"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeLatHp =
{
    .id = 0x2003000c, .name = "CFG-TMODE-LAT_HP",                                .type = UBLOXCFG_TYPE_I1, .size = UBLOXCFG_SIZE_ONE,
    .order =  659, .title ="High-precision latitude of the ARP position",
    .unit = "deg",      .scale = "1e-9",    .scalefact = +0x1.12e0be826d695p-30 /* = 1.00000000000000006228e-09 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeLonHp =
{
    .id = 0x2003000d, .name = "CFG-TMODE-LON_HP",                                .type = UBLOXCFG_TYPE_I1, .size = UBLOXCFG_SIZE_ONE,
    .order =  660, .title ="High-precision longitude of the ARP position.",
    .unit = "deg",      .scale = "1e-9",    .scalefact = +0x1.12e0be826d695p-30 /* = 1.00000000000000006228e-09 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeHeightHp =
{
    .id = 0x2003000e, .name = "CFG-TMODE-HEIGHT_HP",                             .type = UBLOXCFG_TYPE_I1, .size = UBLOXCFG_SIZE_ONE,
    .order =  661, .title ="High-precision height of the ARP position.",
    .unit = "mm",       .scale = "0.1",     .scalefact = +0x1.999999999999ap-4 /* = 1.00000000000000005551e-01 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeFixedPosAcc =
{
    .id = 0x4003000f, .name = "CFG-TMODE-FIXED_POS_ACC",                         .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  662, .title ="Fixed position 3D accuracy",
    .unit = "mm",       .scale = "0.1",     .scalefact = +0x1.999999999999ap-4 /* = 1.00000000000000005551e-01 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeSvinMinDur =
{
    .id = 0x40030010, .name = "CFG-TMODE-SVIN_MIN_DUR",                          .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  663, .title ="Survey-in minimum duration",
        .unit = "s"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTmodeSvinAccLimit =
{
    .id = 0x40030011, .name = "CFG-TMODE-SVIN_ACC_LIMIT",                        .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  664, .title ="Survey-in position accuracy limit",
    .unit = "mm",       .scale = "0.1",     .scalefact = +0x1.999999999999ap-4 /* = 1.00000000000000005551e-01 */,
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgTpPulseDef_consts[2] =
{
    {
        .name = "PERIOD",            .value = "0",                 .val = { .E = 0 },
        .title = "Time pulse period [us]"
    },
    {
        .name = "FREQ",              .value = "1",                 .val = { .E = 1 },
        .title = "Time pulse frequency [Hz]"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpPulseDef =
{
    .id = 0x20050023, .name = "CFG-TP-PULSE_DEF",                                .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  665, .title ="Determines whether the time pulse is interpreted as frequency or period",
    .nConsts =   2, .consts = ubloxcfg_cfgTpPulseDef_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgTpPulseLengthDef_consts[2] =
{
    {
        .name = "RATIO",             .value = "0",                 .val = { .E = 0 },
        .title = "Time pulse ratio"
    },
    {
        .name = "LENGTH",            .value = "1",                 .val = { .E = 1 },
        .title = "Time pulse length"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpPulseLengthDef =
{
    .id = 0x20050030, .name = "CFG-TP-PULSE_LENGTH_DEF",                         .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  666, .title ="Determines whether the time pulse length is interpreted as length[us] or pulse ratio[%]",
    .nConsts =   2, .consts = ubloxcfg_cfgTpPulseLengthDef_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpAntCabledelay =
{
    .id = 0x30050001, .name = "CFG-TP-ANT_CABLEDELAY",                           .type = UBLOXCFG_TYPE_I2, .size = UBLOXCFG_SIZE_TWO,
    .order =  667, .title ="Antenna cable delay",
    .unit = "s",        .scale = "0.000000001", .scalefact = +0x1.12e0be826d695p-30 /* = 1.00000000000000006228e-09 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpPeriodTp1 =
{
    .id = 0x40050002, .name = "CFG-TP-PERIOD_TP1",                               .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  668, .title ="Time pulse period (TP1)",
    .unit = "s",        .scale = "0.000001", .scalefact = +0x1.0c6f7a0b5ed8dp-20 /* = 9.99999999999999954748e-07 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpPeriodLockTp1 =
{
    .id = 0x40050003, .name = "CFG-TP-PERIOD_LOCK_TP1",                          .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  669, .title ="Time pulse period when locked to GNSS time (TP1)",
    .unit = "s",        .scale = "0.000001", .scalefact = +0x1.0c6f7a0b5ed8dp-20 /* = 9.99999999999999954748e-07 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpFreqTp1 =
{
    .id = 0x40050024, .name = "CFG-TP-FREQ_TP1",                                 .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  670, .title ="Time pulse frequency (TP1)",
        .unit = "Hz"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpFreqLockTp1 =
{
    .id = 0x40050025, .name = "CFG-TP-FREQ_LOCK_TP1",                            .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  671, .title ="Time pulse frequency when locked to GNSS time (TP1)",
        .unit = "Hz"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpLenTp1 =
{
    .id = 0x40050004, .name = "CFG-TP-LEN_TP1",                                  .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  672, .title ="Time pulse length (TP1)",
    .unit = "s",        .scale = "0.000001", .scalefact = +0x1.0c6f7a0b5ed8dp-20 /* = 9.99999999999999954748e-07 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpLenLockTp1 =
{
    .id = 0x40050005, .name = "CFG-TP-LEN_LOCK_TP1",                             .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  673, .title ="Time pulse length when locked to GNSS time (TP1)",
    .unit = "s",        .scale = "0.000001", .scalefact = +0x1.0c6f7a0b5ed8dp-20 /* = 9.99999999999999954748e-07 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpDutyTp1 =
{
    .id = 0x5005002a, .name = "CFG-TP-DUTY_TP1",                                 .type = UBLOXCFG_TYPE_R8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  674, .title ="Time pulse duty cycle (TP1)",
        .unit = "%"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpDutyLockTp1 =
{
    .id = 0x5005002b, .name = "CFG-TP-DUTY_LOCK_TP1",                            .type = UBLOXCFG_TYPE_R8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  675, .title ="Time pulse duty cycle when locked to GNSS time (TP1)",
        .unit = "%"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpUserDelayTp1 =
{
    .id = 0x40050006, .name = "CFG-TP-USER_DELAY_TP1",                           .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  676, .title ="User-configurable time pulse delay (TP1)",
    .unit = "s",        .scale = "0.000000001", .scalefact = +0x1.12e0be826d695p-30 /* = 1.00000000000000006228e-09 */,
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpTp1Ena =
{
    .id = 0x10050007, .name = "CFG-TP-TP1_ENA",                                  .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  677, .title ="Enable the first timepulse"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpSyncGnssTp1 =
{
    .id = 0x10050008, .name = "CFG-TP-SYNC_GNSS_TP1",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  678, .title ="Sync time pulse to GNSS time or local clock (TP1)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpUseLockedTp1 =
{
    .id = 0x10050009, .name = "CFG-TP-USE_LOCKED_TP1",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  679, .title ="Use locked parameters when possible (TP1)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpAlignToTowTp1 =
{
    .id = 0x1005000a, .name = "CFG-TP-ALIGN_TO_TOW_TP1",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  680, .title ="Align time pulse to top of second (TP1)"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpPolTp1 =
{
    .id = 0x1005000b, .name = "CFG-TP-POL_TP1",                                  .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  681, .title ="Set time pulse polarity (TP1)"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgTpTimegridTp1_consts[5] =
{
    {
        .name = "UTC",               .value = "0",                 .val = { .E = 0 },
        .title = "UTC time reference"
    },
    {
        .name = "GPS",               .value = "1",                 .val = { .E = 1 },
        .title = "GPS time reference"
    },
    {
        .name = "GLO",               .value = "2",                 .val = { .E = 2 },
        .title = "GLONASS time reference"
    },
    {
        .name = "BDS",               .value = "3",                 .val = { .E = 3 },
        .title = "BeiDou time reference"
    },
    {
        .name = "GAL",               .value = "4",                 .val = { .E = 4 },
        .title = "Galileo time reference"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTpTimegridTp1 =
{
    .id = 0x2005000c, .name = "CFG-TP-TIMEGRID_TP1",                             .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  682, .title ="Time grid to use (TP1)",
    .nConsts =   5, .consts = ubloxcfg_cfgTpTimegridTp1_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTxreadyEnabled =
{
    .id = 0x10a20001, .name = "CFG-TXREADY-ENABLED",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  683, .title ="Flag to indicate if TX ready pin mechanism should be enabled"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTxreadyPolarity =
{
    .id = 0x10a20002, .name = "CFG-TXREADY-POLARITY",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  684, .title ="The polarity of the TX ready pin: false:high-active, true:low-active"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTxreadyPin =
{
    .id = 0x20a20003, .name = "CFG-TXREADY-PIN",                                 .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  685, .title ="Pin number to use for the TX ready functionality"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTxreadyThreshold =
{
    .id = 0x30a20004, .name = "CFG-TXREADY-THRESHOLD",                           .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  686, .title ="Amount of data that should be ready on the interface before triggering the TX ready pin"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgTxreadyInterface_consts[2] =
{
    {
        .name = "I2C",               .value = "0",                 .val = { .E = 0 },
        .title = "I2C interface"
    },
    {
        .name = "SPI",               .value = "1",                 .val = { .E = 1 },
        .title = "SPI interface"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgTxreadyInterface =
{
    .id = 0x20a20005, .name = "CFG-TXREADY-INTERFACE",                           .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  687, .title ="Interface where the TX ready feature should be linked to",
    .nConsts =   2, .consts = ubloxcfg_cfgTxreadyInterface_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1Baudrate =
{
    .id = 0x40520001, .name = "CFG-UART1-BAUDRATE",                              .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  688, .title ="The baud rate that should be configured on the UART1"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUart1Stopbits_consts[4] =
{
    {
        .name = "HALF",              .value = "0",                 .val = { .E = 0 },
        .title = "0.5 stopbits"
    },
    {
        .name = "ONE",               .value = "1",                 .val = { .E = 1 },
        .title = "1.0 stopbits"
    },
    {
        .name = "ONEHALF",           .value = "2",                 .val = { .E = 2 },
        .title = "1.5 stopbits"
    },
    {
        .name = "TWO",               .value = "3",                 .val = { .E = 3 },
        .title = "2.0 stopbits"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1Stopbits =
{
    .id = 0x20520002, .name = "CFG-UART1-STOPBITS",                              .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  689, .title ="Number of stopbits that should be used on UART1",
    .nConsts =   4, .consts = ubloxcfg_cfgUart1Stopbits_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUart1Databits_consts[2] =
{
    {
        .name = "EIGHT",             .value = "0",                 .val = { .E = 0 },
        .title = "8 databits"
    },
    {
        .name = "SEVEN",             .value = "1",                 .val = { .E = 1 },
        .title = "7 databits"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1Databits =
{
    .id = 0x20520003, .name = "CFG-UART1-DATABITS",                              .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  690, .title ="Number of databits that should be used on UART1",
    .nConsts =   2, .consts = ubloxcfg_cfgUart1Databits_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUart1Parity_consts[3] =
{
    {
        .name = "NONE",              .value = "0",                 .val = { .E = 0 },
        .title = "No parity bit"
    },
    {
        .name = "ODD",               .value = "1",                 .val = { .E = 1 },
        .title = "Add an odd parity bit"
    },
    {
        .name = "EVEN",              .value = "2",                 .val = { .E = 2 },
        .title = "Add an even parity bit"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1Parity =
{
    .id = 0x20520004, .name = "CFG-UART1-PARITY",                                .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  691, .title ="Parity mode that should be used on UART1",
    .nConsts =   3, .consts = ubloxcfg_cfgUart1Parity_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1Enabled =
{
    .id = 0x10520005, .name = "CFG-UART1-ENABLED",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  692, .title ="Flag to indicate if the UART1 should be enabled"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1inprotUbx =
{
    .id = 0x10730001, .name = "CFG-UART1INPROT-UBX",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  693, .title ="Flag to indicate if UBX should be an input protocol on UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1inprotNmea =
{
    .id = 0x10730002, .name = "CFG-UART1INPROT-NMEA",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  694, .title ="Flag to indicate if NMEA should be an input protocol on UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1inprotRtcm3x =
{
    .id = 0x10730004, .name = "CFG-UART1INPROT-RTCM3X",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  695, .title ="Flag to indicate if RTCM3X should be an input protocol on UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1outprotUbx =
{
    .id = 0x10740001, .name = "CFG-UART1OUTPROT-UBX",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  696, .title ="Flag to indicate if UBX should be an output protocol on UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1outprotNmea =
{
    .id = 0x10740002, .name = "CFG-UART1OUTPROT-NMEA",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  697, .title ="Flag to indicate if NMEA should be an output protocol on UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart1outprotRtcm3x =
{
    .id = 0x10740004, .name = "CFG-UART1OUTPROT-RTCM3X",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  698, .title ="Flag to indicate if RTCM3X should be an output protocol on UART1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2Baudrate =
{
    .id = 0x40530001, .name = "CFG-UART2-BAUDRATE",                              .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  699, .title ="The baud rate that should be configured on the UART2"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUart2Stopbits_consts[4] =
{
    {
        .name = "HALF",              .value = "0",                 .val = { .E = 0 },
        .title = "0.5 stopbits"
    },
    {
        .name = "ONE",               .value = "1",                 .val = { .E = 1 },
        .title = "1.0 stopbits"
    },
    {
        .name = "ONEHALF",           .value = "2",                 .val = { .E = 2 },
        .title = "1.5 stopbits"
    },
    {
        .name = "TWO",               .value = "3",                 .val = { .E = 3 },
        .title = "2.0 stopbits"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2Stopbits =
{
    .id = 0x20530002, .name = "CFG-UART2-STOPBITS",                              .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  700, .title ="Number of stopbits that should be used on UART2",
    .nConsts =   4, .consts = ubloxcfg_cfgUart2Stopbits_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUart2Databits_consts[2] =
{
    {
        .name = "EIGHT",             .value = "0",                 .val = { .E = 0 },
        .title = "8 databits"
    },
    {
        .name = "SEVEN",             .value = "1",                 .val = { .E = 1 },
        .title = "7 databits"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2Databits =
{
    .id = 0x20530003, .name = "CFG-UART2-DATABITS",                              .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  701, .title ="Number of databits that should be used on UART2",
    .nConsts =   2, .consts = ubloxcfg_cfgUart2Databits_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUart2Parity_consts[3] =
{
    {
        .name = "NONE",              .value = "0",                 .val = { .E = 0 },
        .title = "No parity bit"
    },
    {
        .name = "ODD",               .value = "1",                 .val = { .E = 1 },
        .title = "Add an odd parity bit"
    },
    {
        .name = "EVEN",              .value = "2",                 .val = { .E = 2 },
        .title = "Add an even parity bit"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2Parity =
{
    .id = 0x20530004, .name = "CFG-UART2-PARITY",                                .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  702, .title ="Parity mode that should be used on UART2",
    .nConsts =   3, .consts = ubloxcfg_cfgUart2Parity_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2Enabled =
{
    .id = 0x10530005, .name = "CFG-UART2-ENABLED",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  703, .title ="Flag to indicate if the UART2 should be enabled"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2Remap =
{
    .id = 0x10530006, .name = "CFG-UART2-REMAP",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  704, .title ="UART2 Remapping"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2inprotUbx =
{
    .id = 0x10750001, .name = "CFG-UART2INPROT-UBX",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  705, .title ="Flag to indicate if UBX should be an input protocol on UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2inprotNmea =
{
    .id = 0x10750002, .name = "CFG-UART2INPROT-NMEA",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  706, .title ="Flag to indicate if NMEA should be an input protocol on UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2inprotRtcm3x =
{
    .id = 0x10750004, .name = "CFG-UART2INPROT-RTCM3X",                          .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  707, .title ="Flag to indicate if RTCM3X should be an input protocol on UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2outprotUbx =
{
    .id = 0x10760001, .name = "CFG-UART2OUTPROT-UBX",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  708, .title ="Flag to indicate if UBX should be an output protocol on UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2outprotNmea =
{
    .id = 0x10760002, .name = "CFG-UART2OUTPROT-NMEA",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  709, .title ="Flag to indicate if NMEA should be an output protocol on UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUart2outprotRtcm3x =
{
    .id = 0x10760004, .name = "CFG-UART2OUTPROT-RTCM3X",                         .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  710, .title ="Flag to indicate if RTCM3X should be an output protocol on UART2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbEnabled =
{
    .id = 0x10650001, .name = "CFG-USB-ENABLED",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  711, .title ="Flag to indicate if the USB interface should be enabled"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbSelfpow =
{
    .id = 0x10650002, .name = "CFG-USB-SELFPOW",                                 .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  712, .title ="Self-powered device"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbVendorId =
{
    .id = 0x3065000a, .name = "CFG-USB-VENDOR_ID",                               .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  713, .title ="Vendor ID"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbProductId =
{
    .id = 0x3065000b, .name = "CFG-USB-PRODUCT_ID",                              .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  714, .title ="Vendor ID"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbPower =
{
    .id = 0x3065000c, .name = "CFG-USB-POWER",                                   .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  715, .title ="Power consumption",
        .unit = "mA"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbVendorStr0 =
{
    .id = 0x5065000d, .name = "CFG-USB-VENDOR_STR0",                             .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  716, .title ="Vendor string characters 0-7"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbVendorStr1 =
{
    .id = 0x5065000e, .name = "CFG-USB-VENDOR_STR1",                             .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  717, .title ="Vendor string characters 8-15"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbVendorStr2 =
{
    .id = 0x5065000f, .name = "CFG-USB-VENDOR_STR2",                             .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  718, .title ="Vendor string characters 16-23"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbVendorStr3 =
{
    .id = 0x50650010, .name = "CFG-USB-VENDOR_STR3",                             .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  719, .title ="Vendor string characters 24-31"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbProductStr0 =
{
    .id = 0x50650011, .name = "CFG-USB-PRODUCT_STR0",                            .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  720, .title ="Product string characters 0-7"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbProductStr1 =
{
    .id = 0x50650012, .name = "CFG-USB-PRODUCT_STR1",                            .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  721, .title ="Product string characters 8-15"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbProductStr2 =
{
    .id = 0x50650013, .name = "CFG-USB-PRODUCT_STR2",                            .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  722, .title ="Product string characters 16-23"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbProductStr3 =
{
    .id = 0x50650014, .name = "CFG-USB-PRODUCT_STR3",                            .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  723, .title ="Product string characters 24-31"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbSerialNoStr0 =
{
    .id = 0x50650015, .name = "CFG-USB-SERIAL_NO_STR0",                          .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  724, .title ="Serial number string characters 0-7"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbSerialNoStr1 =
{
    .id = 0x50650016, .name = "CFG-USB-SERIAL_NO_STR1",                          .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  725, .title ="Serial number string characters 8-15"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbSerialNoStr2 =
{
    .id = 0x50650017, .name = "CFG-USB-SERIAL_NO_STR2",                          .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  726, .title ="Serial number string characters 16-23"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbSerialNoStr3 =
{
    .id = 0x50650018, .name = "CFG-USB-SERIAL_NO_STR3",                          .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  727, .title ="Serial number string characters 24-31"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbinprotUbx =
{
    .id = 0x10770001, .name = "CFG-USBINPROT-UBX",                               .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  728, .title ="Flag to indicate if UBX should be an input protocol on USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbinprotNmea =
{
    .id = 0x10770002, .name = "CFG-USBINPROT-NMEA",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  729, .title ="Flag to indicate if NMEA should be an input protocol on USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsbinprotRtcm3x =
{
    .id = 0x10770004, .name = "CFG-USBINPROT-RTCM3X",                            .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  730, .title ="Flag to indicate if RTCM3X should be an input protocol on USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsboutprotUbx =
{
    .id = 0x10780001, .name = "CFG-USBOUTPROT-UBX",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  731, .title ="Flag to indicate if UBX should be an output protocol on USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsboutprotNmea =
{
    .id = 0x10780002, .name = "CFG-USBOUTPROT-NMEA",                             .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  732, .title ="Flag to indicate if NMEA should be an output protocol on USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUsboutprotRtcm3x =
{
    .id = 0x10780004, .name = "CFG-USBOUTPROT-RTCM3X",                           .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  733, .title ="Flag to indicate if RTCM3X should be an output protocol on USB"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestL =
{
    .id = 0x10fe0001, .name = "CFG-UBLOXCFGTEST-L",                              .type = UBLOXCFG_TYPE_L,  .size = UBLOXCFG_SIZE_BIT,
    .order =  734, .title ="ubloxcfg library test item type L"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestU1 =
{
    .id = 0x20fe0011, .name = "CFG-UBLOXCFGTEST-U1",                             .type = UBLOXCFG_TYPE_U1, .size = UBLOXCFG_SIZE_ONE,
    .order =  735, .title ="ubloxcfg library test item type U1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestU2 =
{
    .id = 0x30fe0012, .name = "CFG-UBLOXCFGTEST-U2",                             .type = UBLOXCFG_TYPE_U2, .size = UBLOXCFG_SIZE_TWO,
    .order =  736, .title ="ubloxcfg library test item type U2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestU4 =
{
    .id = 0x40fe0013, .name = "CFG-UBLOXCFGTEST-U4",                             .type = UBLOXCFG_TYPE_U4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  737, .title ="ubloxcfg library test item type U4"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestU8 =
{
    .id = 0x50fe0014, .name = "CFG-UBLOXCFGTEST-U8",                             .type = UBLOXCFG_TYPE_U8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  738, .title ="ubloxcfg library test item type U8"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestI1 =
{
    .id = 0x20fe0021, .name = "CFG-UBLOXCFGTEST-I1",                             .type = UBLOXCFG_TYPE_I1, .size = UBLOXCFG_SIZE_ONE,
    .order =  739, .title ="ubloxcfg library test item type I1"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestI2 =
{
    .id = 0x30fe0022, .name = "CFG-UBLOXCFGTEST-I2",                             .type = UBLOXCFG_TYPE_I2, .size = UBLOXCFG_SIZE_TWO,
    .order =  740, .title ="ubloxcfg library test item type I2"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestI4 =
{
    .id = 0x40fe0023, .name = "CFG-UBLOXCFGTEST-I4",                             .type = UBLOXCFG_TYPE_I4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  741, .title ="ubloxcfg library test item type I4"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestI8 =
{
    .id = 0x50fe0024, .name = "CFG-UBLOXCFGTEST-I8",                             .type = UBLOXCFG_TYPE_I8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  742, .title ="ubloxcfg library test item type I8"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUbloxcfgtestX1_consts[3] =
{
    {
        .name = "FIRST",             .value = "0x01",              .val = { .X = 0x01 },
        .title = "first bit (LSB)"
    },
    {
        .name = "SECOND",            .value = "0x02",              .val = { .X = 0x02 },
        .title = "second bit"
    },
    {
        .name = "LAST",              .value = "0x80",              .val = { .X = 0x80 },
        .title = "last bit (MSB)"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestX1 =
{
    .id = 0x20fe0031, .name = "CFG-UBLOXCFGTEST-X1",                             .type = UBLOXCFG_TYPE_X1, .size = UBLOXCFG_SIZE_ONE,
    .order =  743, .title ="ubloxcfg library test item type X1",
    .nConsts =   3, .consts = ubloxcfg_cfgUbloxcfgtestX1_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUbloxcfgtestX2_consts[3] =
{
    {
        .name = "FIRST",             .value = "0x0001",            .val = { .X = 0x0001 },
        .title = "first bit (LSB)"
    },
    {
        .name = "SECOND",            .value = "0x0002",            .val = { .X = 0x0002 },
        .title = "second bit"
    },
    {
        .name = "LAST",              .value = "0x8000",            .val = { .X = 0x8000 },
        .title = "last bit (MSB)"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestX2 =
{
    .id = 0x30fe0032, .name = "CFG-UBLOXCFGTEST-X2",                             .type = UBLOXCFG_TYPE_X2, .size = UBLOXCFG_SIZE_TWO,
    .order =  744, .title ="ubloxcfg library test item type X2",
    .nConsts =   3, .consts = ubloxcfg_cfgUbloxcfgtestX2_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUbloxcfgtestX4_consts[3] =
{
    {
        .name = "FIRST",             .value = "0x00000001",        .val = { .X = 0x00000001 },
        .title = "first bit (LSB)"
    },
    {
        .name = "SECOND",            .value = "0x00000002",        .val = { .X = 0x00000002 },
        .title = "second bit"
    },
    {
        .name = "LAST",              .value = "0x80000000",        .val = { .X = 0x80000000 },
        .title = "last bit (MSB)"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestX4 =
{
    .id = 0x40fe0033, .name = "CFG-UBLOXCFGTEST-X4",                             .type = UBLOXCFG_TYPE_X4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  745, .title ="ubloxcfg library test item type X4",
    .nConsts =   3, .consts = ubloxcfg_cfgUbloxcfgtestX4_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUbloxcfgtestX8_consts[3] =
{
    {
        .name = "FIRST",             .value = "0x0000000000000001", .val = { .X = 0x0000000000000001 },
        .title = "first bit (LSB)"
    },
    {
        .name = "SECOND",            .value = "0x0000000000000002", .val = { .X = 0x0000000000000002 },
        .title = "second bit"
    },
    {
        .name = "LAST",              .value = "0x8000000000000000", .val = { .X = 0x8000000000000000 },
        .title = "last bit (MSB)"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestX8 =
{
    .id = 0x50fe0034, .name = "CFG-UBLOXCFGTEST-X8",                             .type = UBLOXCFG_TYPE_X8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  746, .title ="ubloxcfg library test item type X8",
    .nConsts =   3, .consts = ubloxcfg_cfgUbloxcfgtestX8_consts
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestR4 =
{
    .id = 0x40fe0041, .name = "CFG-UBLOXCFGTEST-R4",                             .type = UBLOXCFG_TYPE_R4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  747, .title ="ubloxcfg library test item type R4"
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestR8 =
{
    .id = 0x50fe0042, .name = "CFG-UBLOXCFGTEST-R8",                             .type = UBLOXCFG_TYPE_R8, .size = UBLOXCFG_SIZE_EIGHT,
    .order =  748, .title ="ubloxcfg library test item type R8"
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUbloxcfgtestE1_consts[5] =
{
    {
        .name = "ONE",               .value = "1",                 .val = { .E = 1 },
        .title = "test value 1"
    },
    {
        .name = "TWO",               .value = "2",                 .val = { .E = 2 },
        .title = "test value 2"
    },
    {
        .name = "THREE",             .value = "3",                 .val = { .E = 3 },
        .title = "test value 3"
    },
    {
        .name = "MINUS_ONE",         .value = "-1",                .val = { .E = -1 },
        .title = "test value -1"
    },
    {
        .name = "FOUR_HEX",          .value = "0x04",              .val = { .E = 0x04 },
        .title = "test value 0x04"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestE1 =
{
    .id = 0x20fe0041, .name = "CFG-UBLOXCFGTEST-E1",                             .type = UBLOXCFG_TYPE_E1, .size = UBLOXCFG_SIZE_ONE,
    .order =  749, .title ="ubloxcfg library test item type E1",
    .nConsts =   5, .consts = ubloxcfg_cfgUbloxcfgtestE1_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUbloxcfgtestE2_consts[5] =
{
    {
        .name = "ONE",               .value = "1",                 .val = { .E = 1 },
        .title = "test value 1"
    },
    {
        .name = "TWO",               .value = "2",                 .val = { .E = 2 },
        .title = "test value 2"
    },
    {
        .name = "THREE",             .value = "3",                 .val = { .E = 3 },
        .title = "test value 3"
    },
    {
        .name = "MINUS_ONE",         .value = "-1",                .val = { .E = -1 },
        .title = "test value -1"
    },
    {
        .name = "FOUR_HEX",          .value = "0x0004",            .val = { .E = 0x0004 },
        .title = "test value 0x0004"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestE2 =
{
    .id = 0x30fe0042, .name = "CFG-UBLOXCFGTEST-E2",                             .type = UBLOXCFG_TYPE_E2, .size = UBLOXCFG_SIZE_TWO,
    .order =  750, .title ="ubloxcfg library test item type E2",
    .nConsts =   5, .consts = ubloxcfg_cfgUbloxcfgtestE2_consts
};

static const UBLOXCFG_CONST_t ubloxcfg_cfgUbloxcfgtestE4_consts[5] =
{
    {
        .name = "ONE",               .value = "1",                 .val = { .E = 1 },
        .title = "test value 1"
    },
    {
        .name = "TWO",               .value = "2",                 .val = { .E = 2 },
        .title = "test value 2"
    },
    {
        .name = "THREE",             .value = "3",                 .val = { .E = 3 },
        .title = "test value 3"
    },
    {
        .name = "MINUS_ONE",         .value = "-1",                .val = { .E = -1 },
        .title = "test value -1"
    },
    {
        .name = "FOUR_HEX",          .value = "0x00000004",        .val = { .E = 0x00000004 },
        .title = "test value 0x00000004"
    }
};

static const UBLOXCFG_ITEM_t ubloxcfg_cfgUbloxcfgtestE4 =
{
    .id = 0x40fe0043, .name = "CFG-UBLOXCFGTEST-E4",                             .type = UBLOXCFG_TYPE_E4, .size = UBLOXCFG_SIZE_FOUR,
    .order =  751, .title ="ubloxcfg library test item type E4",
    .nConsts =   5, .consts = ubloxcfg_cfgUbloxcfgtestE4_consts
};

static const UBLOXCFG_ITEM_t * const ubloxcfg_allItems[751] =
{
    &ubloxcfg_cfgBdsUsePrn1To5,
    &ubloxcfg_cfgGeofenceConflvl,
    &ubloxcfg_cfgGeofenceUsePio,
    &ubloxcfg_cfgGeofencePinpol,
    &ubloxcfg_cfgGeofencePin,
    &ubloxcfg_cfgGeofenceUseFence1,
    &ubloxcfg_cfgGeofenceFence1Lat,
    &ubloxcfg_cfgGeofenceFence1Lon,
    &ubloxcfg_cfgGeofenceFence1Rad,
    &ubloxcfg_cfgGeofenceUseFence2,
    &ubloxcfg_cfgGeofenceFence2Lat,
    &ubloxcfg_cfgGeofenceFence2Lon,
    &ubloxcfg_cfgGeofenceFence2Rad,
    &ubloxcfg_cfgGeofenceUseFence3,
    &ubloxcfg_cfgGeofenceFence3Lat,
    &ubloxcfg_cfgGeofenceFence3Lon,
    &ubloxcfg_cfgGeofenceFence3Rad,
    &ubloxcfg_cfgGeofenceUseFence4,
    &ubloxcfg_cfgGeofenceFence4Lat,
    &ubloxcfg_cfgGeofenceFence4Lon,
    &ubloxcfg_cfgGeofenceFence4Rad,
    &ubloxcfg_cfgHwAntCfgVoltctrl,
    &ubloxcfg_cfgHwAntCfgShortdet,
    &ubloxcfg_cfgHwAntCfgShortdetPol,
    &ubloxcfg_cfgHwAntCfgOpendet,
    &ubloxcfg_cfgHwAntCfgOpendetPol,
    &ubloxcfg_cfgHwAntCfgPwrdown,
    &ubloxcfg_cfgHwAntCfgPwrdownPol,
    &ubloxcfg_cfgHwAntCfgRecover,
    &ubloxcfg_cfgHwAntSupSwitchPin,
    &ubloxcfg_cfgHwAntSupShortPin,
    &ubloxcfg_cfgHwAntSupOpenPin,
    &ubloxcfg_cfgHwAntSupEngine,
    &ubloxcfg_cfgHwAntSupShortThr,
    &ubloxcfg_cfgHwAntSupOpenThr,
    &ubloxcfg_cfgI2cAddress,
    &ubloxcfg_cfgI2cExtendedtimeout,
    &ubloxcfg_cfgI2cEnabled,
    &ubloxcfg_cfgI2cinprotUbx,
    &ubloxcfg_cfgI2cinprotNmea,
    &ubloxcfg_cfgI2cinprotRtcm3x,
    &ubloxcfg_cfgI2coutprotUbx,
    &ubloxcfg_cfgI2coutprotNmea,
    &ubloxcfg_cfgI2coutprotRtcm3x,
    &ubloxcfg_cfgInfmsgUbxI2c,
    &ubloxcfg_cfgInfmsgUbxUart1,
    &ubloxcfg_cfgInfmsgUbxUart2,
    &ubloxcfg_cfgInfmsgUbxUsb,
    &ubloxcfg_cfgInfmsgUbxSpi,
    &ubloxcfg_cfgInfmsgNmeaI2c,
    &ubloxcfg_cfgInfmsgNmeaUart1,
    &ubloxcfg_cfgInfmsgNmeaUart2,
    &ubloxcfg_cfgInfmsgNmeaUsb,
    &ubloxcfg_cfgInfmsgNmeaSpi,
    &ubloxcfg_cfgItfmBbthreshold,
    &ubloxcfg_cfgItfmCwthreshold,
    &ubloxcfg_cfgItfmEnable,
    &ubloxcfg_cfgItfmAntsetting,
    &ubloxcfg_cfgItfmEnableAux,
    &ubloxcfg_cfgLogfilterRecordEna,
    &ubloxcfg_cfgLogfilterOncePerWakeUpEna,
    &ubloxcfg_cfgLogfilterApplyAllFilters,
    &ubloxcfg_cfgLogfilterMinInterval,
    &ubloxcfg_cfgLogfilterTimeThrs,
    &ubloxcfg_cfgLogfilterSpeedThrs,
    &ubloxcfg_cfgLogfilterPositionThrs,
    &ubloxcfg_cfgMotGnssspeedThrs,
    &ubloxcfg_cfgMotGnssdistThrs,
    &ubloxcfg_cfgMsgoutNmeaIdDtmUart1,
    &ubloxcfg_cfgMsgoutNmeaIdDtmUart2,
    &ubloxcfg_cfgMsgoutNmeaIdDtmSpi,
    &ubloxcfg_cfgMsgoutNmeaIdDtmI2c,
    &ubloxcfg_cfgMsgoutNmeaIdDtmUsb,
    &ubloxcfg_cfgMsgoutNmeaIdGbsUart1,
    &ubloxcfg_cfgMsgoutNmeaIdGbsUart2,
    &ubloxcfg_cfgMsgoutNmeaIdGbsSpi,
    &ubloxcfg_cfgMsgoutNmeaIdGbsI2c,
    &ubloxcfg_cfgMsgoutNmeaIdGbsUsb,
    &ubloxcfg_cfgMsgoutNmeaIdGgaUart1,
    &ubloxcfg_cfgMsgoutNmeaIdGgaUart2,
    &ubloxcfg_cfgMsgoutNmeaIdGgaSpi,
    &ubloxcfg_cfgMsgoutNmeaIdGgaI2c,
    &ubloxcfg_cfgMsgoutNmeaIdGgaUsb,
    &ubloxcfg_cfgMsgoutNmeaIdGllUart1,
    &ubloxcfg_cfgMsgoutNmeaIdGllUart2,
    &ubloxcfg_cfgMsgoutNmeaIdGllSpi,
    &ubloxcfg_cfgMsgoutNmeaIdGllI2c,
    &ubloxcfg_cfgMsgoutNmeaIdGllUsb,
    &ubloxcfg_cfgMsgoutNmeaIdGnsUart1,
    &ubloxcfg_cfgMsgoutNmeaIdGnsUart2,
    &ubloxcfg_cfgMsgoutNmeaIdGnsSpi,
    &ubloxcfg_cfgMsgoutNmeaIdGnsI2c,
    &ubloxcfg_cfgMsgoutNmeaIdGnsUsb,
    &ubloxcfg_cfgMsgoutNmeaIdGrsUart1,
    &ubloxcfg_cfgMsgoutNmeaIdGrsUart2,
    &ubloxcfg_cfgMsgoutNmeaIdGrsSpi,
    &ubloxcfg_cfgMsgoutNmeaIdGrsI2c,
    &ubloxcfg_cfgMsgoutNmeaIdGrsUsb,
    &ubloxcfg_cfgMsgoutNmeaIdGsaUart1,
    &ubloxcfg_cfgMsgoutNmeaIdGsaUart2,
    &ubloxcfg_cfgMsgoutNmeaIdGsaSpi,
    &ubloxcfg_cfgMsgoutNmeaIdGsaI2c,
    &ubloxcfg_cfgMsgoutNmeaIdGsaUsb,
    &ubloxcfg_cfgMsgoutNmeaIdGstUart1,
    &ubloxcfg_cfgMsgoutNmeaIdGstUart2,
    &ubloxcfg_cfgMsgoutNmeaIdGstSpi,
    &ubloxcfg_cfgMsgoutNmeaIdGstI2c,
    &ubloxcfg_cfgMsgoutNmeaIdGstUsb,
    &ubloxcfg_cfgMsgoutNmeaIdGsvUart1,
    &ubloxcfg_cfgMsgoutNmeaIdGsvUart2,
    &ubloxcfg_cfgMsgoutNmeaIdGsvSpi,
    &ubloxcfg_cfgMsgoutNmeaIdGsvI2c,
    &ubloxcfg_cfgMsgoutNmeaIdGsvUsb,
    &ubloxcfg_cfgMsgoutNmeaIdRlmUart1,
    &ubloxcfg_cfgMsgoutNmeaIdRlmUart2,
    &ubloxcfg_cfgMsgoutNmeaIdRlmSpi,
    &ubloxcfg_cfgMsgoutNmeaIdRlmI2c,
    &ubloxcfg_cfgMsgoutNmeaIdRlmUsb,
    &ubloxcfg_cfgMsgoutNmeaIdRmcUart1,
    &ubloxcfg_cfgMsgoutNmeaIdRmcUart2,
    &ubloxcfg_cfgMsgoutNmeaIdRmcSpi,
    &ubloxcfg_cfgMsgoutNmeaIdRmcI2c,
    &ubloxcfg_cfgMsgoutNmeaIdRmcUsb,
    &ubloxcfg_cfgMsgoutNmeaIdVlwUart1,
    &ubloxcfg_cfgMsgoutNmeaIdVlwUart2,
    &ubloxcfg_cfgMsgoutNmeaIdVlwSpi,
    &ubloxcfg_cfgMsgoutNmeaIdVlwI2c,
    &ubloxcfg_cfgMsgoutNmeaIdVlwUsb,
    &ubloxcfg_cfgMsgoutNmeaIdVtgUart1,
    &ubloxcfg_cfgMsgoutNmeaIdVtgUart2,
    &ubloxcfg_cfgMsgoutNmeaIdVtgSpi,
    &ubloxcfg_cfgMsgoutNmeaIdVtgI2c,
    &ubloxcfg_cfgMsgoutNmeaIdVtgUsb,
    &ubloxcfg_cfgMsgoutNmeaIdZdaUart1,
    &ubloxcfg_cfgMsgoutNmeaIdZdaUart2,
    &ubloxcfg_cfgMsgoutNmeaIdZdaSpi,
    &ubloxcfg_cfgMsgoutNmeaIdZdaI2c,
    &ubloxcfg_cfgMsgoutNmeaIdZdaUsb,
    &ubloxcfg_cfgMsgoutPubxIdPolypUart1,
    &ubloxcfg_cfgMsgoutPubxIdPolypUart2,
    &ubloxcfg_cfgMsgoutPubxIdPolypSpi,
    &ubloxcfg_cfgMsgoutPubxIdPolypI2c,
    &ubloxcfg_cfgMsgoutPubxIdPolypUsb,
    &ubloxcfg_cfgMsgoutPubxIdPolysUart1,
    &ubloxcfg_cfgMsgoutPubxIdPolysUart2,
    &ubloxcfg_cfgMsgoutPubxIdPolysSpi,
    &ubloxcfg_cfgMsgoutPubxIdPolysI2c,
    &ubloxcfg_cfgMsgoutPubxIdPolysUsb,
    &ubloxcfg_cfgMsgoutPubxIdPolytUart1,
    &ubloxcfg_cfgMsgoutPubxIdPolytUart2,
    &ubloxcfg_cfgMsgoutPubxIdPolytSpi,
    &ubloxcfg_cfgMsgoutPubxIdPolytI2c,
    &ubloxcfg_cfgMsgoutPubxIdPolytUsb,
    &ubloxcfg_cfgMsgoutRtcm3xType1005Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1005Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1005Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1005I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1005Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType1074Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1074Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1074Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1074I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1074Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType1077Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1077Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1077Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1077I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1077Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType1084Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1084Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1084Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1084I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1084Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType1087Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1087Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1087Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1087I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1087Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType1094Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1094Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1094Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1094I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1094Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType1097Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1097Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1097Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1097I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1097Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType1124Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1124Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1124Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1124I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1124Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType1127Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1127Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1127Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1127I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1127Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType1230Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType1230Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType1230Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType1230I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType1230Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType40720Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType40720Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType40720Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType40720I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType40720Usb,
    &ubloxcfg_cfgMsgoutRtcm3xType40721Uart1,
    &ubloxcfg_cfgMsgoutRtcm3xType40721Uart2,
    &ubloxcfg_cfgMsgoutRtcm3xType40721Spi,
    &ubloxcfg_cfgMsgoutRtcm3xType40721I2c,
    &ubloxcfg_cfgMsgoutRtcm3xType40721Usb,
    &ubloxcfg_cfgMsgoutUbxEsfAlgUart1,
    &ubloxcfg_cfgMsgoutUbxEsfAlgUart2,
    &ubloxcfg_cfgMsgoutUbxEsfAlgSpi,
    &ubloxcfg_cfgMsgoutUbxEsfAlgI2c,
    &ubloxcfg_cfgMsgoutUbxEsfAlgUsb,
    &ubloxcfg_cfgMsgoutUbxEsfInsUart1,
    &ubloxcfg_cfgMsgoutUbxEsfInsUart2,
    &ubloxcfg_cfgMsgoutUbxEsfInsSpi,
    &ubloxcfg_cfgMsgoutUbxEsfInsI2c,
    &ubloxcfg_cfgMsgoutUbxEsfInsUsb,
    &ubloxcfg_cfgMsgoutUbxEsfMeasUart1,
    &ubloxcfg_cfgMsgoutUbxEsfMeasUart2,
    &ubloxcfg_cfgMsgoutUbxEsfMeasSpi,
    &ubloxcfg_cfgMsgoutUbxEsfMeasI2c,
    &ubloxcfg_cfgMsgoutUbxEsfMeasUsb,
    &ubloxcfg_cfgMsgoutUbxEsfRawUart1,
    &ubloxcfg_cfgMsgoutUbxEsfRawUart2,
    &ubloxcfg_cfgMsgoutUbxEsfRawSpi,
    &ubloxcfg_cfgMsgoutUbxEsfRawI2c,
    &ubloxcfg_cfgMsgoutUbxEsfRawUsb,
    &ubloxcfg_cfgMsgoutUbxEsfStatusUart1,
    &ubloxcfg_cfgMsgoutUbxEsfStatusUart2,
    &ubloxcfg_cfgMsgoutUbxEsfStatusSpi,
    &ubloxcfg_cfgMsgoutUbxEsfStatusI2c,
    &ubloxcfg_cfgMsgoutUbxEsfStatusUsb,
    &ubloxcfg_cfgMsgoutUbxLogInfoUart1,
    &ubloxcfg_cfgMsgoutUbxLogInfoUart2,
    &ubloxcfg_cfgMsgoutUbxLogInfoSpi,
    &ubloxcfg_cfgMsgoutUbxLogInfoI2c,
    &ubloxcfg_cfgMsgoutUbxLogInfoUsb,
    &ubloxcfg_cfgMsgoutUbxMonCommsUart1,
    &ubloxcfg_cfgMsgoutUbxMonCommsUart2,
    &ubloxcfg_cfgMsgoutUbxMonCommsSpi,
    &ubloxcfg_cfgMsgoutUbxMonCommsI2c,
    &ubloxcfg_cfgMsgoutUbxMonCommsUsb,
    &ubloxcfg_cfgMsgoutUbxMonHw2Uart1,
    &ubloxcfg_cfgMsgoutUbxMonHw2Uart2,
    &ubloxcfg_cfgMsgoutUbxMonHw2Spi,
    &ubloxcfg_cfgMsgoutUbxMonHw2I2c,
    &ubloxcfg_cfgMsgoutUbxMonHw2Usb,
    &ubloxcfg_cfgMsgoutUbxMonHw3Uart1,
    &ubloxcfg_cfgMsgoutUbxMonHw3Uart2,
    &ubloxcfg_cfgMsgoutUbxMonHw3Spi,
    &ubloxcfg_cfgMsgoutUbxMonHw3I2c,
    &ubloxcfg_cfgMsgoutUbxMonHw3Usb,
    &ubloxcfg_cfgMsgoutUbxMonHwUart1,
    &ubloxcfg_cfgMsgoutUbxMonHwUart2,
    &ubloxcfg_cfgMsgoutUbxMonHwSpi,
    &ubloxcfg_cfgMsgoutUbxMonHwI2c,
    &ubloxcfg_cfgMsgoutUbxMonHwUsb,
    &ubloxcfg_cfgMsgoutUbxMonIoUart1,
    &ubloxcfg_cfgMsgoutUbxMonIoUart2,
    &ubloxcfg_cfgMsgoutUbxMonIoSpi,
    &ubloxcfg_cfgMsgoutUbxMonIoI2c,
    &ubloxcfg_cfgMsgoutUbxMonIoUsb,
    &ubloxcfg_cfgMsgoutUbxMonMsgppUart1,
    &ubloxcfg_cfgMsgoutUbxMonMsgppUart2,
    &ubloxcfg_cfgMsgoutUbxMonMsgppSpi,
    &ubloxcfg_cfgMsgoutUbxMonMsgppI2c,
    &ubloxcfg_cfgMsgoutUbxMonMsgppUsb,
    &ubloxcfg_cfgMsgoutUbxMonRfUart1,
    &ubloxcfg_cfgMsgoutUbxMonRfUart2,
    &ubloxcfg_cfgMsgoutUbxMonRfSpi,
    &ubloxcfg_cfgMsgoutUbxMonRfI2c,
    &ubloxcfg_cfgMsgoutUbxMonRfUsb,
    &ubloxcfg_cfgMsgoutUbxMonRxbufUart1,
    &ubloxcfg_cfgMsgoutUbxMonRxbufUart2,
    &ubloxcfg_cfgMsgoutUbxMonRxbufSpi,
    &ubloxcfg_cfgMsgoutUbxMonRxbufI2c,
    &ubloxcfg_cfgMsgoutUbxMonRxbufUsb,
    &ubloxcfg_cfgMsgoutUbxMonRxrUart1,
    &ubloxcfg_cfgMsgoutUbxMonRxrUart2,
    &ubloxcfg_cfgMsgoutUbxMonRxrSpi,
    &ubloxcfg_cfgMsgoutUbxMonRxrI2c,
    &ubloxcfg_cfgMsgoutUbxMonRxrUsb,
    &ubloxcfg_cfgMsgoutUbxMonSpanUart1,
    &ubloxcfg_cfgMsgoutUbxMonSpanUart2,
    &ubloxcfg_cfgMsgoutUbxMonSpanSpi,
    &ubloxcfg_cfgMsgoutUbxMonSpanI2c,
    &ubloxcfg_cfgMsgoutUbxMonSpanUsb,
    &ubloxcfg_cfgMsgoutUbxMonTempUart1,
    &ubloxcfg_cfgMsgoutUbxMonTempUart2,
    &ubloxcfg_cfgMsgoutUbxMonTempSpi,
    &ubloxcfg_cfgMsgoutUbxMonTempI2c,
    &ubloxcfg_cfgMsgoutUbxMonTempUsb,
    &ubloxcfg_cfgMsgoutUbxMonTxbufUart1,
    &ubloxcfg_cfgMsgoutUbxMonTxbufUart2,
    &ubloxcfg_cfgMsgoutUbxMonTxbufSpi,
    &ubloxcfg_cfgMsgoutUbxMonTxbufI2c,
    &ubloxcfg_cfgMsgoutUbxMonTxbufUsb,
    &ubloxcfg_cfgMsgoutUbxNavAopstatusUart1,
    &ubloxcfg_cfgMsgoutUbxNavAopstatusUart2,
    &ubloxcfg_cfgMsgoutUbxNavAopstatusSpi,
    &ubloxcfg_cfgMsgoutUbxNavAopstatusI2c,
    &ubloxcfg_cfgMsgoutUbxNavAopstatusUsb,
    &ubloxcfg_cfgMsgoutUbxNavAttUart1,
    &ubloxcfg_cfgMsgoutUbxNavAttUart2,
    &ubloxcfg_cfgMsgoutUbxNavAttSpi,
    &ubloxcfg_cfgMsgoutUbxNavAttI2c,
    &ubloxcfg_cfgMsgoutUbxNavAttUsb,
    &ubloxcfg_cfgMsgoutUbxNavClockUart1,
    &ubloxcfg_cfgMsgoutUbxNavClockUart2,
    &ubloxcfg_cfgMsgoutUbxNavClockSpi,
    &ubloxcfg_cfgMsgoutUbxNavClockI2c,
    &ubloxcfg_cfgMsgoutUbxNavClockUsb,
    &ubloxcfg_cfgMsgoutUbxNavCovUart1,
    &ubloxcfg_cfgMsgoutUbxNavCovUart2,
    &ubloxcfg_cfgMsgoutUbxNavCovSpi,
    &ubloxcfg_cfgMsgoutUbxNavCovI2c,
    &ubloxcfg_cfgMsgoutUbxNavCovUsb,
    &ubloxcfg_cfgMsgoutUbxNavDopUart1,
    &ubloxcfg_cfgMsgoutUbxNavDopUart2,
    &ubloxcfg_cfgMsgoutUbxNavDopSpi,
    &ubloxcfg_cfgMsgoutUbxNavDopI2c,
    &ubloxcfg_cfgMsgoutUbxNavDopUsb,
    &ubloxcfg_cfgMsgoutUbxNavEellUart1,
    &ubloxcfg_cfgMsgoutUbxNavEellUart2,
    &ubloxcfg_cfgMsgoutUbxNavEellSpi,
    &ubloxcfg_cfgMsgoutUbxNavEellUsb,
    &ubloxcfg_cfgMsgoutUbxNavEellI2c,
    &ubloxcfg_cfgMsgoutUbxNavEoeUart1,
    &ubloxcfg_cfgMsgoutUbxNavEoeUart2,
    &ubloxcfg_cfgMsgoutUbxNavEoeSpi,
    &ubloxcfg_cfgMsgoutUbxNavEoeI2c,
    &ubloxcfg_cfgMsgoutUbxNavEoeUsb,
    &ubloxcfg_cfgMsgoutUbxNavGeofenceUart1,
    &ubloxcfg_cfgMsgoutUbxNavGeofenceUart2,
    &ubloxcfg_cfgMsgoutUbxNavGeofenceSpi,
    &ubloxcfg_cfgMsgoutUbxNavGeofenceI2c,
    &ubloxcfg_cfgMsgoutUbxNavGeofenceUsb,
    &ubloxcfg_cfgMsgoutUbxNavHpposecefUart1,
    &ubloxcfg_cfgMsgoutUbxNavHpposecefUart2,
    &ubloxcfg_cfgMsgoutUbxNavHpposecefSpi,
    &ubloxcfg_cfgMsgoutUbxNavHpposecefI2c,
    &ubloxcfg_cfgMsgoutUbxNavHpposecefUsb,
    &ubloxcfg_cfgMsgoutUbxNavHpposllhUart1,
    &ubloxcfg_cfgMsgoutUbxNavHpposllhUart2,
    &ubloxcfg_cfgMsgoutUbxNavHpposllhSpi,
    &ubloxcfg_cfgMsgoutUbxNavHpposllhI2c,
    &ubloxcfg_cfgMsgoutUbxNavHpposllhUsb,
    &ubloxcfg_cfgMsgoutUbxNavOdoUart1,
    &ubloxcfg_cfgMsgoutUbxNavOdoUart2,
    &ubloxcfg_cfgMsgoutUbxNavOdoSpi,
    &ubloxcfg_cfgMsgoutUbxNavOdoI2c,
    &ubloxcfg_cfgMsgoutUbxNavOdoUsb,
    &ubloxcfg_cfgMsgoutUbxNavOrbUart1,
    &ubloxcfg_cfgMsgoutUbxNavOrbUart2,
    &ubloxcfg_cfgMsgoutUbxNavOrbSpi,
    &ubloxcfg_cfgMsgoutUbxNavOrbI2c,
    &ubloxcfg_cfgMsgoutUbxNavOrbUsb,
    &ubloxcfg_cfgMsgoutUbxNavPosecefUart1,
    &ubloxcfg_cfgMsgoutUbxNavPosecefUart2,
    &ubloxcfg_cfgMsgoutUbxNavPosecefSpi,
    &ubloxcfg_cfgMsgoutUbxNavPosecefI2c,
    &ubloxcfg_cfgMsgoutUbxNavPosecefUsb,
    &ubloxcfg_cfgMsgoutUbxNavPosllhUart1,
    &ubloxcfg_cfgMsgoutUbxNavPosllhUart2,
    &ubloxcfg_cfgMsgoutUbxNavPosllhSpi,
    &ubloxcfg_cfgMsgoutUbxNavPosllhI2c,
    &ubloxcfg_cfgMsgoutUbxNavPosllhUsb,
    &ubloxcfg_cfgMsgoutUbxNavPvtUart1,
    &ubloxcfg_cfgMsgoutUbxNavPvtUart2,
    &ubloxcfg_cfgMsgoutUbxNavPvtSpi,
    &ubloxcfg_cfgMsgoutUbxNavPvtI2c,
    &ubloxcfg_cfgMsgoutUbxNavPvtUsb,
    &ubloxcfg_cfgMsgoutUbxNavRelposnedUart1,
    &ubloxcfg_cfgMsgoutUbxNavRelposnedUart2,
    &ubloxcfg_cfgMsgoutUbxNavRelposnedSpi,
    &ubloxcfg_cfgMsgoutUbxNavRelposnedI2c,
    &ubloxcfg_cfgMsgoutUbxNavRelposnedUsb,
    &ubloxcfg_cfgMsgoutUbxNavSatUart1,
    &ubloxcfg_cfgMsgoutUbxNavSatUart2,
    &ubloxcfg_cfgMsgoutUbxNavSatSpi,
    &ubloxcfg_cfgMsgoutUbxNavSatI2c,
    &ubloxcfg_cfgMsgoutUbxNavSatUsb,
    &ubloxcfg_cfgMsgoutUbxNavSbasUart1,
    &ubloxcfg_cfgMsgoutUbxNavSbasUart2,
    &ubloxcfg_cfgMsgoutUbxNavSbasSpi,
    &ubloxcfg_cfgMsgoutUbxNavSbasI2c,
    &ubloxcfg_cfgMsgoutUbxNavSbasUsb,
    &ubloxcfg_cfgMsgoutUbxNavSigUart1,
    &ubloxcfg_cfgMsgoutUbxNavSigUart2,
    &ubloxcfg_cfgMsgoutUbxNavSigSpi,
    &ubloxcfg_cfgMsgoutUbxNavSigI2c,
    &ubloxcfg_cfgMsgoutUbxNavSigUsb,
    &ubloxcfg_cfgMsgoutUbxNavSlasUart1,
    &ubloxcfg_cfgMsgoutUbxNavSlasUart2,
    &ubloxcfg_cfgMsgoutUbxNavSlasSpi,
    &ubloxcfg_cfgMsgoutUbxNavSlasI2c,
    &ubloxcfg_cfgMsgoutUbxNavSlasUsb,
    &ubloxcfg_cfgMsgoutUbxNavStatusUart1,
    &ubloxcfg_cfgMsgoutUbxNavStatusUart2,
    &ubloxcfg_cfgMsgoutUbxNavStatusSpi,
    &ubloxcfg_cfgMsgoutUbxNavStatusI2c,
    &ubloxcfg_cfgMsgoutUbxNavStatusUsb,
    &ubloxcfg_cfgMsgoutUbxNavSvinUart1,
    &ubloxcfg_cfgMsgoutUbxNavSvinUart2,
    &ubloxcfg_cfgMsgoutUbxNavSvinSpi,
    &ubloxcfg_cfgMsgoutUbxNavSvinI2c,
    &ubloxcfg_cfgMsgoutUbxNavSvinUsb,
    &ubloxcfg_cfgMsgoutUbxNavTimebdsUart1,
    &ubloxcfg_cfgMsgoutUbxNavTimebdsUart2,
    &ubloxcfg_cfgMsgoutUbxNavTimebdsSpi,
    &ubloxcfg_cfgMsgoutUbxNavTimebdsI2c,
    &ubloxcfg_cfgMsgoutUbxNavTimebdsUsb,
    &ubloxcfg_cfgMsgoutUbxNavTimegalUart1,
    &ubloxcfg_cfgMsgoutUbxNavTimegalUart2,
    &ubloxcfg_cfgMsgoutUbxNavTimegalSpi,
    &ubloxcfg_cfgMsgoutUbxNavTimegalI2c,
    &ubloxcfg_cfgMsgoutUbxNavTimegalUsb,
    &ubloxcfg_cfgMsgoutUbxNavTimegloUart1,
    &ubloxcfg_cfgMsgoutUbxNavTimegloUart2,
    &ubloxcfg_cfgMsgoutUbxNavTimegloSpi,
    &ubloxcfg_cfgMsgoutUbxNavTimegloI2c,
    &ubloxcfg_cfgMsgoutUbxNavTimegloUsb,
    &ubloxcfg_cfgMsgoutUbxNavTimegpsUart1,
    &ubloxcfg_cfgMsgoutUbxNavTimegpsUart2,
    &ubloxcfg_cfgMsgoutUbxNavTimegpsSpi,
    &ubloxcfg_cfgMsgoutUbxNavTimegpsI2c,
    &ubloxcfg_cfgMsgoutUbxNavTimegpsUsb,
    &ubloxcfg_cfgMsgoutUbxNavTimelsUart1,
    &ubloxcfg_cfgMsgoutUbxNavTimelsUart2,
    &ubloxcfg_cfgMsgoutUbxNavTimelsSpi,
    &ubloxcfg_cfgMsgoutUbxNavTimelsI2c,
    &ubloxcfg_cfgMsgoutUbxNavTimelsUsb,
    &ubloxcfg_cfgMsgoutUbxNavTimeqzssUart1,
    &ubloxcfg_cfgMsgoutUbxNavTimeqzssUart2,
    &ubloxcfg_cfgMsgoutUbxNavTimeqzssSpi,
    &ubloxcfg_cfgMsgoutUbxNavTimeqzssI2c,
    &ubloxcfg_cfgMsgoutUbxNavTimeqzssUsb,
    &ubloxcfg_cfgMsgoutUbxNavTimeutcUart1,
    &ubloxcfg_cfgMsgoutUbxNavTimeutcUart2,
    &ubloxcfg_cfgMsgoutUbxNavTimeutcSpi,
    &ubloxcfg_cfgMsgoutUbxNavTimeutcI2c,
    &ubloxcfg_cfgMsgoutUbxNavTimeutcUsb,
    &ubloxcfg_cfgMsgoutUbxNavVelecefUart1,
    &ubloxcfg_cfgMsgoutUbxNavVelecefUart2,
    &ubloxcfg_cfgMsgoutUbxNavVelecefSpi,
    &ubloxcfg_cfgMsgoutUbxNavVelecefI2c,
    &ubloxcfg_cfgMsgoutUbxNavVelecefUsb,
    &ubloxcfg_cfgMsgoutUbxNavVelnedUart1,
    &ubloxcfg_cfgMsgoutUbxNavVelnedUart2,
    &ubloxcfg_cfgMsgoutUbxNavVelnedSpi,
    &ubloxcfg_cfgMsgoutUbxNavVelnedI2c,
    &ubloxcfg_cfgMsgoutUbxNavVelnedUsb,
    &ubloxcfg_cfgMsgoutUbxRxmMeasxUart1,
    &ubloxcfg_cfgMsgoutUbxRxmMeasxUart2,
    &ubloxcfg_cfgMsgoutUbxRxmMeasxSpi,
    &ubloxcfg_cfgMsgoutUbxRxmMeasxI2c,
    &ubloxcfg_cfgMsgoutUbxRxmMeasxUsb,
    &ubloxcfg_cfgMsgoutUbxRxmRawxUart1,
    &ubloxcfg_cfgMsgoutUbxRxmRawxUart2,
    &ubloxcfg_cfgMsgoutUbxRxmRawxSpi,
    &ubloxcfg_cfgMsgoutUbxRxmRawxI2c,
    &ubloxcfg_cfgMsgoutUbxRxmRawxUsb,
    &ubloxcfg_cfgMsgoutUbxRxmRlmUart1,
    &ubloxcfg_cfgMsgoutUbxRxmRlmUart2,
    &ubloxcfg_cfgMsgoutUbxRxmRlmSpi,
    &ubloxcfg_cfgMsgoutUbxRxmRlmI2c,
    &ubloxcfg_cfgMsgoutUbxRxmRlmUsb,
    &ubloxcfg_cfgMsgoutUbxRxmRtcmUart1,
    &ubloxcfg_cfgMsgoutUbxRxmRtcmUart2,
    &ubloxcfg_cfgMsgoutUbxRxmRtcmSpi,
    &ubloxcfg_cfgMsgoutUbxRxmRtcmI2c,
    &ubloxcfg_cfgMsgoutUbxRxmRtcmUsb,
    &ubloxcfg_cfgMsgoutUbxRxmSfrbxUart1,
    &ubloxcfg_cfgMsgoutUbxRxmSfrbxUart2,
    &ubloxcfg_cfgMsgoutUbxRxmSfrbxSpi,
    &ubloxcfg_cfgMsgoutUbxRxmSfrbxI2c,
    &ubloxcfg_cfgMsgoutUbxRxmSfrbxUsb,
    &ubloxcfg_cfgMsgoutUbxTimTm2Uart1,
    &ubloxcfg_cfgMsgoutUbxTimTm2Uart2,
    &ubloxcfg_cfgMsgoutUbxTimTm2Spi,
    &ubloxcfg_cfgMsgoutUbxTimTm2I2c,
    &ubloxcfg_cfgMsgoutUbxTimTm2Usb,
    &ubloxcfg_cfgMsgoutUbxTimTpUart1,
    &ubloxcfg_cfgMsgoutUbxTimTpUart2,
    &ubloxcfg_cfgMsgoutUbxTimTpSpi,
    &ubloxcfg_cfgMsgoutUbxTimTpI2c,
    &ubloxcfg_cfgMsgoutUbxTimTpUsb,
    &ubloxcfg_cfgMsgoutUbxTimVrfyUart1,
    &ubloxcfg_cfgMsgoutUbxTimVrfyUart2,
    &ubloxcfg_cfgMsgoutUbxTimVrfySpi,
    &ubloxcfg_cfgMsgoutUbxTimVrfyI2c,
    &ubloxcfg_cfgMsgoutUbxTimVrfyUsb,
    &ubloxcfg_cfgNavhpgDgnssmode,
    &ubloxcfg_cfgNavspgFixmode,
    &ubloxcfg_cfgNavspgInifix3d,
    &ubloxcfg_cfgNavspgWknrollover,
    &ubloxcfg_cfgNavspgUsePpp,
    &ubloxcfg_cfgNavspgUtcstandard,
    &ubloxcfg_cfgNavspgDynmodel,
    &ubloxcfg_cfgNavspgAckaiding,
    &ubloxcfg_cfgNavspgUseUsrdat,
    &ubloxcfg_cfgNavspgUsrdatMaja,
    &ubloxcfg_cfgNavspgUsrdatFlat,
    &ubloxcfg_cfgNavspgUsrdatDx,
    &ubloxcfg_cfgNavspgUsrdatDy,
    &ubloxcfg_cfgNavspgUsrdatDz,
    &ubloxcfg_cfgNavspgUsrdatRotx,
    &ubloxcfg_cfgNavspgUsrdatRoty,
    &ubloxcfg_cfgNavspgUsrdatRotz,
    &ubloxcfg_cfgNavspgUsrdatScale,
    &ubloxcfg_cfgNavspgInfilMinsvs,
    &ubloxcfg_cfgNavspgInfilMaxsvs,
    &ubloxcfg_cfgNavspgInfilMincno,
    &ubloxcfg_cfgNavspgInfilMinelev,
    &ubloxcfg_cfgNavspgInfilNcnothrs,
    &ubloxcfg_cfgNavspgInfilCnothrs,
    &ubloxcfg_cfgNavspgOutfilPdop,
    &ubloxcfg_cfgNavspgOutfilTdop,
    &ubloxcfg_cfgNavspgOutfilPacc,
    &ubloxcfg_cfgNavspgOutfilTacc,
    &ubloxcfg_cfgNavspgOutfilFacc,
    &ubloxcfg_cfgNavspgConstrAlt,
    &ubloxcfg_cfgNavspgConstrAltvar,
    &ubloxcfg_cfgNavspgConstrDgnssto,
    &ubloxcfg_cfgNavspgSigattcomp,
    &ubloxcfg_cfgNmeaProtver,
    &ubloxcfg_cfgNmeaMaxsvs,
    &ubloxcfg_cfgNmeaCompat,
    &ubloxcfg_cfgNmeaConsider,
    &ubloxcfg_cfgNmeaLimit82,
    &ubloxcfg_cfgNmeaHighprec,
    &ubloxcfg_cfgNmeaSvnumbering,
    &ubloxcfg_cfgNmeaFiltGps,
    &ubloxcfg_cfgNmeaFiltSbas,
    &ubloxcfg_cfgNmeaFiltGal,
    &ubloxcfg_cfgNmeaFiltQzss,
    &ubloxcfg_cfgNmeaFiltGlo,
    &ubloxcfg_cfgNmeaFiltBds,
    &ubloxcfg_cfgNmeaOutInvfix,
    &ubloxcfg_cfgNmeaOutMskfix,
    &ubloxcfg_cfgNmeaOutInvtime,
    &ubloxcfg_cfgNmeaOutInvdate,
    &ubloxcfg_cfgNmeaOutOnlygps,
    &ubloxcfg_cfgNmeaOutFrozencog,
    &ubloxcfg_cfgNmeaMaintalkerid,
    &ubloxcfg_cfgNmeaGsvtalkerid,
    &ubloxcfg_cfgNmeaBdstalkerid,
    &ubloxcfg_cfgOdoUseOdo,
    &ubloxcfg_cfgOdoUseCog,
    &ubloxcfg_cfgOdoOutlpvel,
    &ubloxcfg_cfgOdoOutlpcog,
    &ubloxcfg_cfgOdoProfile,
    &ubloxcfg_cfgOdoCogmaxspeed,
    &ubloxcfg_cfgOdoCogmaxposacc,
    &ubloxcfg_cfgOdoVellpgain,
    &ubloxcfg_cfgOdoCoglpgain,
    &ubloxcfg_cfgPmOperatemode,
    &ubloxcfg_cfgPmPosupdateperiod,
    &ubloxcfg_cfgPmAcqperiod,
    &ubloxcfg_cfgPmGridoffset,
    &ubloxcfg_cfgPmOntime,
    &ubloxcfg_cfgPmMinacqtime,
    &ubloxcfg_cfgPmMaxacqtime,
    &ubloxcfg_cfgPmDonotenteroff,
    &ubloxcfg_cfgPmWaittimefix,
    &ubloxcfg_cfgPmUpdateeph,
    &ubloxcfg_cfgPmExtintsel,
    &ubloxcfg_cfgPmExtintwake,
    &ubloxcfg_cfgPmExtintbackup,
    &ubloxcfg_cfgPmExtintinactive,
    &ubloxcfg_cfgPmExtintinactivity,
    &ubloxcfg_cfgPmLimitpeakcurr,
    &ubloxcfg_cfgQzssUseSlasDgnss,
    &ubloxcfg_cfgQzssUseSlasTestmode,
    &ubloxcfg_cfgQzssUseSlasRaimUncorr,
    &ubloxcfg_cfgRateMeas,
    &ubloxcfg_cfgRateNav,
    &ubloxcfg_cfgRateTimeref,
    &ubloxcfg_cfgRinvDump,
    &ubloxcfg_cfgRinvBinary,
    &ubloxcfg_cfgRinvDataSize,
    &ubloxcfg_cfgRinvChunk0,
    &ubloxcfg_cfgRinvChunk1,
    &ubloxcfg_cfgRinvChunk2,
    &ubloxcfg_cfgRinvChunk3,
    &ubloxcfg_cfgRtcmDf003Out,
    &ubloxcfg_cfgRtcmDf003In,
    &ubloxcfg_cfgRtcmDf003InFilter,
    &ubloxcfg_cfgSbasUseTestmode,
    &ubloxcfg_cfgSbasUseRanging,
    &ubloxcfg_cfgSbasUseDiffcorr,
    &ubloxcfg_cfgSbasUseIntegrity,
    &ubloxcfg_cfgSbasPrnscanmask,
    &ubloxcfg_cfgSecCfgLock,
    &ubloxcfg_cfgSecCfgLockUnlockgrp1,
    &ubloxcfg_cfgSecCfgLockUnlockgrp2,
    &ubloxcfg_cfgSfcoreUseSf,
    &ubloxcfg_cfgSfimuGyroTcUpdatePeriod,
    &ubloxcfg_cfgSfimuGyroRmsthdl,
    &ubloxcfg_cfgSfimuGyroFrequency,
    &ubloxcfg_cfgSfimuGyroLatency,
    &ubloxcfg_cfgSfimuGyroAccuracy,
    &ubloxcfg_cfgSfimuAccelRmsthdl,
    &ubloxcfg_cfgSfimuAccelFrequency,
    &ubloxcfg_cfgSfimuAccelLatency,
    &ubloxcfg_cfgSfimuAccelAccuracy,
    &ubloxcfg_cfgSfimuImuI2cSclPio,
    &ubloxcfg_cfgSfimuImuI2cSdaPio,
    &ubloxcfg_cfgSfimuAutoMntalgEna,
    &ubloxcfg_cfgSfimuImuMntalgYaw,
    &ubloxcfg_cfgSfimuImuMntalgPitch,
    &ubloxcfg_cfgSfimuImuMntalgRoll,
    &ubloxcfg_cfgSignalGpsEna,
    &ubloxcfg_cfgSignalGpsL1caEna,
    &ubloxcfg_cfgSignalGpsL2cEna,
    &ubloxcfg_cfgSignalSbasEna,
    &ubloxcfg_cfgSignalSbasL1caEna,
    &ubloxcfg_cfgSignalGalEna,
    &ubloxcfg_cfgSignalGalE1Ena,
    &ubloxcfg_cfgSignalGalE5bEna,
    &ubloxcfg_cfgSignalBdsEna,
    &ubloxcfg_cfgSignalBdsB1Ena,
    &ubloxcfg_cfgSignalBdsB2Ena,
    &ubloxcfg_cfgSignalQzssEna,
    &ubloxcfg_cfgSignalQzssL1caEna,
    &ubloxcfg_cfgSignalQzssL1sEna,
    &ubloxcfg_cfgSignalQzssL2cEna,
    &ubloxcfg_cfgSignalGloEna,
    &ubloxcfg_cfgSignalGloL1Ena,
    &ubloxcfg_cfgSignalGloL2Ena,
    &ubloxcfg_cfgSpiMaxff,
    &ubloxcfg_cfgSpiCpolarity,
    &ubloxcfg_cfgSpiCphase,
    &ubloxcfg_cfgSpiExtendedtimeout,
    &ubloxcfg_cfgSpiEnabled,
    &ubloxcfg_cfgSpiinprotUbx,
    &ubloxcfg_cfgSpiinprotNmea,
    &ubloxcfg_cfgSpiinprotRtcm3x,
    &ubloxcfg_cfgSpioutprotUbx,
    &ubloxcfg_cfgSpioutprotNmea,
    &ubloxcfg_cfgSpioutprotRtcm3x,
    &ubloxcfg_cfgTmodeMode,
    &ubloxcfg_cfgTmodePosType,
    &ubloxcfg_cfgTmodeEcefX,
    &ubloxcfg_cfgTmodeEcefY,
    &ubloxcfg_cfgTmodeEcefZ,
    &ubloxcfg_cfgTmodeEcefXHp,
    &ubloxcfg_cfgTmodeEcefYHp,
    &ubloxcfg_cfgTmodeEcefZHp,
    &ubloxcfg_cfgTmodeLat,
    &ubloxcfg_cfgTmodeLon,
    &ubloxcfg_cfgTmodeHeight,
    &ubloxcfg_cfgTmodeLatHp,
    &ubloxcfg_cfgTmodeLonHp,
    &ubloxcfg_cfgTmodeHeightHp,
    &ubloxcfg_cfgTmodeFixedPosAcc,
    &ubloxcfg_cfgTmodeSvinMinDur,
    &ubloxcfg_cfgTmodeSvinAccLimit,
    &ubloxcfg_cfgTpPulseDef,
    &ubloxcfg_cfgTpPulseLengthDef,
    &ubloxcfg_cfgTpAntCabledelay,
    &ubloxcfg_cfgTpPeriodTp1,
    &ubloxcfg_cfgTpPeriodLockTp1,
    &ubloxcfg_cfgTpFreqTp1,
    &ubloxcfg_cfgTpFreqLockTp1,
    &ubloxcfg_cfgTpLenTp1,
    &ubloxcfg_cfgTpLenLockTp1,
    &ubloxcfg_cfgTpDutyTp1,
    &ubloxcfg_cfgTpDutyLockTp1,
    &ubloxcfg_cfgTpUserDelayTp1,
    &ubloxcfg_cfgTpTp1Ena,
    &ubloxcfg_cfgTpSyncGnssTp1,
    &ubloxcfg_cfgTpUseLockedTp1,
    &ubloxcfg_cfgTpAlignToTowTp1,
    &ubloxcfg_cfgTpPolTp1,
    &ubloxcfg_cfgTpTimegridTp1,
    &ubloxcfg_cfgTxreadyEnabled,
    &ubloxcfg_cfgTxreadyPolarity,
    &ubloxcfg_cfgTxreadyPin,
    &ubloxcfg_cfgTxreadyThreshold,
    &ubloxcfg_cfgTxreadyInterface,
    &ubloxcfg_cfgUart1Baudrate,
    &ubloxcfg_cfgUart1Stopbits,
    &ubloxcfg_cfgUart1Databits,
    &ubloxcfg_cfgUart1Parity,
    &ubloxcfg_cfgUart1Enabled,
    &ubloxcfg_cfgUart1inprotUbx,
    &ubloxcfg_cfgUart1inprotNmea,
    &ubloxcfg_cfgUart1inprotRtcm3x,
    &ubloxcfg_cfgUart1outprotUbx,
    &ubloxcfg_cfgUart1outprotNmea,
    &ubloxcfg_cfgUart1outprotRtcm3x,
    &ubloxcfg_cfgUart2Baudrate,
    &ubloxcfg_cfgUart2Stopbits,
    &ubloxcfg_cfgUart2Databits,
    &ubloxcfg_cfgUart2Parity,
    &ubloxcfg_cfgUart2Enabled,
    &ubloxcfg_cfgUart2Remap,
    &ubloxcfg_cfgUart2inprotUbx,
    &ubloxcfg_cfgUart2inprotNmea,
    &ubloxcfg_cfgUart2inprotRtcm3x,
    &ubloxcfg_cfgUart2outprotUbx,
    &ubloxcfg_cfgUart2outprotNmea,
    &ubloxcfg_cfgUart2outprotRtcm3x,
    &ubloxcfg_cfgUsbEnabled,
    &ubloxcfg_cfgUsbSelfpow,
    &ubloxcfg_cfgUsbVendorId,
    &ubloxcfg_cfgUsbProductId,
    &ubloxcfg_cfgUsbPower,
    &ubloxcfg_cfgUsbVendorStr0,
    &ubloxcfg_cfgUsbVendorStr1,
    &ubloxcfg_cfgUsbVendorStr2,
    &ubloxcfg_cfgUsbVendorStr3,
    &ubloxcfg_cfgUsbProductStr0,
    &ubloxcfg_cfgUsbProductStr1,
    &ubloxcfg_cfgUsbProductStr2,
    &ubloxcfg_cfgUsbProductStr3,
    &ubloxcfg_cfgUsbSerialNoStr0,
    &ubloxcfg_cfgUsbSerialNoStr1,
    &ubloxcfg_cfgUsbSerialNoStr2,
    &ubloxcfg_cfgUsbSerialNoStr3,
    &ubloxcfg_cfgUsbinprotUbx,
    &ubloxcfg_cfgUsbinprotNmea,
    &ubloxcfg_cfgUsbinprotRtcm3x,
    &ubloxcfg_cfgUsboutprotUbx,
    &ubloxcfg_cfgUsboutprotNmea,
    &ubloxcfg_cfgUsboutprotRtcm3x,
    &ubloxcfg_cfgUbloxcfgtestL,
    &ubloxcfg_cfgUbloxcfgtestU1,
    &ubloxcfg_cfgUbloxcfgtestU2,
    &ubloxcfg_cfgUbloxcfgtestU4,
    &ubloxcfg_cfgUbloxcfgtestU8,
    &ubloxcfg_cfgUbloxcfgtestI1,
    &ubloxcfg_cfgUbloxcfgtestI2,
    &ubloxcfg_cfgUbloxcfgtestI4,
    &ubloxcfg_cfgUbloxcfgtestI8,
    &ubloxcfg_cfgUbloxcfgtestX1,
    &ubloxcfg_cfgUbloxcfgtestX2,
    &ubloxcfg_cfgUbloxcfgtestX4,
    &ubloxcfg_cfgUbloxcfgtestX8,
    &ubloxcfg_cfgUbloxcfgtestR4,
    &ubloxcfg_cfgUbloxcfgtestR8,
    &ubloxcfg_cfgUbloxcfgtestE1,
    &ubloxcfg_cfgUbloxcfgtestE2,
    &ubloxcfg_cfgUbloxcfgtestE4
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaPubxPosition =
{
    .msgName   = "NMEA-PUBX-POSITION",
    .itemUart1 = &ubloxcfg_cfgMsgoutPubxIdPolypUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutPubxIdPolypUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutPubxIdPolypSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutPubxIdPolypI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutPubxIdPolypUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaPubxSvstatus =
{
    .msgName   = "NMEA-PUBX-SVSTATUS",
    .itemUart1 = &ubloxcfg_cfgMsgoutPubxIdPolysUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutPubxIdPolysUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutPubxIdPolysSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutPubxIdPolysI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutPubxIdPolysUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaPubxTime =
{
    .msgName   = "NMEA-PUBX-TIME",
    .itemUart1 = &ubloxcfg_cfgMsgoutPubxIdPolytUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutPubxIdPolytUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutPubxIdPolytSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutPubxIdPolytI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutPubxIdPolytUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardDtm =
{
    .msgName   = "NMEA-STANDARD-DTM",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdDtmUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdDtmUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdDtmSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdDtmI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdDtmUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardGbs =
{
    .msgName   = "NMEA-STANDARD-GBS",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdGbsUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdGbsUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdGbsSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdGbsI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdGbsUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardGga =
{
    .msgName   = "NMEA-STANDARD-GGA",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdGgaUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdGgaUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdGgaSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdGgaI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdGgaUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardGll =
{
    .msgName   = "NMEA-STANDARD-GLL",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdGllUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdGllUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdGllSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdGllI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdGllUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardGns =
{
    .msgName   = "NMEA-STANDARD-GNS",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdGnsUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdGnsUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdGnsSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdGnsI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdGnsUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardGrs =
{
    .msgName   = "NMEA-STANDARD-GRS",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdGrsUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdGrsUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdGrsSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdGrsI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdGrsUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardGsa =
{
    .msgName   = "NMEA-STANDARD-GSA",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdGsaUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdGsaUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdGsaSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdGsaI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdGsaUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardGst =
{
    .msgName   = "NMEA-STANDARD-GST",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdGstUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdGstUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdGstSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdGstI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdGstUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardGsv =
{
    .msgName   = "NMEA-STANDARD-GSV",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdGsvUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdGsvUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdGsvSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdGsvI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdGsvUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardRlm =
{
    .msgName   = "NMEA-STANDARD-RLM",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdRlmUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdRlmUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdRlmSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdRlmI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdRlmUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardRmc =
{
    .msgName   = "NMEA-STANDARD-RMC",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdRmcUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdRmcUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdRmcSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdRmcI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdRmcUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardVlw =
{
    .msgName   = "NMEA-STANDARD-VLW",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdVlwUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdVlwUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdVlwSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdVlwI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdVlwUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardVtg =
{
    .msgName   = "NMEA-STANDARD-VTG",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdVtgUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdVtgUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdVtgSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdVtgI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdVtgUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_nmeaStandardZda =
{
    .msgName   = "NMEA-STANDARD-ZDA",
    .itemUart1 = &ubloxcfg_cfgMsgoutNmeaIdZdaUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutNmeaIdZdaUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutNmeaIdZdaSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutNmeaIdZdaI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutNmeaIdZdaUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1005 =
{
    .msgName   = "RTCM-3X-TYPE1005",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1005Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1005Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1005Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1005I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1005Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1074 =
{
    .msgName   = "RTCM-3X-TYPE1074",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1074Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1074Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1074Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1074I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1074Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1077 =
{
    .msgName   = "RTCM-3X-TYPE1077",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1077Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1077Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1077Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1077I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1077Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1084 =
{
    .msgName   = "RTCM-3X-TYPE1084",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1084Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1084Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1084Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1084I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1084Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1087 =
{
    .msgName   = "RTCM-3X-TYPE1087",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1087Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1087Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1087Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1087I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1087Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1094 =
{
    .msgName   = "RTCM-3X-TYPE1094",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1094Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1094Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1094Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1094I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1094Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1097 =
{
    .msgName   = "RTCM-3X-TYPE1097",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1097Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1097Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1097Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1097I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1097Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1124 =
{
    .msgName   = "RTCM-3X-TYPE1124",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1124Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1124Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1124Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1124I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1124Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1127 =
{
    .msgName   = "RTCM-3X-TYPE1127",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1127Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1127Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1127Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1127I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1127Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType1230 =
{
    .msgName   = "RTCM-3X-TYPE1230",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType1230Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType1230Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType1230Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType1230I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType1230Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType4072_0 =
{
    .msgName   = "RTCM-3X-TYPE4072_0",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType40720Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType40720Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType40720Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType40720I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType40720Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_rtcm3xType4072_1 =
{
    .msgName   = "RTCM-3X-TYPE4072_1",
    .itemUart1 = &ubloxcfg_cfgMsgoutRtcm3xType40721Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutRtcm3xType40721Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutRtcm3xType40721Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutRtcm3xType40721I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutRtcm3xType40721Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxEsfAlg =
{
    .msgName   = "UBX-ESF-ALG",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxEsfAlgUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxEsfAlgUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxEsfAlgSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxEsfAlgI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxEsfAlgUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxEsfIns =
{
    .msgName   = "UBX-ESF-INS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxEsfInsUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxEsfInsUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxEsfInsSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxEsfInsI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxEsfInsUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxEsfMeas =
{
    .msgName   = "UBX-ESF-MEAS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxEsfMeasUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxEsfMeasUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxEsfMeasSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxEsfMeasI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxEsfMeasUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxEsfRaw =
{
    .msgName   = "UBX-ESF-RAW",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxEsfRawUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxEsfRawUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxEsfRawSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxEsfRawI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxEsfRawUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxEsfStatus =
{
    .msgName   = "UBX-ESF-STATUS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxEsfStatusUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxEsfStatusUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxEsfStatusSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxEsfStatusI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxEsfStatusUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxLogInfo =
{
    .msgName   = "UBX-LOG-INFO",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxLogInfoUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxLogInfoUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxLogInfoSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxLogInfoI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxLogInfoUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonComms =
{
    .msgName   = "UBX-MON-COMMS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonCommsUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonCommsUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonCommsSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonCommsI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonCommsUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonHw =
{
    .msgName   = "UBX-MON-HW",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonHwUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonHwUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonHwSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonHwI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonHwUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonHw2 =
{
    .msgName   = "UBX-MON-HW2",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonHw2Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonHw2Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonHw2Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonHw2I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonHw2Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonHw3 =
{
    .msgName   = "UBX-MON-HW3",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonHw3Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonHw3Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonHw3Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonHw3I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonHw3Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonIo =
{
    .msgName   = "UBX-MON-IO",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonIoUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonIoUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonIoSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonIoI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonIoUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonMsgpp =
{
    .msgName   = "UBX-MON-MSGPP",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonMsgppUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonMsgppUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonMsgppSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonMsgppI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonMsgppUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonRf =
{
    .msgName   = "UBX-MON-RF",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonRfUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonRfUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonRfSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonRfI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonRfUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonRxbuf =
{
    .msgName   = "UBX-MON-RXBUF",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonRxbufUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonRxbufUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonRxbufSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonRxbufI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonRxbufUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonRxr =
{
    .msgName   = "UBX-MON-RXR",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonRxrUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonRxrUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonRxrSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonRxrI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonRxrUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonSpan =
{
    .msgName   = "UBX-MON-SPAN",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonSpanUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonSpanUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonSpanSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonSpanI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonSpanUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonTemp =
{
    .msgName   = "UBX-MON-TEMP",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonTempUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonTempUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonTempSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonTempI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonTempUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxMonTxbuf =
{
    .msgName   = "UBX-MON-TXBUF",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxMonTxbufUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxMonTxbufUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxMonTxbufSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxMonTxbufI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxMonTxbufUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavAopstatus =
{
    .msgName   = "UBX-NAV-AOPSTATUS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavAopstatusUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavAopstatusUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavAopstatusSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavAopstatusI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavAopstatusUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavAtt =
{
    .msgName   = "UBX-NAV-ATT",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavAttUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavAttUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavAttSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavAttI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavAttUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavClock =
{
    .msgName   = "UBX-NAV-CLOCK",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavClockUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavClockUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavClockSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavClockI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavClockUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavCov =
{
    .msgName   = "UBX-NAV-COV",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavCovUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavCovUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavCovSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavCovI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavCovUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavDop =
{
    .msgName   = "UBX-NAV-DOP",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavDopUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavDopUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavDopSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavDopI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavDopUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavEell =
{
    .msgName   = "UBX-NAV-EELL",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavEellUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavEellUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavEellSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavEellI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavEellUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavEoe =
{
    .msgName   = "UBX-NAV-EOE",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavEoeUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavEoeUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavEoeSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavEoeI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavEoeUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavGeofence =
{
    .msgName   = "UBX-NAV-GEOFENCE",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavGeofenceUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavGeofenceUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavGeofenceSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavGeofenceI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavGeofenceUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavHpposecef =
{
    .msgName   = "UBX-NAV-HPPOSECEF",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavHpposecefUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavHpposecefUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavHpposecefSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavHpposecefI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavHpposecefUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavHpposllh =
{
    .msgName   = "UBX-NAV-HPPOSLLH",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavHpposllhUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavHpposllhUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavHpposllhSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavHpposllhI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavHpposllhUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavOdo =
{
    .msgName   = "UBX-NAV-ODO",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavOdoUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavOdoUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavOdoSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavOdoI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavOdoUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavOrb =
{
    .msgName   = "UBX-NAV-ORB",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavOrbUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavOrbUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavOrbSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavOrbI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavOrbUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavPosecef =
{
    .msgName   = "UBX-NAV-POSECEF",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavPosecefUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavPosecefUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavPosecefSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavPosecefI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavPosecefUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavPosllh =
{
    .msgName   = "UBX-NAV-POSLLH",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavPosllhUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavPosllhUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavPosllhSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavPosllhI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavPosllhUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavPvt =
{
    .msgName   = "UBX-NAV-PVT",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavPvtUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavPvtUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavPvtSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavPvtI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavPvtUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavRelposned =
{
    .msgName   = "UBX-NAV-RELPOSNED",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavRelposnedUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavRelposnedUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavRelposnedSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavRelposnedI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavRelposnedUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavSat =
{
    .msgName   = "UBX-NAV-SAT",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavSatUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavSatUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavSatSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavSatI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavSatUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavSbas =
{
    .msgName   = "UBX-NAV-SBAS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavSbasUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavSbasUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavSbasSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavSbasI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavSbasUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavSig =
{
    .msgName   = "UBX-NAV-SIG",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavSigUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavSigUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavSigSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavSigI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavSigUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavSlas =
{
    .msgName   = "UBX-NAV-SLAS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavSlasUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavSlasUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavSlasSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavSlasI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavSlasUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavStatus =
{
    .msgName   = "UBX-NAV-STATUS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavStatusUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavStatusUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavStatusSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavStatusI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavStatusUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavSvin =
{
    .msgName   = "UBX-NAV-SVIN",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavSvinUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavSvinUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavSvinSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavSvinI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavSvinUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavTimebds =
{
    .msgName   = "UBX-NAV-TIMEBDS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavTimebdsUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavTimebdsUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavTimebdsSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavTimebdsI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavTimebdsUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavTimegal =
{
    .msgName   = "UBX-NAV-TIMEGAL",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavTimegalUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavTimegalUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavTimegalSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavTimegalI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavTimegalUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavTimeglo =
{
    .msgName   = "UBX-NAV-TIMEGLO",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavTimegloUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavTimegloUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavTimegloSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavTimegloI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavTimegloUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavTimegps =
{
    .msgName   = "UBX-NAV-TIMEGPS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavTimegpsUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavTimegpsUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavTimegpsSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavTimegpsI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavTimegpsUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavTimels =
{
    .msgName   = "UBX-NAV-TIMELS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavTimelsUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavTimelsUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavTimelsSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavTimelsI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavTimelsUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavTimeqzss =
{
    .msgName   = "UBX-NAV-TIMEQZSS",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavTimeqzssUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavTimeqzssUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavTimeqzssSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavTimeqzssI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavTimeqzssUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavTimeutc =
{
    .msgName   = "UBX-NAV-TIMEUTC",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavTimeutcUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavTimeutcUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavTimeutcSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavTimeutcI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavTimeutcUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavVelecef =
{
    .msgName   = "UBX-NAV-VELECEF",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavVelecefUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavVelecefUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavVelecefSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavVelecefI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavVelecefUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxNavVelned =
{
    .msgName   = "UBX-NAV-VELNED",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxNavVelnedUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxNavVelnedUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxNavVelnedSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxNavVelnedI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxNavVelnedUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxRxmMeasx =
{
    .msgName   = "UBX-RXM-MEASX",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxRxmMeasxUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxRxmMeasxUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxRxmMeasxSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxRxmMeasxI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxRxmMeasxUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxRxmRawx =
{
    .msgName   = "UBX-RXM-RAWX",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxRxmRawxUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxRxmRawxUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxRxmRawxSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxRxmRawxI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxRxmRawxUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxRxmRlm =
{
    .msgName   = "UBX-RXM-RLM",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxRxmRlmUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxRxmRlmUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxRxmRlmSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxRxmRlmI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxRxmRlmUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxRxmRtcm =
{
    .msgName   = "UBX-RXM-RTCM",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxRxmRtcmUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxRxmRtcmUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxRxmRtcmSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxRxmRtcmI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxRxmRtcmUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxRxmSfrbx =
{
    .msgName   = "UBX-RXM-SFRBX",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxRxmSfrbxUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxRxmSfrbxUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxRxmSfrbxSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxRxmSfrbxI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxRxmSfrbxUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxTimTm2 =
{
    .msgName   = "UBX-TIM-TM2",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxTimTm2Uart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxTimTm2Uart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxTimTm2Spi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxTimTm2I2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxTimTm2Usb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxTimTp =
{
    .msgName   = "UBX-TIM-TP",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxTimTpUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxTimTpUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxTimTpSpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxTimTpI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxTimTpUsb
};

static const UBLOXCFG_MSGRATE_t ubloxcfg_ubxTimVrfy =
{
    .msgName   = "UBX-TIM-VRFY",
    .itemUart1 = &ubloxcfg_cfgMsgoutUbxTimVrfyUart1,
    .itemUart2 = &ubloxcfg_cfgMsgoutUbxTimVrfyUart2,
    .itemSpi   = &ubloxcfg_cfgMsgoutUbxTimVrfySpi,
    .itemI2c   = &ubloxcfg_cfgMsgoutUbxTimVrfyI2c,
    .itemUsb   = &ubloxcfg_cfgMsgoutUbxTimVrfyUsb
};
static const UBLOXCFG_MSGRATE_t * const ubloxcfg_allRates[86] =
{
    &ubloxcfg_nmeaPubxPosition,
    &ubloxcfg_nmeaPubxSvstatus,
    &ubloxcfg_nmeaPubxTime,
    &ubloxcfg_nmeaStandardDtm,
    &ubloxcfg_nmeaStandardGbs,
    &ubloxcfg_nmeaStandardGga,
    &ubloxcfg_nmeaStandardGll,
    &ubloxcfg_nmeaStandardGns,
    &ubloxcfg_nmeaStandardGrs,
    &ubloxcfg_nmeaStandardGsa,
    &ubloxcfg_nmeaStandardGst,
    &ubloxcfg_nmeaStandardGsv,
    &ubloxcfg_nmeaStandardRlm,
    &ubloxcfg_nmeaStandardRmc,
    &ubloxcfg_nmeaStandardVlw,
    &ubloxcfg_nmeaStandardVtg,
    &ubloxcfg_nmeaStandardZda,
    &ubloxcfg_rtcm3xType1005,
    &ubloxcfg_rtcm3xType1074,
    &ubloxcfg_rtcm3xType1077,
    &ubloxcfg_rtcm3xType1084,
    &ubloxcfg_rtcm3xType1087,
    &ubloxcfg_rtcm3xType1094,
    &ubloxcfg_rtcm3xType1097,
    &ubloxcfg_rtcm3xType1124,
    &ubloxcfg_rtcm3xType1127,
    &ubloxcfg_rtcm3xType1230,
    &ubloxcfg_rtcm3xType4072_0,
    &ubloxcfg_rtcm3xType4072_1,
    &ubloxcfg_ubxEsfAlg,
    &ubloxcfg_ubxEsfIns,
    &ubloxcfg_ubxEsfMeas,
    &ubloxcfg_ubxEsfRaw,
    &ubloxcfg_ubxEsfStatus,
    &ubloxcfg_ubxLogInfo,
    &ubloxcfg_ubxMonComms,
    &ubloxcfg_ubxMonHw,
    &ubloxcfg_ubxMonHw2,
    &ubloxcfg_ubxMonHw3,
    &ubloxcfg_ubxMonIo,
    &ubloxcfg_ubxMonMsgpp,
    &ubloxcfg_ubxMonRf,
    &ubloxcfg_ubxMonRxbuf,
    &ubloxcfg_ubxMonRxr,
    &ubloxcfg_ubxMonSpan,
    &ubloxcfg_ubxMonTemp,
    &ubloxcfg_ubxMonTxbuf,
    &ubloxcfg_ubxNavAopstatus,
    &ubloxcfg_ubxNavAtt,
    &ubloxcfg_ubxNavClock,
    &ubloxcfg_ubxNavCov,
    &ubloxcfg_ubxNavDop,
    &ubloxcfg_ubxNavEell,
    &ubloxcfg_ubxNavEoe,
    &ubloxcfg_ubxNavGeofence,
    &ubloxcfg_ubxNavHpposecef,
    &ubloxcfg_ubxNavHpposllh,
    &ubloxcfg_ubxNavOdo,
    &ubloxcfg_ubxNavOrb,
    &ubloxcfg_ubxNavPosecef,
    &ubloxcfg_ubxNavPosllh,
    &ubloxcfg_ubxNavPvt,
    &ubloxcfg_ubxNavRelposned,
    &ubloxcfg_ubxNavSat,
    &ubloxcfg_ubxNavSbas,
    &ubloxcfg_ubxNavSig,
    &ubloxcfg_ubxNavSlas,
    &ubloxcfg_ubxNavStatus,
    &ubloxcfg_ubxNavSvin,
    &ubloxcfg_ubxNavTimebds,
    &ubloxcfg_ubxNavTimegal,
    &ubloxcfg_ubxNavTimeglo,
    &ubloxcfg_ubxNavTimegps,
    &ubloxcfg_ubxNavTimels,
    &ubloxcfg_ubxNavTimeqzss,
    &ubloxcfg_ubxNavTimeutc,
    &ubloxcfg_ubxNavVelecef,
    &ubloxcfg_ubxNavVelned,
    &ubloxcfg_ubxRxmMeasx,
    &ubloxcfg_ubxRxmRawx,
    &ubloxcfg_ubxRxmRlm,
    &ubloxcfg_ubxRxmRtcm,
    &ubloxcfg_ubxRxmSfrbx,
    &ubloxcfg_ubxTimTm2,
    &ubloxcfg_ubxTimTp,
    &ubloxcfg_ubxTimVrfy
};
static const char * const ubloxcfg_allSources[4] =
{
    "u-blox ZED-F9P Interface Description (HPG 1.13) (https://www.u-blox.com/en/docs/UBX-18010854), copyright (c) 2020 u-blox AG",
    "u-blox NEO-M9N Interface description (SPG 4.04) (https://www.u-blox.com/en/docs/UBX-19035940), copyright (c) 2020 u-blox AG",
    "u-blox ZED-F9R Interface description (HPS 1.20) (https://www.u-blox.com/en/docs/UBX-19056845), copyright (c) 2020 u-blox AG",
    "u-center 20.01, copyright (c) 2020 u-blox AG",
};

#ifndef _DOXYGEN_
const void **_ubloxcfg_allItems(void) { return (const void **)ubloxcfg_allItems; }
const void **_ubloxcfg_allRates(void) { return (const void **)ubloxcfg_allRates; }
const char **_ubloxcfg_allSources(void) { return (const char **)ubloxcfg_allSources; }
#endif

